@@ -7,10 +7,11 @@
  *  unaltered copy of this message (including the copyright).
  */
 
-char Men3_mdisplay_c_sccsid[] = "@(#)mdisplay.c	1.12 26/4/92 (UKC)";
+char Men3_mdisplay_c_sccsid[] = "@(#)mdisplay.c	1.14 4/6/95 (UKC)";
 
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 
 #include <local/wn.h>
 #include "menu3.h"
@@ -31,9 +32,9 @@ static MENU *msfind MPROTO((int x, int y, WOTYPE wn, int ignore));
 static void msdelete MPROTO((MENU *menu));
 static void rmshow MPROTO((MENU *menu, WOTYPE wn));
 static void mshade MPROTO((MENU *menu, int colour));
-static void dcmess MPROTO((WOTYPE wn, MENU *mp));
+static void dcmess MPROTO((WOTYPE wn, MENU *mp, int invert, int greying));
 static int wbold MPROTO((WOTYPE wn, Box_t *clip));
-static void wgrey MPROTO((WOTYPE wn, Box_t *clip, int colour));
+static void wgrey MPROTO((WOTYPE wn, Box_t *clip, int colour, MENU *menu));
 static int b_in_m MPROTO((MENU *menu, MENU *button));
 
 #define inmenu(m,x,y)	(((x) > (m)->me_xstart) && ((x) <= (m)->me_xend) &&\
@@ -50,6 +51,52 @@ static int msnext = 0;		/* the number of menus in the stack */
 
 static int (*fpopsu)MPROTO((int wn)) = NULL, (*fpushsu)MPROTO((int wn)) = NULL;
 
+/*  Routines for turning on and off submenus RGA
+ */
+void
+Mactivate_submenu(menu)
+MENU *menu;
+{
+  menu->me_flags |= (ME_ISUB);
+}
+
+void
+Mdeactivate_submenu(menu)
+MENU *menu;
+{
+  menu->me_flags &= ~(ME_OPEN | ME_ISUB);
+}
+
+int
+Mselectable(menu)
+MENU *menu;
+{
+  return !(menu->me_flags & ME_NSEL);
+}
+
+/*  Return md of a menu
+ */
+int
+Mgetmd(x,y,wn)
+int x, y;
+WOTYPE wn;
+{
+  MENU *m, *menu;
+  unsigned short flags;
+
+  menu = msfind(x,y,wn,0);
+  if (menu)
+  {
+    flags = menu->me_flags;
+    menu->me_flags &= ~ME_NSEL;
+    m = mfind(menu,x,y);
+    menu->me_flags = flags;
+    if (m)
+      return m->me_omen->om_md;
+  }
+  return 0;
+}
+
 /*  Set the functions to be used for turning screen updating on and
  *  off. The functions are called in the same way as Mpushsu and Mpopsu,
  *  and should have the same semantics - in particular, they should stack.
@@ -70,7 +117,7 @@ int (*fpush)MPROTO((int wn)), (*fpop)MPROTO((int wn));
 const char *
 Mversion()
 {
-	return(_Men3wn_sccsdata[0]);
+	return(Men3wn__sccsdata[0]);
 }
 
 /*  Push screen updating onto the update stack.
@@ -154,7 +201,7 @@ int redo_save;
 		if (_menu_[i].om_wout != wn)
 			continue;
 		if (redo_save) {
-			if (_menu_[i].om_rect != NULL) {
+			if (_menu_[i].om_rect != NULLRECT) {
 				setarea(i,wn,1);
 			}
 			else
@@ -183,7 +230,7 @@ int md;
 
 	if (_menu_[md].om_root == NULL)
 		return;
-	if (_menu_[md].om_rect != NULL) {
+	if (_menu_[md].om_rect != NULLRECT) {
 		/* pr_destroy(_menu_[md].om_pr); */
 		setarea(md,_menu_[md].om_wout,1);
 	}
@@ -246,9 +293,10 @@ font_t *font0, *font1, *font2, *font3;
  *  disabled.
  */
 int
-Mnonsel(md,rvs)
+Mnonsel(md,rvs,display)
 int md;
 const char *rvs;
+int display;
 {
 	if ((md < 0) || (md >= MAXMEN)) {
 		menerr = MBADMD;
@@ -263,7 +311,7 @@ const char *rvs;
 		return(-1);
 	}
 	mnonsel(_menu_[md].om_root, rvs);
-	if (_menu_[md].om_last != NULL) {
+	if (display && _menu_[md].om_last != NULL) {
 		Mpushsu(_menu_[md].om_wout);
 		mredraw(_menu_[md].om_last);
 		Mpopsu(_menu_[md].om_wout);
@@ -459,7 +507,7 @@ int popup;
 			ms = menu->me_topleft;
 			wn_restore_area(ms->me_save);
 			wn_free_area(ms->me_save);
-			ms->me_save = NULL;
+			ms->me_save = (long)NULL;
 			msdelete(ms);
 		}
 		menu->me_flags &= ~ME_OPEN;
@@ -507,7 +555,7 @@ MENU *menu;
 			ms = m->me_topleft;
 			wn_restore_area(ms->me_save);
 			wn_free_area(ms->me_save);
-			ms->me_save = NULL;
+			ms->me_save = (long)NULL;
 			msdelete(ms);
 			if (m->me_flags & ME_OPEN) {
 				m->me_flags &= ~ME_OPEN;
@@ -721,9 +769,9 @@ WOTYPE wn;
 		_menu_[md].om_area.size.w -= 2;
 		_menu_[md].om_area.size.h -= 2;
 	}
-	if (_menu_[md].om_rect != NULL) {
+	if (_menu_[md].om_rect != NULLRECT) {
 		wn_free_area(_menu_[md].om_rect);
-		_menu_[md].om_rect = NULL;
+		_menu_[md].om_rect = NULLRECT;
 	}
 	if (save) {
 		/*  save the area that will be covered by the menu
@@ -772,12 +820,13 @@ int md;
 	if (b_in_m(_menu_[md].om_root,lastpress))
 		lastpress = NULL;
 
-	if (_menu_[md].om_rect == NULL)
-		wblank(_menu_[md].om_wout,&_menu_[md].om_area);
+	if (_menu_[md].om_rect == NULLRECT)
+		wblank(_menu_[md].om_wout,&_menu_[md].om_area,
+		       _menu_[md].om_root->me_bg_colour);
 	else {
 		wn_restore_area(_menu_[md].om_rect);
 		wn_free_area(_menu_[md].om_rect);
-		_menu_[md].om_rect = NULL;
+		_menu_[md].om_rect = NULLRECT;
 	}
 	return(0);
 }
@@ -803,7 +852,7 @@ int drawall;
 		cl.pos.y = menu->me_ystart + 1;
 		cl.size.w = menu->me_xend - cl.pos.x;
 		cl.size.h = menu->me_yend - cl.pos.y;
-		if (wblank(wn,&cl) < 0) {
+		if (wblank(wn,&cl,menu->me_bg_colour) < 0) {
 			menerr = MBADWD;
 			Mpopsu(wn);
 			return(-1);
@@ -837,11 +886,14 @@ int colour;
 	cl.size.w = menu->me_xend - cl.pos.x;
 	cl.size.h = menu->me_yend - cl.pos.y;
 	if (colour & MH_BOLD)
-		wbold(wn,&cl);
+	  wbold(wn,&cl);
 	if (colour & MH_GREY)
-		wgrey(wn,&cl,1);
+	  wgrey(wn,&cl,1,menu);
 	if (colour & MH_BLACK)
-		wn_invert_area(wn,cl.pos.x,cl.pos.y,cl.size.w,cl.size.h);
+	  if (wn_use_alloc_color_for_highlight(0))
+	    dcmess(wn,menu,1,0);	/* invert */
+	  else
+	    wn_invert_area(wn,cl.pos.x,cl.pos.y,cl.size.w,cl.size.h);
 }
 
 int
@@ -904,16 +956,18 @@ WOTYPE wn;
 		rmshow(menu->me_botrite,wn);
 	}
 	else 
-		dcmess(wn,menu);
+		dcmess(wn,menu,0,0);
 	mshade(menu,menu->me_colour);
 }
 
 /*  Display string  in the centre of menu field. Only called by rmshow.
  */
 static void
-dcmess(wn,mp)
+dcmess(wn,mp,invert,greying)
 WOTYPE wn;
 MENU *mp;
+int invert;
+int greying;
 {
 	register int l, cx, cy, x, y;
 	int charheight, charbase;
@@ -947,7 +1001,7 @@ MENU *mp;
 		if (*sp == '\n')
 			l++;
 	y = cy - (l * charheight) / 2 + charbase;
-	wblank(wn,&cl);
+	wblank(wn,&cl, invert ? mp->me_fg_colour : mp->me_bg_colour);
 	while (*str) {
 		/* calculate the length of a caption line
 		 */
@@ -974,7 +1028,10 @@ MENU *mp;
 		db.DBSrcString = str;
 		db.DBScreen = 0;
 		db.DBFont = fnt;
-		wn_wdbyte(wn,&db,&cl);
+		if (invert)
+		  wn_wdbyte(wn,&db,&cl,mp->me_bg_colour,mp->me_fg_colour);
+		else
+		  wn_wdbyte(wn,&db,&cl,mp->me_fg_colour,mp->me_bg_colour);
 		str = sp;
 		while ((*str != '\n') && (*str != 0))
 			str++;
@@ -982,18 +1039,21 @@ MENU *mp;
 			str++;
 		y += charheight;
 	}
-	if (mp->me_flags & ME_NSEL)
-	wgrey(wn,&cl,0);
+	if (!greying && mp->me_flags & ME_NSEL)
+	  wgrey(wn,&cl,0,mp);
 }
 
+
 /*  Blank the area described in the clip area.
  */
 int
-wblank(wn,clip)
+wblank(wn,clip,colour)
 WOTYPE wn;
 Box_t *clip;
+long colour;
 {
-	wn_set_area(wn, clip->pos.x, clip->pos.y, clip->size.w, clip->size.h, WN_BG);
+	wn_set_area(wn, clip->pos.x, clip->pos.y, clip->size.w, clip->size.h,
+		    colour);
 	return(0);
 }
 
@@ -1013,21 +1073,80 @@ Box_t *clip;
  *  is in the foreground colour. If 0 it is in the background;
  */
 static void
-wgrey(wn,clip,colour)
+wgrey(wn,clip,colour,menu)
 WOTYPE wn;
 Box_t *clip;
 int colour;
+MENU* menu;
 {
-	int shade, func;
+	int shade, func, want_menu_colors = 0;
+	long fg, bg;
+	static color_done = -1;
+	static color_t color_fg, color_bg;
 
-	if (colour == 1) {
-		shade = WN_GREY4;
-		func = R_OR;
+	if (color_done == -1)
+	{
+	  color_fg.co_pixel = WN_FG;
+	  color_bg.co_pixel = WN_BG;
+	  if (wn_use_menu_colors())
+	  {
+	    const char *colorname;
+	    
+	    colorname = wn_get_default("DisabledTextColor");
+	    if (colorname == NULL)
+	      colorname = "gray";
+	    wn_parse_color(colorname, &color_fg);
+	    if (!wn_alloc_color(&color_fg, colorname))
+	      color_fg.co_pixel = WN_FG;
+
+	    colorname = wn_get_default("LastButtonTextColor");
+	    if (colorname == NULL)
+	      colorname = "white";
+	    wn_parse_color(colorname, &color_bg);
+	    if (!wn_alloc_color(&color_bg, colorname))
+	      color_bg.co_pixel = WN_BG;
+
+	    color_done = 1;	/* done and using colors */
+	  }
+	  else
+	    color_done = wn_use_alloc_color(0);	/* 0 for adjacent planes */
 	}
-	else {
-		shade = WN_GREY12;
-		func = R_AND;
+
+	if (color_done == 1)
+	{
+	  fg = menu->me_fg_colour;
+	  bg = menu->me_bg_colour;
+	  if (colour == 0)
+	  {
+	    menu->me_fg_colour = color_fg.co_pixel;
+	    menu->me_bg_colour = WN_BG;
+	  }
+	  else
+	  {
+	    menu->me_fg_colour = color_bg.co_pixel;
+	    menu->me_bg_colour = color_fg.co_pixel;
+	  }
+	  dcmess(wn,menu,0,1); /* greying */
+	  menu->me_fg_colour = fg;
+	  menu->me_bg_colour = bg;
+	}
+	else
+	{
+	  if (colour == 1) {
+	    shade = WN_GREY4;
+	    func = R_OR;
+	  }
+	  else {
+	    shade = WN_GREY12;
+	    func = R_AND;
+	  }
+	  wn_shade_area(wn, clip->pos.x, clip->pos.y,
+			clip->size.w, clip->size.h, shade, func);
 	}
-	wn_shade_area(wn, clip->pos.x, clip->pos.y,
-					clip->size.w, clip->size.h, shade, func);
 }
+
+
+
+
+
+
