@@ -747,7 +747,7 @@ Edit_propchange **p_pc;
 			  while(*iptr != '\n' && iptr != ilim)
 			  {
 			    xpos += char_width;
-			    *iptr++;
+			    iptr++;
 			    point++;
 			  }
 			  break;
@@ -862,7 +862,7 @@ Edit_propchange **p_pc;
 	  while(*iptr != '\n' && iptr != ilim)
 	  {
 	    xpos += char_width;
-	    *iptr++;
+	    iptr++;
 	    point++;
 	  }
 	  line_continues = 0;
