@@ -9,21 +9,11 @@
 
 char utils_failmesg_sccsid[] = "@(#)failmesg.c	1.2 9/4/95 (UKC)";
 
-#include <errno.h>
-#include <stdio.h>
-#include <string.h>
+#include <ifdefs.h>
 #include <local/ukcprog.h>
 
 #include "utils.h"
 
-#if !defined(__STDC__) || (defined(WANT_STRERROR) && !defined(strerror))
-extern char *sys_errlist[];
-extern int sys_nerr;
-#define strerror(n) \
-    (((n) >= 0 && (n) < sys_nerr) ? sys_errlist[n] : "unknown error")
-#endif
-
-
 void
 failmesg(mesg, what, path)
 const char *mesg, *what, *path;
@@ -43,3 +33,15 @@ get_errno_str()
 {
 	return (strerror (errno));
 }
+
+/* Create an 'strerror()' routine to work round a problem in libukcprog.a
+   with GCC 2.8.1 on SunOS 4.1.1 */
+#if !HAVE_STRERROR && defined(__STDC__)
+#undef strerror
+char *strerror(n)
+int n;
+{
+	return (((n) >= 0 && (n) < sys_nerr) ? sys_errlist[n] : "unknown error");
+}
+#endif
+
