@@ -14,11 +14,18 @@ char obj_sel_sccsid[] = "@(#)o_sel.c	1.18 21/10/94 (UKC)";
 
 #include <local/ukcprog.h>
 #include <mtrprog/alloc.h>
-#if defined (OS_BSD44) || defined (OS_LINUX)
-#include <sys/time.h>
+
+/* 'poll()' or 'select()' ? */
+#if HAVE_POLL
+#if HAVE_POLL_H
+#include <poll.h>
+#elif HAVE_SYS_POLL_H
+#include <sys/poll.h>
+#endif
+#elif HAVE_SELECT
 static struct timeval timeout = { 0L, 10L };
 #else
-#include <poll.h>
+error Neither poll nor select
 #endif
 
 #include "obj.h"
@@ -918,7 +925,7 @@ select_list(x_threshold, threshold_exceeded)
 	struct objst *obj, *newobj;
 	struct lptrst *lptr, *newlptr;
 	short orig_type;
-#if !(defined (OS_BSD44) || defined (OS_LINUX))
+#if HAVE_POLL
 	struct pollfd unused;
 #endif
 
@@ -1005,10 +1012,10 @@ select_list(x_threshold, threshold_exceeded)
 		      v_scroll(lptr->lp_ldepth);
 		      obj_y -= lptr->lp_ldepth;
 		      orig_y += lptr->lp_ldepth;
-#if defined (OS_BSD44) || defined (OS_LINUX)
-		      select(0, NULL, NULL, NULL, &timeout);
-#else
+#if HAVE_POLL
 		      poll(&unused, 0, 10);
+#else
+		      select(0, NULL, NULL, NULL, &timeout);
 #endif
 		    }
 		    else
@@ -1018,10 +1025,10 @@ select_list(x_threshold, threshold_exceeded)
 			v_scroll(-lptr->lp_ldepth);
 			obj_y += lptr->lp_ldepth;
 			orig_y -= lptr->lp_ldepth;
-#if defined (OS_BSD44) || defined (OS_LINUX)
-		        select(0, NULL, NULL, NULL, &timeout);
-#else
+#if HAVE_POLL
 			poll(&unused, 0, 10);
+#else
+		        select(0, NULL, NULL, NULL, &timeout);
 #endif
 		      }
 		  }
