@@ -116,6 +116,10 @@ typedef long fdmask_t;
 static long Wn_fd_mask = 0;
 static long User_fd_mask = 0;
 
+#ifndef __FDS_BITS
+#define __FDS_BITS(set)	((set)->fds_bits)
+#endif
+
 #ifdef SUNVIEW
 swin_t *_wn_Fdtab[MAX_FDS];
 static int Wakeup_fd = -1;
@@ -201,7 +205,7 @@ fdmask_t *p_resmask;
 		struct timeval tvbuf, *stm;
 
 		FD_ZERO(&mask);
-		mask.fds_bits[0] = win_mask | User_fd_mask;
+		__FDS_BITS(&mask)[0] = win_mask | User_fd_mask;
 #ifdef SUNVIEW
 		if (Wakeup_fd != -1)
 			FD_SET(Wakeup_fd, &mask);
@@ -238,12 +242,12 @@ fdmask_t *p_resmask;
 					return EV_OTHER;
 			}
 #endif
-			if (mask.fds_bits[0] & win_mask) {
-				*p_resmask = mask.fds_bits[0] & win_mask;
+			if (__FDS_BITS(&mask)[0] & win_mask) {
+				*p_resmask = __FDS_BITS(&mask)[0] & win_mask;
 				return EV_OTHER;
 			}
-			if (mask.fds_bits[0] & User_fd_mask) {
-				*p_resmask = mask.fds_bits[0] & User_fd_mask;
+			if (__FDS_BITS(&mask)[0] & User_fd_mask) {
+				*p_resmask = __FDS_BITS(&mask)[0] & User_fd_mask;
 				return EV_OTHER_INPUT;
 			}
 		}
