@@ -9,28 +9,23 @@
 
 char wn_wn_init_c_sccsid[] = "@(#)wn_init.c	1.53 25 May 1995 (UKC)";
 
+#include <mtrprog/ifdefs.h>
+
 #if defined(__svr4__) || defined(__SVR4)
 #define SVR4 1
 #endif
 
-#include <sys/types.h>
 #include <sys/file.h>
 #include <sys/param.h>		/* for MAXPATHLEN */
-#include <stdio.h>
 #include <ctype.h>
 #include <signal.h>
-#include <string.h>
 #include <stdlib.h>
 #include <fcntl.h>
 
-#ifdef __STDC__
-#include <unistd.h>
-#endif
-
 #include "wn.h"
 #include "wn_priv.h"
 
-#ifdef X11
+#if HAVE_X_WINDOWS
 #include <X11/Xresource.h>
 #include <X11/Xatom.h>
 #include <X11/Xos.h>
@@ -226,24 +221,114 @@ const char *name;
 {
 	Appclass = name;
 }
+#ifdef X11
+XrmDatabase resourcesDB;
+static  void wn_merge_databases()
+{
+   /*  The code to read the app-defaults database was originally
+    *  by Greg McFarlane <gregm@iname.com>
+    *
+    *  Enhanced by RCB following guidelines in "XLib Programming Manual"
+    *     by Adrian Nye, O'Rielly & Associates, 1990
+    *     ( Version 11, Release 4, Page 371)
+    */
+    XrmDatabase applicationDB, aux_applicationDB;
+    char path[MAXPATHLEN];
+    const char* xuserfilesearchpath = getenv("XUSERFILESEARCHPATH");
+    const char* xapplresdir = getenv("XAPPLRESDIR");
+    const char* xenvironment = getenv("XENVIRONMENT");
+    XrmDatabase serverDB = 0, homeDB = 0;
+
+    /*  Get the defaults from the standard location*/
+
+    sprintf(path, "/usr/lib/X11/app-defaults/%s", Appclass);
+    applicationDB = XrmGetFileDatabase(path);
+    XrmMergeDatabases(applicationDB,&resourcesDB);
+
+    /* Merge in any resource files in $XUSERFILESEARCHPATH
+     *  XLib Programming Manual does not say this is supposed to be : separated,
+     *  but the name suggests it
+     */
+    while ( xuserfilesearchpath && *xuserfilesearchpath )
+    {
+	const char* pathend = strchr(xuserfilesearchpath,':');
+	int len;
+	if ( pathend)
+	{
+	    len = pathend-xuserfilesearchpath;
+	    strncpy(path, xuserfilesearchpath,len);
+	    xuserfilesearchpath = pathend+1;
+	}
+	else
+	{
+	    strcpy(path, xuserfilesearchpath);
+	    len = strlen(path);
+	    xuserfilesearchpath = NULL;
+	}
+
+	path[len++] = '/';
+	strcpy(path+len,Appclass);
+	aux_applicationDB = XrmGetFileDatabase(path);
+	if ( aux_applicationDB)
+	   XrmMergeDatabases(aux_applicationDB,&resourcesDB);
+    }
+    /* Merge in any resource files in $XAPPLRESDIR
+    ** XLib Programming Manual suggests that at most one of $XUSERFILESEARCHPATH
+    ** and $XAPPLRESDIR should be defined.  What to do if both are defined
+    ** is not specified.
+    */
+    if ( xapplresdir && *xapplresdir )
+    {
+	sprintf(path,"%s/%s", xapplresdir, Appclass);
+	aux_applicationDB = XrmGetFileDatabase(path);
+	if ( aux_applicationDB)
+	   XrmMergeDatabases(aux_applicationDB,&resourcesDB);
+    }
+
+    /*  Merge in any resources set by xdrb */
+    if ( XResourceManagerString(wn__Dpy))
+	serverDB = XrmGetStringDatabase(XResourceManagerString(wn__Dpy));
+    else
+    {
+	const char* home = getenv("HOME");
+	if ( home && *home)
+	{
+	    sprintf(path,"%s/.Xdefaults", home);
+	    serverDB = XrmGetFileDatabase(path);
+	}
+    }
+    if ( serverDB)
+	XrmMergeDatabases(serverDB,&resourcesDB);
+
+    /* Merge XENVIRONMENT file */
+
+    if ( xenvironment && *xenvironment)
+    {
+	homeDB = XrmGetFileDatabase(xenvironment);
+    } else
+    {
+	const char* home = getenv("HOME");
+	if ( home && *home)
+	{
+	    int len;
+	    sprintf(path,"%s/.Xdefaults-", home);
+	    len = strlen(path);
+	    if (!gethostname(path+len, sizeof(path)-len-1))
+		homeDB = XrmGetFileDatabase(path);
+	}
+    }
+    if ( homeDB)
+	XrmMergeDatabases(homeDB,&resourcesDB);
+}
+#endif
 
 const char *
 wn_get_default(name)
 const char *name;
 {
 #ifdef X11
-	/*  The code to read the app-defaults database is
-	 *  by Greg McFarlane <gregm@otc.research.otca.oz.au>.
-	 */
-	const char *value;
-	static XrmDatabase applicationDB = NULL;
+	const char *value = NULL;
 
-	if (applicationDB == NULL) {
-		char path[MAXPATHLEN];
-
-		sprintf(path, "/usr/lib/X11/app-defaults/%s", Appclass);
-		applicationDB = XrmGetFileDatabase(path);
-	}
 
 	if (wn__Dpy == NULL)
 		return NULL;
@@ -253,7 +338,7 @@ const char *name;
 	if (value == NULL && Appclass != NULL && strcmp(Appclass, Appname) != 0)
 		value = XGetDefault(wn__Dpy, Appclass, name);
 
-	if (value == NULL && applicationDB != NULL) {
+	if (value == NULL && resourcesDB != NULL) {
 		char app_name[512], class_name[512];
 		XrmValue xrm_value;
 		char *str_type;
@@ -261,7 +346,7 @@ const char *name;
 		sprintf(app_name, "%s.%s", Appname, name);
 		sprintf(class_name, "%s.%s", Appclass, name);
 
-		if (XrmGetResource (applicationDB, app_name, class_name,
+		if (XrmGetResource (resourcesDB, app_name, class_name,
 							&str_type, &xrm_value))
 			value = xrm_value.addr;
 	}
@@ -384,6 +469,11 @@ const char **argv;
 #endif /* X11 */
 
 #ifdef X11
+	/*  Merge the various sources of X resources
+	*/
+	if (wn__Dpy)
+		wn_merge_databases();
+
 	/* XrmGetDefault("Font", "font"); */
 	if ((font = wn_get_default("Font")) != NULL) 
 		_wn_Sysfont_file = font;
