@@ -18,7 +18,9 @@ char ups_ao_elflib_c_sccsid[] = "@(#)ao_elflib.c	1.1 24/5/95 (UKC)";
 #include <sys/stat.h>
 #include <sys/param.h>                /* for MAXPATHLEN */
 #include <elf.h>
+#define FREEBSD_ELF 1
 #include <link.h>
+#undef FREEBSD_ELF
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
@@ -100,6 +102,10 @@ struct Libdep {
 };
 
 static Libdep *next_ld PROTO((Libdep *cur));
+static bool
+elf_get_dynamic_shlib_info PROTO((alloc_pool_t *ap, Libdep *ld, const char *textpath,
+			   taddr_t debug_vaddr,
+			   Libdep **last_child));
 
 static unsigned long Main_debug_vaddr = 0;
 
@@ -208,15 +214,21 @@ search_lib_path(const char *dirs, const char *seps, const char *name,
 static char *
 get_ld_path(Libdep *ld)
 {
-	char *path;
+	char *path, *ptr;
 	
 	if (strchr(ld->name, '/') != NULL)
 		return strsave(ld->name);
 
-	if (search_lib_path(ld->par->so->rpath, ":", ld->name, &path) ||
-	    search_lib_path(getenv("LD_LIBRARY_PATH"), ":;", ld->name, &path))
+	if (search_lib_path(ld->par->so->rpath, ":", ld->name, &path))
 		return path;
-	
+	if ((ptr = getenv ("LD_LIBRARY_PATH")) != NULL) {
+		if (search_lib_path (ptr, ":;", ld->name, &path))
+			return path;
+	} else {
+		if (search_lib_path ("/lib:/usr/lib", ":", ld->name, &path))
+			return path;
+	}
+
 	return strf("/usr/lib/%s", ld->name);
 }
 
@@ -520,20 +532,30 @@ elf_get_core_shlib_info(alloc_pool_t *ap, iproc_t *ip)
 		char libpath[1024]; /* TODO: use MAXPATHLEN or similar */
 		struct stat stbuf;
 
-		if (!core_dread(co, lmaddr, &lmap, sizeof(lmap)) ||
-		    !core_readstr(co, (taddr_t)lmap.l_name,
-				  libpath, sizeof(libpath))) {
+		if (!core_dread(co, lmaddr, &lmap, sizeof(lmap))) {
 			errf("Error reading lmap at address %lx in %s",
 			     lmaddr, path);
 			return FALSE;
 		}
-
 		/*  Skip the first entry - it refers to the executable file
 		 *  rather than a shared library.
 		 */
 		if (lmap.l_prev == NULL)
 			continue;
-		
+#ifdef OS_LINUX
+		if (lmap.l_phnum == 0) {
+			errf("Ignoring lmap at address %lx in %s",
+			     lmaddr, path);
+			continue;
+		}
+#endif
+		if (!core_readstr(co, (taddr_t)lmap.l_name,
+				  libpath, sizeof(libpath))) {
+			errf("Error reading lmap.l_name at address %lx in %s",
+			     lmap.l_name, path);
+			return FALSE;
+		}
+
 		if (stat(libpath, &stbuf) != 0) {
 			errf("Can't stat shared library %s: %s (ignored)",
 			     libpath, get_errno_str());
@@ -965,4 +987,11 @@ elf_restore_symtab_breakpoints()
   restore_cached_bpts();
 }
 
+void
+unload_shared_library_symtabs(xp)
+target_t *xp;
+{
+    /* Just to satisfy a link reference. */
+}
+
 #endif /* AO_ELF */
