@@ -12,7 +12,7 @@ char ups_ao_procfs_c_sccsid[] = "@(#)ao_procfs.c	1.3 20 Jun 1995 (UKC)";
 #include <mtrprog/ifdefs.h>
 #include "ao_ifdefs.h"
 
-#ifdef AO_USE_PROCFS
+#if AO_USE_PROCFS
 
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -71,7 +71,7 @@ struct Procfs_info {
 	bool at_pause;
 };
 
-#ifdef ARCH_SPARC
+#ifdef ARCH_SUN4
 #define IS_INTEGER_REG(regno)	((regno) < 32)
 #define FLOAT_REGNO(regno)	((regno) - 32)
 #endif
@@ -953,7 +953,7 @@ procfs_single_step(xp, sig)
 target_t *xp;
 int sig;
 {
-#ifdef ARCH_SPARC
+#ifdef ARCH_SUN4
 	Procfs_info *pi;
 	stopres_t stopres;
 
@@ -1079,7 +1079,7 @@ fpval_t *p_val;
  	    case sizeof(double):
  		memcpy(&p_val->d, addr, num_bytes);
  		break;
-#if (defined(__GNUC__) && !defined (OS_SUNOS_4)) || defined(HAVE_LONG_DOUBLE)
+#if HAVE_LONG_DOUBLE
  	    case sizeof(long double):
  		memcpy(&p_val->ld, addr, num_bytes);
  		break;
