@@ -14,18 +14,19 @@ char ups_st_shlib_c_sccsid[] = "@(#)ao_shlib.c	1.5 24 May 1995 (UKC)";
 
 #ifdef AO_TARGET
 
-#if defined(OS_SUNOS_4) || defined(OS_BSD44)
-#include <sys/types.h>
-#include <stdio.h>
+#if defined(AO_AOUT_SHLIBS)
 #include <stdlib.h>
-#include <string.h>
-#include <sys/wait.h>
 #include <fcntl.h>
+#if HAVE_A_OUT_H
 #include <a.out.h>
+#endif
+#if HAVE_LINK_H
+#define FREEBSD_AOUT 1
 #include <link.h>
+#undef FREEBSD_AOUT
+#endif
 
-#ifdef __STDC__
-#include <unistd.h>
+#if HAVE_SYS_STAT_H
 #include <sys/stat.h>
 #endif
 
@@ -133,6 +134,7 @@ symtab_t **p_next_st;
 	return TRUE;
 }
 
+
 /*  Dig out the list of loaded shared libraries and run time linked
  *  global addresses.  This basically involves trundling down linked	
  *  lists in the target via dread().  This must be called after the
@@ -260,6 +262,7 @@ shlib_t **p_shlibs;
 	return 0;
 }
 
+
 /*  Return a pointer to an array of strings which consists of the
  *  environment plus string s, which should be of the form
  *  "name=value".
@@ -711,6 +714,6 @@ target_t *xp;
 	ip->ip_shlib_symtabs = NULL;
 }
 
-#endif /* OS_SUNOS_4 or OS_BSD44 */
+#endif /* AO_AOUT_SHLIBS */
 
 #endif /* AO_TARGET */
