@@ -407,7 +407,7 @@ target_t *xp;
 #ifdef ARCH_CLIPPER
 	must_find_fp = FALSE;
 #endif
-	for (stk = last = NULL; fp != NULL; last = stk) {
+	for (stk = last = NULL; fp != (taddr_t)0; last = stk) {
 		fil_t *fil;
 		int lnum;
 		normal_frame = TRUE;
@@ -429,7 +429,7 @@ target_t *xp;
 #endif
 #ifdef ARCH_LINUX386
 		if (strcmp(f->fu_demangled_name, "_entry") == 0) {
-			fp = NULL;
+			fp = (taddr_t)0;
 			break;
 		}
 #endif
@@ -708,7 +708,7 @@ target_t *xp;
 		}
 #endif /* ARCH_VAX */
 	}
-	if (fp != NULL && stk != NULL)
+	if ((fp != (taddr_t)0) && (stk != NULL))
 		stk->stk_bad = TRUE;
 
 	return discard_junk_frames(xp, stk);
