@@ -97,7 +97,7 @@ block_t *hdrbl, *bl;
 	}
 }
 
-#ifdef OS_SUNOS
+#if defined(OS_SUNOS) || defined(OS_LINUX)
 static stf_t *
 id_to_hdrstf(stf, id, symno)
 stf_t *stf;
@@ -128,7 +128,7 @@ int symno;
 static
 void 
 get_fi_compiler(fil)
-  fil_t *fil;
+fil_t *fil;
 {
 
   stf_t *stf, *stf_next;
@@ -203,8 +203,8 @@ get_fi_compiler(fil)
   }
 
   stf->stf_compiler_type =
-    (stf->stf_language == LANG_C || stf->stf_language == LANG_CC) ?
-      CT_CC : CT_F77;
+    (stf->stf_language == LANG_C || stf->stf_language == LANG_CC)
+      ? CT_CC : (stf->stf_language == LANG_UNKNOWN) ? CT_UNKNOWN : CT_F77;
 
   /*  old_cursor = wn_get_window_cursor(WN_STDWIN);*/
   /*  set_bm_cursor(WN_STDWIN, CU_WAIT);*/
@@ -381,7 +381,7 @@ bool is_header;
 			break;
 		
 		getsym(symrec.symio, symrec.symno, &nm);
-#ifdef OS_SUNOS
+#if defined(OS_SUNOS) || defined(OS_LINUX)
 		if ((nm.n_type == N_BINCL || nm.n_type == N_EXCL)
 							   && nm.n_value != 0) {
 			stf_t *hdrstf;
@@ -507,6 +507,8 @@ bool is_header;
 			
 	}
 
+	wrapup_types(stf);
+
 	if (!is_header) {
 		int i;
 		
@@ -707,7 +709,7 @@ fil_t *fil;
 		  continue;
 
 		parse_name(&symrec, &s, (alloc_pool_t *)NULL, 1,
-			   stf->stf_compiler_type); /* RGA */
+			   stf->stf_compiler_type, IS_FORTRAN(stf->stf_language));
 
 		/*  Ignore symbols with funny characters in their names.
 		 *  For normally named symbols, parse_name will have
@@ -735,10 +737,13 @@ fil_t *fil;
 		   Is not a problem with other compilers.
 		   */
 
-		if (nm.n_value != 0 &&
-		    !(stf->stf_compiler_type == CT_CC &&
+		if (nm.n_value != 0
+#ifdef AO_ELF
+		    && !(stf->stf_compiler_type == CT_CC &&
 		      (class == CL_EXT || class == CL_STAT) &&
-		      fil->fi_language == LANG_C))
+		      fil->fi_language == LANG_C)
+#endif
+		)
 			addr = (taddr_t)nm.n_value + ast->st_base_address;
 		else
 			addr = lookup_global_addr(st, sn->sn_symtab_name);
@@ -760,8 +765,17 @@ fil_t *fil;
 	fil->fi_flags |= FI_DONE_VARS;
 	errf("\bReading symbols of `%s'... done", fil->fi_name_only);
 	errf_set_ofunc(oldf);
-	if (target_menu_search_disabled(0, 0) == FALSE)
-	  indicate_target_menu_search(0);
+        if (target_menu_search_disabled(0, 0) == FALSE)
+        {
+		bool stop;
+
+		stop = stop_pressed(0, 0);
+		indicate_target_menu_search(0);
+		if (stop)
+		    stop_pressed(1, 0);
+				/* set it back again to break out of reading */
+                                /* more source file symbols */
+        }
 	wn_define_cursor(WN_STDWIN, old_cursor);
 
 	return fil->fi_block->bl_vars;
@@ -1077,7 +1091,7 @@ func_t *f;
 
 		case N_LBRAC:
 			if (!seen_lbrac) {
-#if defined(OS_SUNOS_5) || defined(OS_LINUX)
+#ifdef AO_ELF
 				sane_bracs = nm.n_desc != 0;
 #else
 				sane_bracs = TRUE;
@@ -1251,8 +1265,9 @@ func_t *f;
 					  backup_lnum_to_curly(f, f->fu_fil, next_lnum - 1);
 
 			break;
-		case N_LSYM:
+
 		case N_PSYM:
+		case N_LSYM:
 		case N_STSYM:
 		case N_RSYM:
 		case N_FUN:
@@ -1278,17 +1293,18 @@ func_t *f;
 			  while (*s == '.')
 			    ++s;
 
-			name = parse_name
-			  (&symrec, &s, ap, nm.n_type == N_FUN ? 2 : 1,
-			   stf->stf_compiler_type); /* RGA */
+			name = parse_name (&symrec, &s, ap,
+			                   nm.n_type == N_FUN ? 2 : 1,
+					   stf->stf_compiler_type,
+					   IS_FORTRAN(stf->stf_language));
 			if (*s == ' ') /* RGA for C++  */
 				break;
 			field_scheck(&symrec, &s, ':');
 			type = Class(stf, &symrec, &s, &class);
 
-			if (class == CL_FUNC &&
-			    symrec.symno == AO_FSYMDATA(f)->fs_symno &&
-			    strcmp(name, f->fu_demangled_name) == 0) {
+			if ((class == CL_FUNC) &&
+			    (symrec.symno == AO_FSYMDATA(f)->fs_symno) &&
+			    (strcmp(name, f->fu_demangled_name) == 0)) {
 				f->fu_type = type;
 				break;
 			}
@@ -1337,7 +1353,7 @@ func_t *f;
 			 *  block (where parameters occur) discard this variable
 			 *  if we already have one with same name and address.
 			 */
-			if (level == 0 && class == CL_AUTO) {
+			if (level == 0 && (class == CL_AUTO || class == CL_ARG)) {
 				for (v = *p_varlist; v != NULL;
 							      v = v->va_next) {
 					if (v->va_addr == nm.n_value &&
@@ -1429,7 +1445,7 @@ func_t *f;
 			v->va_next = *p_varlist;
 			*p_varlist = v;
 
-#if defined(IS_BIG_ENDIAN) && defined(FIX_SHORT_PARAMS)
+#if IS_BIG_ENDIAN && defined(FIX_SHORT_PARAMS)
 			if (v->va_class == CL_ARG) {
 				switch (v->va_type->ty_code) {
 				case TY_USHORT:
@@ -1470,6 +1486,10 @@ func_t *f;
 			    type != NULL && /* RGA added for gcc 2.8.0 */
 			    type->ty_code != TY_FLOAT &&
 			    type->ty_code != TY_DOUBLE &&
+#if HAVE_LONG_LONG
+			    type->ty_code != TY_LONGLONG &&	/* RCB */
+			    type->ty_code != TY_ULONGLONG &&	/* RCB */
+#endif
 		            typesize(type) > sizeof(long)) {
 				type = ci_make_type(ap, DT_PTR_TO);
 				type->ty_qualifiers = 0;
@@ -1671,7 +1691,7 @@ ao_get_fu_lnos(f)
 
     if ( lno && addr < min_addr)
       continue;
-               
+ 
     /*              if (compiler == CT_GNU_CC && fil != f->fu_fil)*/
     /*                      continue;*/
              
@@ -1810,14 +1830,14 @@ Compiler_type compiler;
 {
   stf_t *stf;
   static Compiler_type likely = CT_UNKNOWN;
-  static compiler_found_once = FALSE;
+  static bool compiler_found_once = FALSE;
 
   if (compiler_found == TRUE)
   {
     compiler_found_once = TRUE;
     if (likely == CT_UNKNOWN)
       likely = compiler;
-    return TRUE;
+    return likely;
   }
 
   if (compiler_found_once == TRUE || fil == NULL)
@@ -1831,6 +1851,7 @@ Compiler_type compiler;
   }
 
   stf = AO_FIDATA(fil);
-  likely = stf->stf_compiler_type;
+  if (stf->stf_compiler_type != CT_UNKNOWN)  /* RCB */
+    likely = stf->stf_compiler_type;
   return likely;
 }
