@@ -173,8 +173,8 @@ int ch;
 {
 	if (**p_s != ch)
 	{
-	  /*		panic("syntax error in symtab");*/
-		errf("syntax error in symtab");
+		errf("syntax error in symtab : got '%c' expected '%c'",
+		     **p_s, (char)ch);
 		field_scheck(sr, p_s, ch);
 	}
 	bump_str(sr, p_s);
@@ -213,8 +213,7 @@ static void
 notimp(s)
 const char *s;
 {
-	errf(strf("%s not implemented", s));
-	/* RGA	panic(strf("%s not implemented", s));*/
+	errf("%s not implemented", s);
 }
 
 /*  Return the symbol number for the definition of type number tnum
@@ -233,11 +232,11 @@ Ftype **p_ft;
 	bool got_match;
 	ao_stdata_t *ast;
 	Symrec symrec;
-	
+
 	ast = AO_STDATA(stf->stf_symtab);
 
 	got_match = FALSE;
-	
+
 	for (symno = next_unmarked_sym(symio, min);
 	     symno <= max;
 	     symno = next_unmarked_sym(symio, symno + 1)) {
@@ -245,7 +244,7 @@ Ftype **p_ft;
 		const char *s, *base, *pos, *end;
 		char *s2;
 		int len;
-	
+
 		getsym(symio, symno, &nm);
 
 		switch (nm.n_type) {
@@ -381,7 +380,7 @@ bool is_undef_tag;
 	lookup_ftype(stf, tnum, &ft, &prevft);
 
 	already_noted = ft != NULL;
-	
+
 	if (!already_noted)
 		ft = add_ftype_to_list(stf, tnum, FALSE, prevft);
 
@@ -405,9 +404,9 @@ bool have_type;
 Ftype *prevft;
 {
 	Ftype *ft;
-	
+
 	ft = (Ftype *)alloc(stf->stf_symtab->st_apool, sizeof(Ftype));
-	
+
 	ft->tnum = tnum;
 	ft->have_type = FALSE;
 
@@ -425,7 +424,7 @@ Ftype *prevft;
 
 	if (ft->next != NULL && ft->next->tnum >= tnum)
 		panic("next tnum order botch in aftl");
-	
+
 	return ft;
 }
 
@@ -444,7 +443,7 @@ int min, max;
 	char *end, *s2;
 	type_t *type_id;
 	size_t len;
-	
+
 	if (ft != NULL) {
 		if (ft->have_type)
 			panic("have_type botch in gt");
@@ -475,7 +474,7 @@ int min, max;
 		 */
 		return NULL;
 	}
-	
+
 	symrec.symio = symio;
 	symrec.symno = ft->u.defpos.symno;
 	s = symstring(symio, symrec.symno);
@@ -508,7 +507,7 @@ int min, max;
 	  }
 	}
 	s += ft->u.defpos.offset;
-	
+
 	type_id = TypeId(stf, &symrec, &s, TRUE, *(s - 1));
 	if (s2)
 	  free(s2);
@@ -524,7 +523,7 @@ Ftype **p_ft, **p_prevft;
 	Ftype *ft, *prevft;
 
 	prevft = NULL;
-	
+
 	for (ft = stf->stf_ftypes; ft != NULL; ft = ft->next) {
 		if (ft->tnum == tnum)
 			break;
@@ -543,6 +542,38 @@ Ftype **p_ft, **p_prevft;
 		*p_prevft = prevft;
 }
 
+static void
+patch_ftypes(stf)
+stf_t *stf;
+{
+   if ( stf->stf_flags & STF_NEED_PATCH)
+   {
+	Ftype *ft;
+	/*
+	**   Search for any types marked "same as" during the parse
+	**   and copy the true definition.
+	*/
+	for (ft = stf->stf_ftypes; ft != NULL; ft = ft->next) {
+		if ( ft->have_type && ft->u.type.ty_code == PI_SAME_AS)
+		{
+			type_t* type = ft->u.type.ty_base;
+			while ( type->ty_code == PI_SAME_AS)
+				type = type->ty_base;
+			ft->u.type = *type;
+		}
+	}
+	stf->stf_flags &= ~STF_NEED_PATCH;
+   }
+}
+
+void wrapup_types(stf)
+stf_t *stf;
+{
+	int i;
+	for ( i = 0; i < stf->stf_mapsize; i++)
+	    patch_ftypes(stf->stf_fmap[i]->hf_stf);
+}
+
 static type_t *
 tnum_to_type(stf, sr, symio, tnum, have_undef_tag)
 stf_t *stf;
@@ -553,23 +584,27 @@ bool have_undef_tag;
 {
 	Ftype *ft;
 	type_t *type;
-	
+
 	lookup_ftype(stf, tnum, &ft, (Ftype **)NULL);
-	
+
 	if (ft != NULL && ft->have_type) {
 		type = &ft->u.type;
 	}
 	else {
 		stf_t *search_stf;
-#ifdef OS_SUNOS_5
+#ifdef AO_ELF
 		search_stf = stf->stf_fmap[0]->hf_stf;
 #else
-		search_stf = stf;
+		/* RCB: gcc version 2.8 or later under sun 4 */
+		if (stf->stf_compiler_type == CT_GNU_CC)
+		    search_stf = stf->stf_fmap[0]->hf_stf;
+		else
+		    search_stf = stf;
 #endif
 		type = get_type(stf, sr, symio, ft, tnum, have_undef_tag,
 				stf->stf_symno, search_stf->stf_symlim - 1);
 	}
-	
+
 	return type;
 }
 
@@ -592,7 +627,7 @@ int tnum;
 	else {
 		ft = add_ftype_to_list(stf, tnum, TRUE, prevft);
 	}
-	
+
 	ci_init_type(&ft->u.type, TY_NOTYPE);
 	ft->have_type = TRUE;
 
@@ -642,7 +677,7 @@ class_t *p_class;
 		notimp("Constants");
 		class = CL_NOCLASS;	/* to satisfy gcc */
 		break;
-	
+
 	/* Variable */
 	case '(':
 	case '0':
@@ -681,7 +716,7 @@ class_t *p_class;
 	case 'G':
 		class = CL_EXT;
 		break;
-	
+
 	/*  Procedure
 	 *
 	 *  DEV: 'P' should be in this group according to the grammar
@@ -702,7 +737,7 @@ class_t *p_class;
 		notimp("Internal functions");
 		class = CL_NOCLASS;	/* to satisfy gcc */
 		break;
-	
+
 	/* Parameter
 	 *
 	 *  DEV: the grammar says 'P' introduces a global procedure,
@@ -716,7 +751,7 @@ class_t *p_class;
 	case 'v':
 		class = CL_REF;
 		break;
-	
+
 	/* Namedtype */
 	case 't':
 		class = CL_TYPEDEF;
@@ -733,7 +768,7 @@ class_t *p_class;
 
 		class = CL_TAGNAME;
 		break;
-	
+
 	/* 'X' ExportInfo */
 	case 'X':
 		/*  This has been seen in a SunOS 4.0 f77 a.out file.
@@ -743,38 +778,42 @@ class_t *p_class;
 		 */
 		class = CL_NOCLASS; 
 		break;
-	
+
 	case 'Y':		/* RGA added for SC4.2 */
 		class = CL_NOCLASS;
 		rtype = NULL;
 		break;
-	
+
 	default:
-/*		panic("unknown type class letter in symbol table");*/
 		errf("\bunknown type class letter in symbol table");
 		class = CL_NOCLASS; /* to satisfy gcc */
 	}
-	
+
 	prior_chr = *s == '\\' ? *(s-1) : *s;
 	bump_str(sr, &s);
 	if (prior_chr != 'Y')
-	  rtype = TypeId(stf, sr, &s, TRUE, prior_chr);
-	if (rtype)
-	{
-	if ( (rtype[0].ty_code == TY_STRUCT || rtype[0].ty_code == TY_UNION)
-	    && class == CL_ARG )
-	    class = CL_REF ; 
+		rtype = TypeId(stf, sr, &s, TRUE, prior_chr);
+	if (rtype == NULL)
+		return rtype;
+
+	/*  (IDE) Was this to fix a bug ?
+	 *  Modern compilers support passing struct/union by value.
+	 *  Still works on Solaris 2 so keep for OS_SUNOS.
+	 */
+#ifdef OS_SUNOS
+	if ((class == CL_ARG) && (rtype->ty_code == TY_STRUCT || rtype->ty_code == TY_UNION))
+		class = CL_REF; 
+#endif
 	*p_s = s;
 
 	/*  The basic types (int, char etc) get entries in the symbol
 	 *  table that look like user typedefs.  We don't want to
 	 *  clutter up the typedef lists with these entries.
 	 */
-	if (class == CL_TYPEDEF && rtype && rtype->ty_typedef == NULL)
+	if ((class == CL_TYPEDEF) && rtype && (rtype->ty_typedef == NULL))
 		*p_class = CL_NOCLASS;
 	else
 		*p_class = class;
-      }
 	return rtype;
 }
 
@@ -787,7 +826,7 @@ Symrec *sr;
 const char **p_s;
 {
 	int res;
-	
+
 	if (!parse_number(stf, sr, p_s, &res))
 		panic("bad number in parse_num");
 
@@ -807,13 +846,13 @@ const char **p_s;
 	bool neg;
 
 	s = *p_s;
-	
+
 	neg = *s == '-';
 	if (neg)
 	        bump_str(sr, &s);
-	
+
 	num = parse_num(stf, sr, &s);
-	
+
 	*p_s = s;
 	return neg ? -num : num;
 }
@@ -874,11 +913,16 @@ type_t *type;
 		{ 0,		255,		TY_UCHAR,	sizeof(char)  },
 		{ 0,		65535,		TY_USHORT,	sizeof(short) },
 		{ 0,		-1,		TY_UINT,	sizeof(long)  },
-		{ SR_MINUS_2E63, SR_2E63_MINUS_1, TY_LONGLONG,	2*sizeof(long)},
+#if HAVE_LONG_LONG
+		{ SR_MINUS_2E63,SR_2E63_MINUS_1,TY_LONGLONG,	sizeof(long long)},
+		{ 0,		SR_2E64_MINUS_1,TY_ULONGLONG,	sizeof(long long)},
+#else
+		{ SR_MINUS_2E63,SR_2E63_MINUS_1,TY_LONGLONG,	2*sizeof(long)},
 		{ 0,		SR_2E64_MINUS_1,TY_ULONGLONG,	2*sizeof(long)},
+#endif
 		{ 4,		0,		TY_FLOAT,	sizeof(float) },
 		{ 8,		0,		TY_DOUBLE,	sizeof(double)},
-#if (defined(__GNUC__) && !defined (OS_SUNOS_4)) || defined(HAVE_LONG_DOUBLE)
+#if HAVE_LONG_DOUBLE
  		{ 12,		0,		TY_LONGDOUBLE,	sizeof(long double)},
  		{ 16,		0,		TY_LONGDOUBLE,	sizeof(long double)},
 #endif
@@ -909,7 +953,7 @@ type_t *type;
 
 	type->ty_base = NULL;
 	type->ty_typedef = NULL;
-	
+
 	if (IS_FORTRAN(language)) {
 		f77_typetab_t *ft;
 
@@ -931,10 +975,12 @@ type_t *type;
 				return;
 			}
 		}
-		panic("unknown f77 basic type line in symtab");
+		if (stf->stf_compiler_type != CT_GNU_CC)
+			panic("unknown f77 basic type line in symtab");
 	}
 
-	if (!(language == LANG_C || language == LANG_CC))
+	if ((language != LANG_C) && (language != LANG_CC)
+			&& (stf->stf_compiler_type != CT_GNU_CC))
 		panic("unknown lang in gbt");
 
 	type->ty_name = make_typename(st->st_apool, line, len);
@@ -977,164 +1023,166 @@ const char **p_s;
 bool eval;
 int prior_chr;
 {
-	stf_t *nstf;
-	typecode_t utypecode;
-	int fnum, tnum, save_symno;
-	bool have_typenum, is_named_type, is_typedefed;
-	Compiler_type compiler;
-	const char *s, *tag;
-	alloc_pool_t *ap;
-	type_t *rtype;
+    stf_t *nstf;
+    typecode_t utypecode;
+    int fnum, tnum, save_symno;
+    bool have_typenum, is_named_type, is_typedefed;
+    Compiler_type compiler;
+    const char *s, *tag;
+    alloc_pool_t *ap;
+    type_t *rtype;
+    bool is_fortran;
 
-	s = *p_s;
-	ap = stf->stf_symtab->st_apool;
+    s = *p_s;
+    ap = stf->stf_symtab->st_apool;
 
 /*	is_named_type = s[-1] == 'T';*/
 /*	is_typedefed = s[-1] == 't';*/
-	is_named_type = prior_chr == 'T';
-	is_typedefed = prior_chr == 't';
-	have_typenum = isdigit(*s) || *s == '(';
-	compiler =  stf->stf_compiler_type;
+    is_named_type = prior_chr == 'T';
+    is_typedefed = prior_chr == 't';
+    have_typenum = isdigit(*s) || *s == '(';
+    compiler = stf->stf_compiler_type;
+    is_fortran = IS_FORTRAN(stf->stf_language);
 
-	if (have_typenum) {
-		Typenum(stf, sr, FALSE, &s, &fnum, &tnum);
-		if (fnum >= stf->stf_mapsize)
-		{		/* RGA for yacc garbage */
-/*		  panic("fnum out of range in TypeId");*/
-		  rtype = NULL;
-		  nstf = stf;
-		  tnum = -1;
-		  utypecode = TY_NOTYPE;		/* to satisfy gcc */
-		  tag = 0;			/* to satisfy gcc */
-		  *p_s = s;
-		  return rtype;
-		}
-		nstf = stf->stf_fmap[fnum]->hf_stf;
+    if (have_typenum) {
+	Typenum(stf, sr, FALSE, &s, &fnum, &tnum);
+	if (fnum >= stf->stf_mapsize)
+	{
+	    /* RGA for yacc garbage */
+	    errf ("fnum %d out of range %d in TypeId", fnum, stf->stf_mapsize);
+	    rtype = NULL;
+	    nstf = stf;
+	    tnum = -1;
+	    utypecode = TY_NOTYPE;
+	    tag = 0;
+	    *p_s = s;
+	    return rtype;
+	}
+	nstf = stf->stf_fmap[fnum]->hf_stf;
 
-		if (*s == '=' && s[1] == 'x' &&
-		    char_to_utypecode(s[2], &utypecode)) {
-		        bump_str(sr, &s);
-		        bump_str(sr, &s);
-		        bump_str(sr, &s);
-			tag = parse_name(sr, &s, ap, 0, compiler); /* RGA */
-			if (stf->stf_compiler_type == CT_GNU_CC)
-			  field_scheck(sr, &s, ':');
-			else
-			  scheck(sr, &s, ':');
-		}
-		else {
-			utypecode = TY_INT_ASSUMED;
-			tag = NULL;
-		}
-		rtype = lookup_tnum(nstf, tnum);
+	if (*s == '=' && s[1] == 'x' && char_to_utypecode(s[2], &utypecode)) {
+	    bump_str(sr, &s);
+	    bump_str(sr, &s);
+	    bump_str(sr, &s);
+	    tag = parse_name(sr, &s, ap, 0, compiler, is_fortran);
+	    if (stf->stf_compiler_type == CT_GNU_CC)
+	        field_scheck(sr, &s, ':');
+	    else
+	        scheck(sr, &s, ':');
 	}
 	else {
+	    utypecode = TY_INT_ASSUMED;
+	    tag = NULL;
+	}
+	rtype = lookup_tnum(nstf, tnum);
+    }
+    else {
+	rtype = NULL;
+	nstf = stf;
+	tnum = -1;
+	utypecode = TY_NOTYPE;		/* to satisfy gcc */
+	tag = 0;			/* to satisfy gcc */
+    }
+
+    if (is_named_type && rtype != NULL)
+	return rtype;
+    save_symno = sr->symno;
+
+    if (have_typenum) {
+	if (*s == '=') {
+	    bump_str(sr, &s);
+	    
+	    if (*s == '@' || *s == '#')
+	        bump_str(sr, &s);
+
+	    if (rtype == NULL)
+		rtype = TypeDef(nstf, sr, &s, tnum, eval);
+	    else if (!is_typedefed)
+		(void) TypeDef(nstf, sr, &s, tnum, FALSE);
+	}
+	else if (eval || !rtype)  /*RGA*/ {
+	    rtype = tnum_to_type(nstf, sr, sr->symio, tnum, tag != NULL);
+		
+	    if (rtype == NULL) {
+		Ftype *ft;
+
+		ft = insert_ftype(nstf, tnum);
+		rtype = &ft->u.type;
+		make_undef_type(nstf, tag, utypecode, rtype);
+	    }
+	}
+    }
+    else {
+	rtype = TypeDef(nstf, sr, &s, -1, eval);
+    }
+
+    *p_s = s;
+
+    if (!eval)
+	return NULL;
+
+    while ( rtype->ty_code == PI_SAME_AS)
+	rtype = rtype->ty_base;
+
+    if (rtype->ty_typedef == &Is_basic_type) {
+	is_typedefed = FALSE;
+	rtype->ty_typedef = NULL;
+    }
+
+    if (is_named_type || is_typedefed) {
+	const char *name;
+
+	name = symstring(sr->symio, save_symno);
+
+	if (is_typedefed) {
+	  if (stf->stf_language == LANG_CC &&
+	      (name[0] != ':' && name[0] != '?' &&
+	       !isalpha(name[0]) && name[0] != '_' &&
+	       name[0] != '$' && name[0] != '.'))
+	  {
+	      /* RGA added return of dummy type for C++ */
+	      rtype = NULL;
+	      nstf = stf;
+	      tnum = -1;
+	      utypecode = TY_NOTYPE;	
+	      tag = 0;
+	      *p_s = s;
+	      return rtype;
+	  }
+	  else
+		ci_make_typedef (ap,
+			 parse_name (sr, &name, ap, 0, compiler, is_fortran),
+			 rtype); /* RGA */
+	}
+	else {
+	    switch(rtype->ty_code) {
+	    case TY_U_STRUCT:
+	    case TY_U_UNION:
+	    case TY_U_ENUM:
+	    case TY_STRUCT:
+	    case TY_UNION:
+	    case TY_ENUM:
+		break;
+	    default:
+		/* RGA added return of dummy type for C++ */
 		rtype = NULL;
 		nstf = stf;
 		tnum = -1;
-		utypecode = TY_NOTYPE;		/* to satisfy gcc */
-		tag = 0;			/* to satisfy gcc */
-	}
-
-	if (is_named_type && rtype != NULL)
+		utypecode = TY_NOTYPE;	
+		tag = 0;
+		*p_s = s;
 		return rtype;
-	save_symno = sr->symno;
+	    } /* switch */
 
-	if (have_typenum) {
-		if (*s == '=') {
-		        bump_str(sr, &s);
-			
-			if (*s == '@' || *s == '#')
-			  bump_str(sr, &s);
-/*	RGA			notimp("Type attributes");*/
-			
-			if (rtype == NULL)
-				rtype = TypeDef(nstf, sr, &s, tnum, eval);
-			else if (!is_typedefed)
-				(void) TypeDef(nstf, sr, &s, tnum, FALSE);
-		}
-		else if (eval || !rtype)  /*RGA*/ {
-			rtype = tnum_to_type(nstf, sr, sr->symio, tnum,
-					     tag != NULL);
-			
-			if (rtype == NULL) {
-				Ftype *ft;
-
-				ft = insert_ftype(nstf, tnum);
-				rtype = &ft->u.type;
-				make_undef_type(nstf, tag, utypecode, rtype);
-			}
-		}
+	    tag = parse_name(sr, &name, ap, 0, compiler, is_fortran); /* RGA */
+	    if (*tag == '\0')
+		tag = NULL;
+		
+	    rtype->ty_aggr_or_enum->ae_tag = tag;
 	}
-	else {
-		rtype = TypeDef(nstf, sr, &s, -1, eval);
-	}
-	
-	*p_s = s;
+    }
 
-	if (!eval)
-		return NULL;
-	
-	if (rtype->ty_typedef == &Is_basic_type) {
-		is_typedefed = FALSE;
-		rtype->ty_typedef = NULL;
-	}
-
-	if (is_named_type || is_typedefed) {
-		const char *name;
-
-		name = symstring(sr->symio, save_symno);
-
-		if (is_typedefed) {
-		  if (stf->stf_language == LANG_CC &&
-		      (name[0] != ':' && name[0] != '?' &&
-		       !isalpha(name[0]) && name[0] != '_' &&
-		       name[0] != '$' && name[0] != '.'))
-		  {
-		    /* RGA added return of dummy type for C++ */
-		    rtype = NULL;
-		    nstf = stf;
-		    tnum = -1;
-		    utypecode = TY_NOTYPE;	
-		    tag = 0;
-		    *p_s = s;
-		    return rtype;
-		  }
-		  else
-			ci_make_typedef
-			  (ap, parse_name
-			   (sr, &name, ap, 0, compiler), rtype); /* RGA */
-		}
-		else {
-			switch(rtype->ty_code) {
-			case TY_U_STRUCT:
-			case TY_U_UNION:
-			case TY_U_ENUM:
-			case TY_STRUCT:
-			case TY_UNION:
-			case TY_ENUM:
-				break;
-			default:
-				/* RGA added return of dummy type for C++ */
-/*				panic("bad type code in TypeId");*/
-				rtype = NULL;
-				nstf = stf;
-				tnum = -1;
-				utypecode = TY_NOTYPE;	
-				tag = 0;
-				*p_s = s;
-				return rtype;
-			}
-
-			tag = parse_name(sr, &name, ap, 0, compiler); /* RGA */
-			if (*tag == '\0')
-				tag = NULL;
-			
-			rtype->ty_aggr_or_enum->ae_tag = tag;
-		}
-	}
-
-	return rtype;
+    return rtype;
 }
 
 static void
@@ -1180,11 +1228,11 @@ type_t *type;
 	int width, offset, nbits;
 	const char *typename;
 	size_t len;
-	
+
 	s = *p_s;
 
 	is_signed = *s == 's';
-	
+
 	if (!is_signed && *s != 'u')
 		panic("unknown value for signed flag in gbi");
 	bump_str((Symrec*)sr, &s);
@@ -1234,8 +1282,8 @@ type_t *type;
 		typecode = TY_NOTYPE; /* to satisfy gcc */
 	}
 
-	
-	
+
+
 	get_typename_str(sr, &typename, &len);
 	type->ty_name = make_typename(ap, typename, len);
 
@@ -1246,7 +1294,7 @@ type_t *type;
 
 	type->ty_size = width;
 	type->ty_code = typecode;
-	
+
 	*p_s = s;
 }
 
@@ -1284,7 +1332,7 @@ type_t *type;
 
 	if (type->ty_code == TY_NOTYPE)
 		panic("unknown fp type in gbf");
-	
+
 	type->ty_size = nbytes;
 
 	get_typename_str(sr, &typename, &len);
@@ -1303,13 +1351,13 @@ size_t *p_len;
 
 	if ((*p_line = symstring(sr->symio, sr->symno)) == NULL)
 		panic("NULL line in gbt");
-	
+
 	if ((cptr = strchr(*p_line, ':')) == NULL)
 		panic("missing ':' in gbt");
-	
+
 	*p_len = cptr - *p_line;
 }
-	
+
 static const char *
 make_typename(ap, line, len)
 alloc_pool_t *ap;
@@ -1380,12 +1428,14 @@ int tnum, eval;
 	char prior_chr;
 	alloc_pool_t *ap;
 	Compiler_type compiler;
+	bool is_fortran;
 
 	s = *p_s;
 	ae = NULL;
 	ap = stf->stf_symtab->st_apool;
 /* RGA */
 	compiler = stf->stf_compiler_type;
+	is_fortran = IS_FORTRAN(stf->stf_language);
 
 	if (stf->stf_language == LANG_CC)
 	{
@@ -1416,7 +1466,7 @@ int tnum, eval;
 	  return TypeId(stf, sr, p_s, eval, prior_chr);
 	}
 #endif /* AO_ELF */
-	
+
 	if (tnum == -1) {
 		ft = (Ftype *)alloc(ap, sizeof(Ftype));
 		ft->tnum = -1;
@@ -1464,15 +1514,31 @@ int tnum, eval;
 				   sr, (dim_t *)NULL, &ft->u.type);
 		  }
 		  else
-		    ft->u.type = *rtype;
-/*		  if (rtype && const_type)
 		  {
-		    char *const_name;
+		    /*  RCB: This causes problems when *rtype itself is
+		    **       not set up yet.  For example, if rtype is a
+		    **	     pointer with ty_base still NULL, ty_base in
+		    **	     the copy never gets set up.
+		    **    ft->u.type = *rtype;
+		    */
+		    if ( rtype != &ft->u.type)
+		    {
+			ft->u.type.ty_code = PI_SAME_AS;
+			ft->u.type.ty_base = rtype;
+			stf->stf_flags |= STF_NEED_PATCH;
+		    }
+		  }
 
-		    const_name = e_malloc(strlen((ft->u.type).ty_name) + 7);
-		    sprintf(const_name, "const %s", (ft->u.type).ty_name);
-		    (ft->u.type).ty_name = const_name;
-		  }*/
+/*
+ *		if (rtype && const_type)
+ *		  {
+ *		    char *const_name;
+ *
+ *		    const_name = e_malloc(strlen((ft->u.type).ty_name) + 7);
+ *		    sprintf(const_name, "const %s", (ft->u.type).ty_name);
+ *		    (ft->u.type).ty_name = const_name;
+ *		  }
+ */
 		}
 		else
 		{
@@ -1517,7 +1583,7 @@ int tnum, eval;
 		scheck(sr, &s, ';');
 		ft->u.type.ty_base = TypeId(stf, sr, &s, eval, prior_chr);
 		break;
-	
+
 	/*  ProcedureType.
 	 *  We only implement the < 'f' TypeId ';' > form.
 	 *  Sun symbol tables seem to omit the ';'.
@@ -1530,7 +1596,7 @@ int tnum, eval;
 							FALSE);
 		ft->u.type.ty_base = TypeId(stf, sr, &s, eval, prior_chr);
 		break;
-	
+
 	/*  Record.
 	 */
 	case 'Y':		/* RGA */
@@ -1571,7 +1637,7 @@ int tnum, eval;
 
 		}
 		break;
-	
+
 	/*  'e' EnumList
 	 */
 				/* drop thru */
@@ -1586,7 +1652,7 @@ int tnum, eval;
 	        bump_str(sr, &s);
 		if (!char_to_utypecode(bump_str(sr, &s), &utypecode))
 		  panic("unknown undef typecode in TypeDef");
-		tag = parse_name(sr, &s, ap, 0, compiler); /* RGA */
+		tag = parse_name(sr, &s, ap, 0, compiler, is_fortran);
 		if (stf->stf_compiler_type == CT_GNU_CC)
 		  field_scheck(sr, &s, ':');
 		else
@@ -1600,7 +1666,7 @@ int tnum, eval;
 		ft->u.type.ty_name = "UnKnOwN";
 	  /*		panic("unknown character in TypeDef");*/
 	}
-	
+
 	*p_s = s;
 	return &ft->u.type;
 }
@@ -1667,7 +1733,7 @@ Symrec *sr;
 	s = *p_s;
 
 	compiler = stf->stf_compiler_type;
-	name = parse_name(sr, &s, st->st_apool, 0, compiler);	/* RGA */
+	name = parse_name(sr, &s, st->st_apool, 0, compiler, FALSE);	/* RGA */
 	if (*s == '\\')
 	  s = get_cont_symstring(sr);
 	field_scheck(sr, &s, ':');
@@ -1707,7 +1773,7 @@ type_t *type;
 	Compiler_type compiler = CT_CC;
 	bool terminate = FALSE;
 	bool sc4 =FALSE;
-	
+
 	if (stf->stf_compiler_type == CT_UNKNOWN)
 	  compiler = ao_compiler(NULL, FALSE, CT_UNKNOWN);
 	else
@@ -1896,6 +1962,7 @@ Compiler_type compiler;
     *p_s = s;
     return next;
 }
+
 static void
 GnuStructMethods(stf,sr, p_s)
 stf_t *stf;
@@ -1911,10 +1978,21 @@ const char **p_s;
     **
     **   The format of the data is:
     **     
-    **        method_name::type_def=type_desc return_type(int);
-    **  	:arg_types; protection qualifier virt_static_normal vtblinfo;;"
+    **        <method_name::type_def=type_desc return_type(int);
+    **  	{:arg_types;method_kind vtblinfo};>;"
+    **	      The portion inside {} is repeated for each method of the same
+    **	      name and a different arguement list.
+    **	      The portion between <> is repeated for each method.
     **
-    **    virt_static_normal is indicated by
+    **    method_kind is indicated by three characters
+    **        [0-2][A-D][.*?]
+    **	      0  = private
+    **	      1  = protected
+    **	      2  = public
+    **	      A  = normal
+    **	      B  = const
+    **	      C  = violatile
+    **	      D  = const violatile
     **        .  = normal
     **        *  = virtual
     **        ?  = static
@@ -1924,7 +2002,8 @@ const char **p_s;
     **        vtable_index;class_first_defining;
     **
     **
-    **   Our algorithm is to skip to the next ".", '?', or '*'
+    **   Our algorithm is to look for the sequenct ;[0-2][A-D][.*?],
+    **   skip to the next ".", '?', or '*'
     **   then to the next, or third next semicolon, and repeat
     **   until the next character is also a semicolon.
     **
@@ -1945,20 +2024,30 @@ const char **p_s;
 	   SkipToSplChar(stf, sr, &s, ":");
 	}
 
-	/* Skip to the . ? or * */
-	SkipToSplChar(stf, sr, &s, ".?*");
+	/* Look for ";[0-2][A-D][.*?]" */
+	do SkipPastSemi(stf, sr, &s);
+	while (!(    ((unsigned)(s[0]-'0')) <= 2
+		&& ((unsigned)(s[1]-'A')) <= 3
+		&& ((s[2] == '.') || (s[2] == '?') || (s[2] == '*'))));
 
-	/* If it was a *, skip past the vtbl index in type number of the
+
+	/* For a virtual method, skip past the vtbl index in type number of the
 	** class first defining this method 
 	*/
-	if ( *s == '*')
+	if ( s[2] == '*')
 	{
 	    SkipPastSemi(stf, sr, &s);
 	    SkipPastSemi(stf, sr, &s);
 	}
 
-	/* Next ';' marks end of the method */
-	SkipPastSemi(stf, sr, &s);
+	/* Go to the ':' that starts the next arguement list for a method
+	** of the same name, or the';' that ends the methods of this name.
+	*/
+	SkipToSplChar(stf, sr, &s, ";:");
+	if (*s == ';')
+	{
+	    bump_str(sr, &s);
+	}
 
 	/* Repeat until remaining char is also a ';' */
     }
@@ -2139,7 +2228,7 @@ Compiler_type compiler;
     {
 	var_t* v = (var_t *) alloc(stf->stf_symtab->st_apool, sizeof(var_t));
 	const char* name = parse_name(sr, &s, stf->stf_symtab->st_apool,
-				  0, compiler);
+				  0, compiler, FALSE);
 	const char* ename = strrchr(name, ':');
 	if ( ename)
 	   v->va_name = ename+1;
@@ -2254,7 +2343,7 @@ bool *terminate;
 	{
 	  v = (var_t *) alloc(stf->stf_symtab->st_apool, sizeof(var_t));
 	  v->va_name = parse_name(sr, &s, stf->stf_symtab->st_apool,
-				  1, compiler); /* RGA */
+				  1, compiler, FALSE); /* RGA */
 	  v->va_language = stf->stf_language;
 	  v->va_flags = 0;
 	  v->va_class = is_struct ? CL_MOS : CL_MOU;
@@ -2288,7 +2377,7 @@ bool *terminate;
 	  *p_s = s;
 	  return NULL;
 	}
-	
+
 	if (*s == '\\')
 	{
 	  s = get_cont_symstring(sr);
@@ -2301,7 +2390,7 @@ bool *terminate;
 	    sprintf(tmp_s, "A%s", s);
 	    tmp_s2 = (const char *)tmp_s;
 	    v->va_name = parse_name(sr, &tmp_s2, stf->stf_symtab->st_apool,
-				    1, compiler);
+				    1, compiler, FALSE);
 	    s += tmp_s2 - orig_s - 1;
 	    free(orig_s);
 	  }
@@ -2342,7 +2431,7 @@ bool *terminate;
 	    v->va_flags = VA_STATIC_MEMBER;
 	    s++;
 	    v->va_addr = (taddr_t) parse_name(sr, &s, stf->stf_symtab->st_apool,
-				    0, compiler);
+				    0, compiler, FALSE);
 	    v->va_type = type;
 	    (void)field_scheck(sr,&s, ';');
 	    *p_s = s;
@@ -2440,7 +2529,7 @@ bool *terminate;
 	else {
 		v->va_type = type;
 	}
-	
+
 	v->va_next = next;
 	return v;
 }
@@ -2501,9 +2590,9 @@ long *p_val;
 {
 	const char *s;
 	Dimtype dimtype;
-	
+
 	s = *p_s;
-	
+
 	switch (*s) {
 	case 'T':
 		dimtype = DT_FPREL;
@@ -2527,7 +2616,7 @@ long *p_val;
 	  0 : parse_subrange_signed_num(stf, sr, &s);
 	*p_s = s;
 }
-	
+
 /*  Like parse_signed_num, but special case the values emitted by gcc
  *  for the 64 bit types.  These do not fit in 32 bits, so we just use
  *  special values which get_basic_type() will recognise.
@@ -2541,7 +2630,7 @@ const char **p_s;
 	const char *s;
 
 	s = *p_s;
-	
+
 	if (*s == '0' && (s[1] == '1' || s[1] == '7')) {
 		const char *ends;
 		int ndig;
