@@ -234,6 +234,8 @@ typedef struct stf_s {
 #define STF_LNOS_PRECEDE_FUNCS	0x01	/* for gcc */
 #define STF_HIDE		0x02	/* don't show this under source files */
 #define STF_NEED_SYMSCAN	0x04    /* need to get syms from .o file */
+#define STF_NEED_PATCH		0x08    /* some types have internal type codes */
+#define STF_FUNCS_REPEATED	0x10	/* two N_FUN syms for each function */
 
 typedef struct hfst {
 	stf_t *hf_stf;
