@@ -20,11 +20,9 @@ char ups_ao_target_c_sccsid[] = "@(#)ao_target.c	1.1 24/5/95 (UKC)";
 #include <stdio.h>
 #include <signal.h>
 
-#ifndef OS_LINUX /* RGA linux merge */
-#ifndef AO_ELF
+#if HAVE_MACHINE_REG_H
 #include <machine/reg.h>
 #endif
-#endif
 
 #include <local/ukcprog.h>
 #include <mtrprog/utils.h>
@@ -48,9 +46,6 @@ char ups_ao_target_c_sccsid[] = "@(#)ao_target.c	1.1 24/5/95 (UKC)";
 #include "obj_signal.h"
 #include "state.h"
 
-#ifdef OS_LINUX
-#include <sys/ptrace.h>
-#endif
 
 static int ao_initialise PROTO((ebuf_t *usage_eb, char **argv));
 static void ao_show_target_driver_info PROTO((bool name_only));
@@ -95,7 +90,7 @@ static int ao_call_func PROTO((target_t *xp, char *cma, taddr_t addr,
                                taddr_t *p_res, const char **p_mesg));
 static void ao_detach PROTO((target_t *xp));
 
-#ifdef AO_USE_PROCFS
+#if AO_USE_PROCFS
 #define ps_create_child			procfs_create_child
 #define ps_attach_to_process		procfs_attach_to_process
 #define ps_continue			procfs_continue
@@ -119,7 +114,7 @@ static void ao_detach PROTO((target_t *xp));
 #endif
 
 
-#ifdef AO_USE_PTRACE
+#if AO_USE_PTRACE
 #define ps_create_child			ptrace_create_child
 #define ps_attach_to_process		ptrace_attach_to_process
 #define ps_continue			ptrace_continue
@@ -239,7 +234,7 @@ const char **p_cmdline;
 	xp->xp_data = (char *)ip;
 
 #ifdef AO_ELF
-#ifdef AO_USE_PROCFS
+#if AO_USE_PROCFS
 	procfs_init(ip);
 #else
 	ip->ip_ptrace_info = NULL;
@@ -465,7 +460,7 @@ fpval_t *p_val;
 		return ao_read_data(xp, addr, (char *)&p_val->f, num_bytes);
 	    case sizeof(double):
 		return ao_read_data(xp, addr, (char *)&p_val->d, num_bytes);
-#if (defined(__GNUC__) && !defined (OS_SUNOS_4)) || defined(HAVE_LONG_DOUBLE)
+#if HAVE_LONG_DOUBLE && (SIZEOF_LONG_DOUBLE > SIZEOF_DOUBLE)
 	    case sizeof(long double):
 		return ao_read_data(xp, addr, (char *)&p_val->ld, num_bytes);
 #endif
@@ -567,7 +562,7 @@ target_t *xp;
 taddr_t sp;
 {
 	GET_IPROC(xp)->ip_base_sp = sp;
-#if (defined OS_SUNOS_4) || (defined ARCH_BSDI386)
+#if defined(AO_AOUT_SHLIBS)
 	load_shared_library_symtabs(xp, FALSE);
 	recalculate_bpt_addrs(xp);
 #endif
@@ -845,12 +840,12 @@ const char **p_mesg;
 	unsigned short regmask;
 #endif
 #ifdef OS_SUNOS
-#ifdef AO_USE_PROCFS
-	static int *regs = NULL, *origregs;
+#if AO_USE_PROCFS
+	static int *regs = NULL, *orig_regs;
 	static size_t regbytes;
 #else
-	sunregs_t sunregs, origsunregs;
-	sunregs_t *regs, *origregs;
+	sunregs_t sunregs, orig_sunregs;
+	sunregs_t *regs, *orig_regs;
 #endif
 #endif
 #ifdef ARCH_SUN4
@@ -864,7 +859,12 @@ const char **p_mesg;
 	taddr_t saved_sp, saved_regs[N_REG_ARGS];
 #endif
 #if defined(ARCH_BSDI386) || defined(ARCH_LINUX386)
+#if AO_HAS_PTRACE_REGS
+	ptrace_regs_t ptrace_regs, orig_ptrace_regs;
+	ptrace_regs_t *regs, *orig_regs; 
+#else
 	taddr_t saved_regs[N_UREGS];
+#endif
 #endif
 	breakpoint_t *bp;
 	taddr_t realargs[40];
@@ -949,21 +949,21 @@ const char **p_mesg;
 	sp = saved_sp & ~03;
 #endif
 #ifdef OS_SUNOS
-#ifdef AO_USE_PROCFS
+#if AO_USE_PROCFS
 	if (regs == NULL) {
 		regbytes = sizeof(int) * procfs_get_reg_index(PROCFS_REG_NREGS);
 		regs = e_malloc(regbytes);
-		origregs = e_malloc(regbytes);
+		orig_regs = e_malloc(regbytes);
 	}
 	
 	procfs_get_regtab(ip, regs);
-	memcpy(origregs, regs, regbytes);
+	memcpy(orig_regs, regs, regbytes);
 	sp = regs[procfs_get_reg_index(PROCFS_REG_SP)];
 #else
 	ptrace_get_regtab(ip, &sunregs);
-	origsunregs = sunregs;
+	orig_sunregs = sunregs;
 	regs = &sunregs;
-	origregs = &origsunregs;
+	orig_regs = &orig_sunregs;
 	sp = sunregs.sr_regs.r_sp;
 #endif
 #endif
@@ -973,10 +973,18 @@ const char **p_mesg;
 	sp = saved_sp = xp_getreg(xp, UPSREG_SP);
 #endif
 #if defined(ARCH_BSDI386) || defined(ARCH_LINUX386)
+#if AO_HAS_PTRACE_REGS
+	ptrace_get_regtab(ip, &ptrace_regs);
+	orig_ptrace_regs = ptrace_regs;
+	regs = &ptrace_regs;
+	orig_regs = &orig_ptrace_regs;
+	sp = xp_getreg(xp, UPSREG_SP);
+#else
 	for (i = 0; i < N_UREGS; ++i)
 		if (get_uarea_reg(ip, i, &saved_regs[i]) != 0)
 			panic("can't get reg in pcf");
 	sp = xp_getreg(xp, UPSREG_SP);
+#endif
 #endif
 
 	retpc = saved_restart_pc = ip->ip_restart_pc;
@@ -1150,7 +1158,7 @@ const char **p_mesg;
 	}
 #endif
 #ifdef ARCH_SUN4
-#ifdef AO_USE_PROCFS
+#if AO_USE_PROCFS
 	oregs = &regs[procfs_get_reg_index(PROCFS_REG_O0)];
 #else
 	oregs = &sunregs.sr_regs.r_o0;
@@ -1165,7 +1173,7 @@ const char **p_mesg;
 		*p_mesg = "Can't set registers for target function call";
 		return -1;
 	}
-#endif
+#endif /* ARCH_SUN4 */
 
 	/*  Jump to the start of the function.
 	 */
@@ -1195,16 +1203,14 @@ const char **p_mesg;
 
 	/*  Restore the registers we saved.
 	 */
-#ifdef ARCH_VAX
+#if defined(ARCH_VAX)
 	ps_setreg(ip, UPSREG_PC, saved_restart_pc);
 	ps_setreg(ip, UPSREG_SP, saved_sp);
 	ps_setreg(ip, 0, saved_r0);
 	ps_setreg(ip, 1, saved_r1);
-#endif
-#ifdef OS_SUNOS
-	ps_set_all_regs(ip, origregs);
-#endif
-#ifdef ARCH_MIPS
+#elif AO_HAS_PTRACE_REGS
+	ps_set_all_regs(ip, orig_regs);
+#elif defined(ARCH_MIPS)
 	if (saveregs) {
 		for (i = 1; i < 16; ++i) {
 			if (ps_setreg(ip, i, regtab[i]) != 0)
@@ -1215,24 +1221,23 @@ const char **p_mesg;
 				panic("can't restore registers in cf");
 		}
 	}
-#endif
-#ifdef ARCH_CLIPPER
+#elif defined(ARCH_CLIPPER)
 	for (i = 0; i < N_REG_ARGS; ++i) {
 		if (ps_setreg(ip, i, saved_regs[i]) != 0)
 			panic("can't restore regs in cf");
 	}
 	if (ps_setreg(ip, UPSREG_SP, saved_sp) != 0)
 		panic("can't restore sp in cf");
-#endif
-#ifdef ARCH_BSDI386
+#elif defined(ARCH_BSDI386)
 	for (i = 0; i < N_UREGS; ++i)
 		if (set_uarea_reg(ip, i, saved_regs[i]) != 0)
 			panic("can't restore regs in cf");
-#endif
-#ifdef ARCH_LINUX386
+#elif defined(ARCH_LINUX386)
 	for (i = 0; i < N_UREGS; ++i)
 		if (i != ORIG_EAX && set_uarea_reg(ip, i, saved_regs[i]) != 0)
 			panic("can't restore regs in cf");
+#else
+	ps_set_all_regs(ip, orig_regs);
 #endif
 
 	/*  Wait for target will have set ip_restart_pc to retpc, because
@@ -1242,4 +1247,5 @@ const char **p_mesg;
 
 	return 0;
 }
+
 #endif /* AO_TARGET */
