@@ -11,7 +11,7 @@
 
 #define AO_TARGET_H_INCLUDED
 
-#ifdef AO_USE_PROCFS
+#if AO_USE_PROCFS
 typedef struct Procfs_info Procfs_info;
 #else
 typedef struct Ptrace_info Ptrace_info;
@@ -25,7 +25,7 @@ typedef struct iproc {
 	bool ip_lastsig;
 	bool ip_attached;
 	stopres_t ip_stopres;
-#ifdef AO_USE_PROCFS
+#if AO_USE_PROCFS
 	Procfs_info *ip_procfs_info;
 #else
 	Ptrace_info *ip_ptrace_info;
