@@ -11,12 +11,14 @@ char ups_cc_c_sccsid[] = "@(#)cc.c	1.3 16 Sep 1994 (UKC)";
 
 #define UKC_WANT_COMMON_UNIX_EXTENSIONS 1	/* for popen() and pclose() */
 
-#include <stdlib.h>
+#include <mtrprog/ifdefs.h>
+
+#include <sys/stat.h>
 #include <stdio.h>
-#include <string.h>
-#include <errno.h>
+#include <fcntl.h>
+#include <ctype.h>
+
 #include <local/ukcprog.h>
-#include <mtrprog/utils.h>
 
 #include "ups.h"
 #include "symtab.h"
@@ -27,16 +29,36 @@ static const char *getline PROTO((char *arg));
 static parse_id_t parse PROTO((const char *name, const char *cppflags,
 			       unsigned long parse_flags));
 
+#include "xc_opcodes.h"
+#include "xc_machine.h"
+#include "xc_builtins.h"
 
-#define WANT_NAMES
+#if HAVE_X_WINDOWS
+#include <X11/Xlib.h>
+#include <X11/Xutil.h>
+#include <X11/Xresource.h>
+extern int _Xdebug;
+#endif
+
+
+/* ---------------------------------------------------------------------------
+ */
+
+#define WANT_DECLS
+#include "cx_libfuncs.h"
+#undef  WANT_DECLS
 
 static const char *Libfuncnames[] = {
+#define WANT_NAMES
 #include "cx_libfuncs.h"
+#undef  WANT_NAMES
 };
 #define N_LIBFUNCS ((int)(sizeof Libfuncnames / sizeof *Libfuncnames))
 
 static const char *Libvarnames[] = {
+#define WANT_NAMES
 #include "cx_libvars.h"
+#undef  WANT_NAMES
 };
 #define N_LIBVARS ((int)(sizeof Libvarnames / sizeof *Libvarnames))
 
@@ -56,10 +78,17 @@ struct ccstate_s {
 static const char Common_flags[] =
 "[-g] [-oldc] [-Idir] [-Dsym[=value]] [-Usym] [-ccerrfmt]";
 
-static const char Std_cppflags[] = "\
--D__CXC__ \
--I/usr/src/local/X11/ups/ups/cxinclude \
--I/usr/local/lib/ansi-include";
+/*  C pre-processor flags, undefine __GNUC__ to remove various extensions.
+ */
+static const char Std_cppflags[] = 
+"-D__STDC__=1 -D__CXC__=1 -U__GNUC__ -I/usr/local/lib/ups/ansi-include ";
+/*
+"'-D__attribute__(x)=' "
+"-D__inline__= "
+"-D__extension__= "
+"-D__signed__=signed "
+"-I/usr/src/local/X11/ups/ups/cxinclude "
+*/
 
 ccstate_t *
 cc_create_ccstate(extra_flags, compile_flags)
@@ -77,6 +106,18 @@ unsigned compile_flags;
 
 	Errsep = ", ";
 
+	/** Dibyendu: New warning messages **/
+	ci_add_message_action("Floating point suffix ignored", MA_WARNING_ONLY);
+	ci_add_message_action("Integer suffix ignored", MA_WARNING_ONLY);
+	ci_add_message_action("Cast ignored in initialisation", MA_WARNING_ONLY);
+	ci_add_message_action("Conversion to '", MA_WARNING_ONLY);
+
+	/** Dibyendu: These are now warnings rather than errors **/
+	ci_add_message_action("call via old style function expression",
+				      MA_WARNING_ONLY);
+	ci_add_message_action("No prototype in scope", MA_WARNING_ONLY);
+	ci_add_message_action("Implicit declaration of", MA_WARNING_ONLY);
+
 	return cs;
 }
 
@@ -98,6 +139,21 @@ void
 cc_get_libinfo(p_nlibfuncs, p_nlibvars)
 size_t *p_nlibfuncs, *p_nlibvars;
 {
+	static int i = 0;
+	static int j = 0;
+
+	/* Following is a temporary feature for checking supported
+	 * library functions 
+	 */
+	if (getenv("CX_DUMP_LIBFUNC_NAMES") != NULL) {
+		fprintf(stderr, "Library functions recognised\n");
+		for (; i < N_LIBFUNCS; i++) 
+			fprintf(stderr, "%d: %s\n", i, Libfuncnames[i]);
+		fprintf(stderr, "Library variables recognised\n");
+		for (; j < N_LIBVARS; j++) 
+			fprintf(stderr, "%d: %s\n", j, Libvarnames[j]);
+	}
+	
 	*p_nlibfuncs = N_LIBFUNCS;
 	*p_nlibvars = N_LIBVARS;
 }
@@ -176,10 +232,11 @@ char ***p_argv;
 }
 
 linkinfo_t *
-cc_parse_and_compile(cs, srcpath, p_parse_id)
+cc_parse_and_compile(cs, srcpath, p_parse_id, checkarg_proc)
 ccstate_t *cs;
 const char *srcpath;
 parse_id_t *p_parse_id;
+ci_checkarg_proc_t checkarg_proc;
 {
 	*p_parse_id = parse(srcpath, cs->cs_cppflags, cs->cs_parse_flags);
 	
@@ -189,7 +246,7 @@ parse_id_t *p_parse_id;
 	}
 			
 	return ci_compile(srcpath, *p_parse_id, cc_report_error,
-			  (ci_checkarg_proc_t)NULL,
+			  checkarg_proc,
 			  (ci_regno_to_addr_proc_t)NULL,
 			  cs->cs_compile_flags);
 }
@@ -273,7 +330,11 @@ unsigned long parse_flags;
 		char *cmd;
 
 		fclose(fp);
+#if defined(C_PREPROCESSOR)
+		cmd = strf("%s %s %s", C_PREPROCESSOR, cppflags, name);
+#else
 		cmd = strf("gcc -E %s %s", cppflags, name);
+#endif
 		errno = 0;
 		if ((fp = popen(cmd, "r")) == NULL) {
 			errf("Can't run \"%s\": %s", cmd, get_errno_str());
@@ -299,3 +360,4 @@ unsigned long parse_flags;
 
 	return parse_id;
 }
+
