@@ -9,15 +9,12 @@
 
 char ups_ci_compile_c_sccsid[] = "@(#)ci_compile.c	1.23 09 Sep 1994 (UKC)";
 
-#include <string.h>
+#include <mtrprog/ifdefs.h>
+
 #include <stdlib.h>
 #include <stdio.h>
 #include <setjmp.h>
 
-#ifndef __STDC__
-char *memcpy();
-#endif
-
 #include <local/ukcprog.h>
 #include <mtrprog/alloc.h>
 
@@ -1097,7 +1094,7 @@ unsigned flags;
 	 *  because it starts from one (to avoid NULL valid function ptrs.
 	 */
 	if (tx->tx_num_funcs <= 2) {
-		if (tx->tx_max_sp & sizeof(stackword_t) != 0)
+		if ((tx->tx_max_sp % sizeof(stackword_t)) != 0)
 			panic("misaligned stack in ci_compile");
 		max_stack_nwords = tx->tx_max_sp / sizeof(stackword_t) + 20;
 	}
@@ -1438,7 +1435,13 @@ func_t *f;
 	ci_code_generic_opcode(tx, OC_LINK_B, tx->tx_sp);
 
 	savesp = tx->tx_sp;
+#if WANT_OLD_LINK
 	checkpc = tx->tx_pc++;
+#else
+	/* Fix LINK ARG (CHAR -> LONG) : Dibyendu */
+	checkpc = tx->tx_pc;
+	tx->tx_pc += 4;
+#endif
 
 	tx->tx_curfil = f->fu_fil;
 	compile_statement(tx, f->fu_statement);
@@ -1446,7 +1449,12 @@ func_t *f;
 
 	savepc = tx->tx_pc;
 	tx->tx_pc = checkpc;
+#if WANT_OLD_LINK
 	ci_code_byte(tx, (long)(tx->tx_max_sp - savesp));
+#else
+	/* Fix LINK ARG (CHAR -> LONG) : Dibyendu */
+	ci_code_long(tx, (long)(tx->tx_max_sp - savesp));
+#endif
 	tx->tx_pc = savepc;
 
 	f->fu__lnos = tx->tx_lnos;
@@ -1860,6 +1868,11 @@ expr_t *expr;
 		case TY_DOUBLE:
 			opcode = OC_RET_DOUBLE;
 			break;
+#if WANT_LDBL
+		case TY_LONGDOUBLE:
+			opcode = OC_RET_DOUBLE;	/* FIX: */
+			break;
+#endif
 		default:
 			opcode = OC_RET_WORD;
 			break;
