@@ -194,8 +194,14 @@ initlist_t **p_initlist;
 			 *  is null.  This is so we don't bomb on the
 			 *  special case prototype syntax f(void).
 			 */
+#if 0
 			if (type != NULL && type->ty_code == TY_VOID &&
 								name != NULL) {
+#else
+			if (type != NULL && type->ty_code == TY_VOID 
+			&& name != NULL && class != CL_TYPEDEF) {
+				/* Allow 'typedef void void_t;' */
+#endif
 				diagf(ET_ERROR, lx,
 					"Illegal type void for `%s'", name);
 				type = ci_code_to_type(TY_INT);
@@ -340,16 +346,17 @@ const char *tag;
 }
 
 type_t *
-ci_build_aggr_or_enum_def(typecode, id, new_is_complete, aggr_decls, enum_members)
+ci_build_aggr_or_enum_def(typecode, id, new_is_complete, aggr_decls, enum_members, is_definition)
 typecode_t typecode;
 identifier_t *id;
 ae_is_complete_t new_is_complete;
 declaration_t *aggr_decls;
 enum_member_t *enum_members;
+bool is_definition;
 {
 	const char *tag;
 	block_t *bl;
-	aggr_or_enum_def_t *ae = NEW(aggr_or_enum_def_t);
+	aggr_or_enum_def_t *ae;
 
 	tag = (id == NULL) ? NULL : id->id_name;
 	if (tag != NULL) {
@@ -380,20 +387,65 @@ enum_member_t *enum_members;
 						      NT_ENUM_CONST,em2->em_lexinfo);
 	}
 
+	/* Redeclaration Fix : Dibyendu 8/1/99 */
+	if (ae != NULL && ae->ae_is_complete == AE_INCOMPLETE) {
+
+		/* A redeclaration in the same scope is valid */
+		if (bl == Current_block && new_is_complete == AE_INCOMPLETE)
+			return ae->ae_type;
+
+	}
+
 	if (ae != NULL && ae->ae_is_complete == AE_COMPLETE) {
-		if (new_is_complete == AE_INCOMPLETE)
+		/* Redeclaration Fix : Dibyendu 8/1/99 */
+		/* Because an incomplete type can mean the start of a new type
+		 * if the complete type was defined in the enclosing block.
+		 */
+		if (bl == Current_block && new_is_complete == AE_INCOMPLETE)
 			return ae->ae_type;
 
 		/*  Redeclaration.  Print an error message if it's at the same
 		 *  level as the original declaration, then forget the old
 		 *  declaration so we can insert a new one.
 		 */
-		if (bl == Current_block) {
+		/* Redeclaration Fix : Dibyendu 8/1/99 */
+		/* A redeclaration is an error if both are complete
+		 * definitions and in the same block.
+		 */
+		if (bl == Current_block && new_is_complete == AE_COMPLETE) {
 			report_redecl(tag, NT_TAG, (id == NULL) ? NULL
 								: id->id_lexinfo,
 					   NT_TAG, ae->ae_lexinfo);
+			ae = NULL;
 		}
-		ae = NULL;
+
+		/* Redeclaration Fix : Dibyendu 8/1/99 */
+		/* A complete definition in this block will hide
+		 * any previous complete definition in enclosing block.
+		 * The special case of 'struct tag;' also hides any complete
+		 * definition of tag in enclosing scope.
+		 */
+		else if (new_is_complete == AE_COMPLETE ||
+		   (new_is_complete == AE_INCOMPLETE && id->id_semi_follows)) {
+			ae = NULL;
+		}
+		else {
+			/* See changes in the ci_parse.y. We now define
+			 * an incomplete type immediately after we see
+			 * the tag (ISO C) - earlier this was deferred until we
+			 * saw a reference to the tag.
+			 * The is_definition flag tells us that although
+			 * this is currently being defined as an incomplete
+			 * type - its full definition is following
+			 * immediately after. Hence this definition hides
+			 * any previous definition in enclosing block.
+			 */
+			if (is_definition)
+				ae = NULL;
+			else
+				return ae->ae_type;
+		}
+
 	}
 			
 	if (ae == NULL) {
@@ -557,7 +609,7 @@ taddr_t addr;
 		return addr;
 	}
 
-#ifdef IS_BIG_ENDIAN
+#if IS_BIG_ENDIAN
 	if (prev == NULL || prev->va_type->ty_code != TY_BITFIELD)
 		offset = -1;
 	else
@@ -576,9 +628,18 @@ taddr_t addr;
 #else
 	if (prev == NULL || prev->va_type->ty_code != TY_BITFIELD)
 		offset = bits_per_word;
-	else
-		offset = prev->va_type->ty_bitfield->bf_offset -
+	else {
+		/* 
+		 * Dibyendu : following caused bit fields to have
+		 * negative offsets - causing CX to panic().
+		 * 8/12/98.
+		 *
+		 * offset = prev->va_type->ty_bitfield->bf_offset -
+	 	 *			prev->va_type->ty_bitfield->bf_width;
+		 */
+		offset = prev->va_type->ty_bitfield->bf_offset +
 					prev->va_type->ty_bitfield->bf_width;
+	}
 
 	if (bf->bf_width == 0 || offset + bf->bf_width > bits_per_word) {
 		v->va_addr = ci_align_addr_for_type(addr, v->va_type);
@@ -651,6 +712,72 @@ declaration_t *declaration;
 	}
 }
 
+/* Dibyendu 26/12/98 - new function added 
+ * This is called for type declarations without declaration specifiers.
+ * C allows a type declaration for side-effect - such as declaring a 
+ * struct, union or enum type. However, the grammer allows non-sensical 
+ * constructs as well, such as:
+ *     extern;
+ *     static struct s { int dummy; };
+ *     struct { int dummy; };
+ *     typedef int;
+ * The purpose of this function is to catch such errors. 
+ */
+void
+ci_check_declaration(declaration)
+declaration_t *declaration;
+{
+	type_t *type;
+
+	if (declaration->dn_class == CL_TYPEDEF) {
+		/* This function is called only when there are no
+		 * declarators.
+		 */
+		diagf(ET_ERROR, NULL, "Typedef without a declarator");
+		return;
+	}
+
+	type = ci_get_dn_basetype(declaration);
+	if (type->ty_code != TY_STRUCT 
+	 && type->ty_code != TY_UNION 
+	 && type->ty_code != TY_ENUM
+	 && type->ty_code != TY_U_STRUCT
+	 && type->ty_code != TY_U_UNION
+	 && type->ty_code != TY_U_ENUM) {
+		/* Only struct, union or enum declarations are valid
+		 * without a declarator.
+		 */
+		diagf(ET_ERROR, NULL, 
+		"Declaration does not have a declarator");
+		return;
+	}
+
+	if (type->ty_code == TY_STRUCT 
+	 || type->ty_code == TY_UNION
+	 || type->ty_code == TY_U_STRUCT
+	 || type->ty_code == TY_U_UNION) {
+		if (type->ty_aggr_or_enum->ae_tag == NULL) {
+			/* A struct or union without a tag name 
+			 * or a declarator, cannot be accessed.
+			 */
+			diagf(ET_ERROR, NULL,
+			"Unnamed aggregate type cannot be accessed");
+		}
+	}
+
+	if (type->ty_code == TY_STRUCT 
+	 || type->ty_code == TY_UNION 
+	 || type->ty_code == TY_ENUM
+	 || type->ty_code == TY_U_STRUCT
+	 || type->ty_code == TY_U_UNION
+	 || type->ty_code == TY_U_ENUM) {
+		if (declaration->dn_class != CL_NOCLASS) {
+			diagf(ET_ERROR, NULL, 
+			"Aggregate type declaration has incorrect storage class");
+		}
+	}
+}
+
 void
 ci_insert_var_declaration(v)
 var_t *v;
@@ -843,6 +970,14 @@ const char *name;
 	for (bl = Current_block; bl != NULL; bl = bl->bl_parent) {
 		if ((td = name_to_typedef(bl->bl_typedefs, name)) != NULL)
 			return td->td_type;
+
+		/* Dibyendu : 28/12/98.
+		 * typedef names are ordinary identifiers. A variable
+		 * or function declaration may have hidden the typedef
+		 * name.
+		 */
+		if (lookup_name_in_block(bl, name) != NULL)
+			return NULL;
 	}
 
 	return NULL;
