@@ -9,6 +9,8 @@
 
 char ups_ci_expr_c_sccsid[] = "@(#)ci_expr.c	1.22 04 Jun 1995 (UKC)";
 
+#include <mtrprog/ifdefs.h>
+
 #include <stdlib.h>
 #include <string.h>
 
@@ -174,6 +176,122 @@ expr_t *expr;
 	}
 }
 
+/* Dibyendu 12/1/99 */
+/* Changes for ISO C compliant usual arithmetic conversions */
+static int
+integer_rank(type)
+typecode_t type;
+{
+	int rank = 0;
+
+	switch (type) {
+#if WANT_LL
+	case TY_LONGLONG:
+	case TY_ULONGLONG:
+		rank = 5;
+		break;
+#endif
+	case TY_LONG:
+	case TY_ULONG:
+		rank = 4;
+		break;
+	case TY_INT:
+	case TY_UINT:
+	case TY_ENUM:
+		rank = 3;
+		break;
+	case TY_SHORT:
+	case TY_USHORT:
+		rank = 2;
+		break;
+	case TY_CHAR:	
+	case TY_UCHAR:	
+		rank = 1;
+		break;
+	default:
+		ci_panic("type botch in ir");
+	}
+	return rank;
+}
+
+static int
+integer_size(type)
+typecode_t type;
+{
+	int size = 0;
+
+	switch (type) {
+#if WANT_LL
+	case TY_LONGLONG:
+	case TY_ULONGLONG:
+		size = sizeof(long_long_t);
+		break;
+#endif
+	case TY_LONG:
+	case TY_ULONG:
+		size = sizeof(long);
+		break;
+	case TY_INT:
+	case TY_UINT:
+	case TY_ENUM:
+		size = sizeof(int);
+		break;
+	case TY_SHORT:
+	case TY_USHORT:
+		size = sizeof(short);
+		break;
+	case TY_CHAR:	
+	case TY_UCHAR:	
+		size = 1;
+		break;
+	default:
+		ci_panic("type botch in is");
+	}
+	return size;
+}
+
+static bool
+can_accomodate(target, source)
+typecode_t target;
+typecode_t source;
+{
+	if (ci_is_signed_type(target) && !ci_is_signed_type(source)) {
+		return integer_size(target) > integer_size(source);
+	}
+	else if (ci_is_signed_type(target) && ci_is_signed_type(source) 
+	|| !ci_is_signed_type(target) && !ci_is_signed_type(source)) {
+		return integer_size(target) >= integer_size(source);
+	}
+	return FALSE;
+}
+
+static typecode_t
+to_unsigned(type)
+typecode_t type;
+{
+	switch (type) {
+#if WANT_LL
+	case TY_LONGLONG:
+		return TY_ULONGLONG;
+#endif
+	case TY_LONG:
+		return TY_ULONG;
+	case TY_INT:
+		return TY_UINT;
+	case TY_SHORT:
+		return TY_USHORT;
+	case TY_CHAR:
+		return TY_UCHAR;
+	default:
+		ci_panic("type botch in tu");
+		return TY_ULONG;
+	}
+}
+
+/***
+* Dibyendu : 12/1/99
+* Reference page 38 Section 6.3.1.8 of C9X
+*/
 static type_t *
 do_usual_arithmetic_conversions(left, right, opname)
 expr_t *left, *right;
@@ -187,13 +305,19 @@ const char *opname;
 	if (leftbad || rightbad)
 		return NULL;
 
-	ci_do_integral_promotions(left);
-	ci_do_integral_promotions(right);
+	/* Dibyendu 12/1/99 - remove
+	 * ci_do_integral_promotions(left);
+	 * ci_do_integral_promotions(right);
+	 */
 	leftcode = left->ex_type->ty_code;
 	rightcode = right->ex_type->ty_code;
 
-	/* TODO: check for long double. */
-
+#if WANT_LDBL
+	if (leftcode == TY_LONGDOUBLE || rightcode == TY_LONGDOUBLE) {
+		(void) ci_push_conversion(left, TY_LONGDOUBLE, ET_PROMOTION);
+		return ci_push_conversion(right, TY_LONGDOUBLE, ET_PROMOTION);
+	}
+#endif
 	if (leftcode == TY_DOUBLE || rightcode == TY_DOUBLE) {
 		(void) ci_push_conversion(left, TY_DOUBLE, ET_PROMOTION);
 		return ci_push_conversion(right, TY_DOUBLE, ET_PROMOTION);
@@ -202,32 +326,57 @@ const char *opname;
 		(void) ci_push_conversion(left, TY_FLOAT, ET_PROMOTION);
 		return ci_push_conversion(right, TY_FLOAT, ET_PROMOTION);
 	}
-	
-	if (leftcode == TY_ULONG || rightcode == TY_ULONG) {
-		(void) ci_push_conversion(left, TY_ULONG, ET_PROMOTION);
-		return ci_push_conversion(right, TY_ULONG, ET_PROMOTION);
-	}
 
-	if ((leftcode == TY_LONG && rightcode == TY_UINT) ||
-	    (leftcode == TY_UINT && rightcode == TY_LONG)) {
-		if (long_is_bigger_than_unsigned()) {
-			(void) ci_push_conversion(left, TY_LONG, ET_PROMOTION);
-			return ci_push_conversion(right, TY_LONG, ET_PROMOTION);
+	/* Dibyendu 12/1/99 - start */
+	ci_do_integral_promotions(left);
+	ci_do_integral_promotions(right);
+	leftcode = left->ex_type->ty_code;
+	rightcode = right->ex_type->ty_code;
+
+	if (leftcode == rightcode)
+		return left->ex_type;
+
+	if (ci_is_signed_type(leftcode) && ci_is_signed_type(rightcode) 
+	|| !ci_is_signed_type(leftcode) && !ci_is_signed_type(rightcode)) {
+		if (integer_rank(leftcode) > integer_rank(rightcode)) {
+			(void) ci_push_conversion(left, leftcode, ET_PROMOTION);
+			return ci_push_conversion(right, leftcode, ET_PROMOTION);
+		}
+		else if (integer_rank(leftcode) < integer_rank(rightcode)) {
+			(void) ci_push_conversion(left, rightcode, ET_PROMOTION);
+			return ci_push_conversion(right, rightcode, ET_PROMOTION);
 		}
 		else {
-			(void) ci_push_conversion(left, TY_ULONG, ET_PROMOTION);
-			return ci_push_conversion(right, TY_ULONG, ET_PROMOTION);
+			return left->ex_type;
 		}
 	}
-
-	if (leftcode == TY_LONG || rightcode == TY_LONG) {
-		(void) ci_push_conversion(left, TY_LONG, ET_PROMOTION);
-		return ci_push_conversion(right, TY_LONG, ET_PROMOTION);
+	else if (!ci_is_signed_type(leftcode) && integer_rank(leftcode) >= integer_rank(rightcode)) {
+		(void) ci_push_conversion(left, leftcode, ET_PROMOTION);
+		return ci_push_conversion(right, leftcode, ET_PROMOTION);
 	}
-	if (leftcode == TY_UINT || rightcode == TY_UINT) {
-		(void) ci_push_conversion(left, TY_UINT, ET_PROMOTION);
-		return ci_push_conversion(right, TY_UINT, ET_PROMOTION);
+	else if (!ci_is_signed_type(rightcode) && integer_rank(rightcode) >= integer_rank(leftcode)) {
+		(void) ci_push_conversion(left, rightcode, ET_PROMOTION);
+		return ci_push_conversion(right, rightcode, ET_PROMOTION);
 	}
+	else if (ci_is_signed_type(leftcode) && can_accomodate(leftcode, rightcode)) {
+		(void) ci_push_conversion(left, leftcode, ET_PROMOTION);
+		return ci_push_conversion(right, leftcode, ET_PROMOTION);
+	}
+	else if (ci_is_signed_type(rightcode) && can_accomodate(rightcode, leftcode)) {
+		(void) ci_push_conversion(left, rightcode, ET_PROMOTION);
+		return ci_push_conversion(right, rightcode, ET_PROMOTION);
+	}
+	else {
+		if (ci_is_signed_type(rightcode)) {
+			(void) ci_push_conversion(left, to_unsigned(rightcode), ET_PROMOTION);
+			return ci_push_conversion(right, to_unsigned(rightcode), ET_PROMOTION);
+		}
+		else {
+			(void) ci_push_conversion(left, to_unsigned(leftcode), ET_PROMOTION);
+			return ci_push_conversion(right, to_unsigned(leftcode), ET_PROMOTION);
+		}
+	}
+	/* Dibyendu 12/1/99 - end */
 
 	/*  If we get here, the types should both be int.
 	 */
@@ -361,8 +510,15 @@ expr_t *expr;
 	if (IS_ARITHMETIC_TYPE(code1) && IS_ARITHMETIC_TYPE(code2)) {
 		if (t1->ty_code == TY_BITFIELD)
 			t1 = ci_code_to_type(TY_INT);
-		if (!ci_types_same(t1, t2))
+		if (!ci_types_same(t1, t2)) {
+			/* ENUM fix : Dibyendu 02/Jan/99 */
+			if (code1 == TY_ENUM && code2 != TY_ENUM) {
+				diagf(ET_WARNING, expr->ex_lexinfo,
+				      "Assigning non-enum value to enum");
+				return -1;
+			}	
 			ci_push_conversion(expr, code1, ET_ASSIGNMENT_CONVERSION);
+		}
 		return 0;
 	}
 
@@ -394,15 +550,20 @@ expr_t *expr;
 /* TODO: various integer types for constants.
  */
 expr_t *
-ci_make_integer_constant_expr(exprtype, lx, ival)
+ci_make_integer_constant_expr(exprtype, lx, ival, is_unsigned)
 expr_type_t exprtype;
 lexinfo_t *lx;
 long ival;
+ bool is_unsigned;
 {
 	expr_t *ex = NEW(expr_t);
 
 	ex->ex_exprtype = exprtype;
+#if WANT_UINT_CONST
+	ex->ex_type = ci_code_to_type(is_unsigned ? TY_UINT : TY_INT);
+#else
 	ex->ex_type = ci_code_to_type(TY_INT);
+#endif
 	ex->ex_lexinfo = lx;
 	ex->ex_is_lvalue = FALSE;
 	ex->ex_is_constant = TRUE;
@@ -418,7 +579,7 @@ double fval;
 	expr_t *ex = NEW(expr_t);
 
 	ex->ex_exprtype = ET_FLOATING_CONST;
-	ex->ex_type = ci_code_to_type(TY_DOUBLE);
+	ex->ex_type = ci_code_to_type(TY_DOUBLE);	/* FIX: long double ? */
 	ex->ex_lexinfo = lx;
 	ex->ex_is_lvalue = FALSE;
 	ex->ex_is_constant = TRUE;
@@ -578,7 +739,7 @@ const char *opname;
 		if (code == TY_STRUCT || code == TY_UNION) {
 			v = aggr_expr->ex_type->ty_aggr_or_enum->ae_aggr_members;
 			for (; v != NULL; v = v->va_next)
-				if (strcmp(v->va_name, id->id_name) == 0)
+				if ((v->va_name != NULL) && (strcmp(v->va_name, id->id_name) == 0))
 					break;
 			if (v == NULL)
 				diagf(ET_ERROR, id->id_lexinfo,
@@ -702,8 +863,10 @@ const char *opname;
 
 		/* BUG: can't face doing f++ or d++ in the code generator right now.
 		 */
-		if (type != NULL && (type->ty_code == TY_FLOAT ||
-							type->ty_code == TY_DOUBLE))
+		if (type != NULL && (type->ty_code == TY_FLOAT
+				     || type->ty_code == TY_DOUBLE
+				     || type->ty_code == TY_LONGDOUBLE
+				     ))
 			diagf(ET_ERROR, expr->ex_lexinfo,
 		"Sorry, ++ and -- on floating expressions not yet implemented");
 							
@@ -1442,6 +1605,9 @@ expr_list_t *arglist;
 	return ex;
 }
 
+/***
+* Reference : page 37 of C9X - Section 6.3.1.1
+*/
 void
 ci_do_integral_promotions(expr)
 expr_t *expr;
@@ -1467,6 +1633,10 @@ expr_t *expr;
 		typecode = int_is_bigger_than_short() ? TY_INT : TY_UINT;
 		ci_push_conversion(expr, typecode, ET_PROMOTION);
 		break;
+	/* ENUM Fix : Dibyendu 02/Jan/99 */
+	case TY_ENUM:
+		ci_push_conversion(expr, TY_INT, ET_PROMOTION);
+  		break;
 	default:
 		break;
 	}
