@@ -9,10 +9,7 @@
 
 char ups_ci_types_c_sccsid[] = "@(#)ci_types.c	1.18 04 Jun 1995 (UKC)";
 
-#include <string.h>
-
-#include <stdlib.h>
-#include <stdio.h>
+#include <mtrprog/ifdefs.h>
 
 #include <local/ukcprog.h>
 
@@ -41,6 +38,12 @@ static void complain_about_bad_type PROTO((unsigned flags));
 #define DOUBLE_SIZE	sizeof(double)
 #define ENUM_SIZE	sizeof(typecode_t)	/* or any enum */
 #define POINTER_SIZE	sizeof(int *)
+#if WANT_LL
+#define LONG_LONG_SIZE	sizeof(long_long_t)
+#endif
+#if WANT_LDBL
+#define LONG_DBL_SIZE	sizeof(long_double_t)
+#endif
 
 #define CHAR_ALIGN	CHAR_SIZE
 #define SHORT_ALIGN	SHORT_SIZE
@@ -49,9 +52,15 @@ static void complain_about_bad_type PROTO((unsigned flags));
 #define POINTER_ALIGN	POINTER_SIZE
 #define FLOAT_ALIGN	FLOAT_SIZE
 #define DOUBLE_ALIGN	FLOAT_SIZE	/* BUG: wrong (esp. on SPARC) */
+#if WANT_LL
+#define LONG_LONG_ALIGN	LONG_LONG_SIZE	/* XXX: guess */
+#endif
+#if WANT_LDBL
+#define LONG_DBL_ALIGN	LONG_DBL_SIZE	/* XXX: guess */
+#endif
 
 #define WORD_ALIGN	LONG_ALIGN
-#define MAX_ALIGN	DOUBLE_ALIGN
+#define MAX_ALIGN	DOUBLE_ALIGN	/* XXX: or LONG_DBL_ALIGN ? */
 
 #define TF_TYPE_DONE	0x0001
 #define TF_VOID		0x0002
@@ -63,9 +72,15 @@ static void complain_about_bad_type PROTO((unsigned flags));
 #define TF_DOUBLE	0x0080
 #define TF_SIGNED	0x0100
 #define TF_UNSIGNED	0x0200
-#define TF_ENUM		0x0400
-#define TF_STRUCT	0x0800
-#define TF_UNION	0x1000
+#if WANT_LL
+#define TF_LONG_LONG	0x0400
+#endif
+#if WANT_LDBL
+#define TF_LONG_DBL	0x0800
+#endif
+#define TF_ENUM		0x1000
+#define TF_STRUCT	0x2000
+#define TF_UNION	0x4000
 
 #define TF_MAX_MASK	TF_UNION
 
@@ -88,6 +103,11 @@ type_t *type;
 	case TY_LONG:
 	case TY_ULONG:
 		return LONG_ALIGN;
+#if WANT_LL
+	case TY_LONGLONG:
+	case TY_ULONGLONG:
+		return LONG_LONG_ALIGN;
+#endif
 	case TY_INT:
 	case TY_UINT:
 	case TY_BITFIELD:
@@ -103,6 +123,10 @@ type_t *type;
 		return FLOAT_ALIGN;
 	case TY_DOUBLE:
 		return DOUBLE_ALIGN;
+#if WANT_LDBL
+	case TY_LONGDOUBLE:
+		return LONG_DBL_ALIGN;
+#endif
 	default:
 		ci_panic("bad type in ta");
 		return 0; /* to satisfy gcc */
@@ -124,9 +148,16 @@ typecode_t typecode;
 		case TY_UINT:	return OP_CVT_TO_UINT;
 		case TY_LONG:	return OP_CVT_TO_LONG;
 		case TY_ULONG:	return OP_CVT_TO_ULONG;
+#if WANT_LL
+		case TY_LONGLONG:	return OP_CVT_TO_LONG_LONG;
+		case TY_ULONGLONG:	return OP_CVT_TO_ULONG_LONG;
+#endif
 		case TY_FLOAT:	return OP_CVT_TO_FLOAT;
 		case TY_VOID:	return OP_CVT_TO_VOID;
 		case TY_DOUBLE:	return OP_CVT_TO_DOUBLE;
+#if WANT_LDBL
+		case TY_LONGDOUBLE:	return OP_CVT_TO_LONG_DOUBLE;
+#endif
 		case DT_PTR_TO:	return OP_CVT_TO_PTR;
 		case TY_BOOLEAN:return OP_CVT_TO_INT;
 		default:
@@ -234,8 +265,14 @@ unsigned flag;
 		case TF_SHORT:		return "short";
 		case TF_INT:		return "int";
 		case TF_LONG:		return "long";
+#if WANT_LL
+		case TF_LONG_LONG:	return "long long";
+#endif
 		case TF_FLOAT:		return "float";
 		case TF_DOUBLE:		return "double";
+#if WANT_LDBL
+		case TF_LONG_DBL:	return "";		/* XXX: see call */
+#endif
 		case TF_SIGNED:		return "signed";
 		case TF_UNSIGNED:	return "unsigned";
 		case TF_ENUM:		return "enum";
@@ -251,7 +288,7 @@ static typecode_t
 flags_to_typecode(typeflags)
 unsigned typeflags;
 {
-	switch (ci_effective_typecode(typeflags)) {
+	switch (typeflags) {
 	case TF_VOID:
 		return TY_VOID;
 
@@ -276,12 +313,8 @@ unsigned typeflags;
 
 	case TF_INT:
 	case TF_SIGNED:
-	case TY_BOOLEAN:
 	case TF_SIGNED | TF_INT:
 		return TY_INT;
-	case 0:
-		diagf(ET_WARNING, (lexinfo_t *)NULL, "Type defaults to int");
-		return TY_INT;
 	
 	case TF_UNSIGNED:
 	case TF_UNSIGNED | TF_INT:
@@ -293,24 +326,50 @@ unsigned typeflags;
 	case TF_SIGNED | TF_LONG | TF_INT:
 		return TY_LONG;
 
+#if WANT_LL
+	case TF_LONG_LONG:
+	case TF_SIGNED | TF_LONG_LONG:
+	case TF_LONG_LONG | TF_INT:
+	case TF_SIGNED | TF_LONG_LONG | TF_INT:
+		return TY_LONGLONG;
+#endif
+
 	case TF_UNSIGNED | TF_LONG:
 	case TF_UNSIGNED | TF_LONG | TF_INT:
 		return TY_ULONG;
 	
+#if WANT_LL
+	case TF_UNSIGNED | TF_LONG_LONG:
+	case TF_UNSIGNED | TF_LONG_LONG | TF_INT:
+		return TY_ULONGLONG;
+#endif
+
 	case TF_FLOAT:
 		return TY_FLOAT;
 
 	case TF_DOUBLE:
+#if WANT_LDBL
+		return TY_DOUBLE;
+#endif
 	case TF_LONG | TF_DOUBLE:
-		/* BUG: `long double' and `double' are distinct types.
+#if WANT_LDBL
+	case TF_LONG_DBL:
+		return TY_LONGDOUBLE;
+#else
+		/* BUG: 'long double' and 'double' are distinct types 
 		 */
 		return TY_DOUBLE;
+#endif
 	
 	case TF_ENUM:
 	case TF_STRUCT:
 	case TF_UNION:
 		return TY_STRUCT;	/* see ci_get_dn_basetype() */
 	
+	case 0:
+		diagf(ET_WARNING, (lexinfo_t *)NULL, "Type defaults to int");
+		return TY_INT;
+
 	default:
 		return TY_NOTYPE;
 	}
@@ -333,10 +392,18 @@ bool alltypes_ok;
 		return TF_INT;
 	case TY_LONG:
 		return TF_LONG;
+#if WANT_LL
+	case TY_LONGLONG:
+		return TF_LONG_LONG;
+#endif
 	case TY_FLOAT:
 		return TF_FLOAT;
 	case TY_DOUBLE:
 		return TF_DOUBLE;
+#if WANT_LDBL
+	case TY_LONGDOUBLE:
+		return TF_LONG_DBL;
+#endif
 	case TY_SIGNED:
 		return TF_SIGNED;
 	case TY_UNSIGNED:
@@ -396,6 +463,15 @@ type_t *modtype;
 
 	flag = typecode_to_flag(modtype->ty_code, FALSE);
 
+#if WANT_LL
+	/* Fudge for 'long long'. */
+	if (((dn->dn_typeflags & TF_LONG) != 0) && (flag == TF_LONG)) {
+	    /* Note - clear TF_LONG bit. */
+	    dn->dn_typeflags &= (~TF_LONG);
+	    flag = TF_LONG_LONG;
+	}
+#endif
+
 	if ((dn->dn_typeflags & flag) != 0 &&
 					(dn->dn_dup_typeflags & flag) == 0) {
 		diagf(ET_WARNING, (lexinfo_t *)NULL,
@@ -453,6 +529,12 @@ type_t *type;
 		case TY_ULONG:
 			size = LONG_SIZE;
 			break;
+#if WANT_LL
+		case TY_LONGLONG:
+		case TY_ULONGLONG:
+			size = LONG_LONG_SIZE;
+			break;
+#endif
 		case TY_INT:
 		case TY_UINT:
 		case TY_BITFIELD:
@@ -473,9 +555,15 @@ type_t *type;
 		case TY_DOUBLE:
 			size = DOUBLE_SIZE;
 			break;
+#if WANT_LDBL
+		case TY_LONGDOUBLE:
+			size = LONG_DBL_SIZE;
+			break;
+#endif
 		default:
 /*			ci_panic("unknown typecode in ts");*/
 /*			size = -1;*/ /* to satisfy gcc */
+			errf("unknown typecode in ts");
 			size = 0;
 	}
 		type->ty_size = size;
@@ -597,7 +685,13 @@ type_t *t1, *t2;
 		case TY_SHORT:	case TY_USHORT:
 		case TY_INT:	case TY_UINT:
 		case TY_LONG:	case TY_ULONG:
-		case TY_FLOAT:	case TY_DOUBLE:
+#if WANT_LL
+		case TY_LONGLONG:	case TY_ULONGLONG:
+#endif
+		case TY_FLOAT:	case TY_DOUBLE:	
+#if WANT_LDBL
+		case TY_LONGDOUBLE:
+#endif
 			break;
 		default:
 			ci_panic("bad type in ts");
@@ -628,15 +722,24 @@ typecode_t typecode;
 	case TY_SHORT:
 	case TY_INT:
 	case TY_LONG:
+#if WANT_LL
+	case TY_LONGLONG:
+#endif
 	case TY_ENUM:
 	case TY_FLOAT:
 	case TY_DOUBLE:
+#if WANT_LDBL
+	case TY_LONGDOUBLE:
+#endif
 	case TY_BOOLEAN:
 		return TRUE;
 	case TY_UCHAR:
 	case TY_USHORT:
 	case TY_UINT:
 	case TY_ULONG:
+#if WANT_LL
+	case TY_ULONGLONG:
+#endif
 	case DT_PTR_TO:
 	case DT_ARRAY_OF:
 		return FALSE;
@@ -659,8 +762,14 @@ typecode_t typecode;
 	case TY_UINT:
 	case TY_LONG:
 	case TY_ULONG:
+#if WANT_LL
+	case TY_LONGLONG:
+	case TY_ULONGLONG:
+#endif
 	case TY_BITFIELD:
 	case TY_BOOLEAN:
+	/* Dibyendu added following */
+	case TY_ENUM:
 		return TRUE;
 	default:
 		return FALSE;
@@ -754,6 +863,8 @@ funcret_t *fr;
 	for (v = fr->fr_params; v != NULL; v = v->va_next) {
 		if (v->va_type->ty_code == DT_ARRAY_OF)
 			v->va_type = ci_make_pointer(v->va_type->ty_base, 0);
+		else if (v->va_type->ty_code == DT_FUNC_RETURNING) /* Dibyendu 01/01/99 */
+			v->va_type = ci_make_pointer(v->va_type, 0);
 	}
 }
 
@@ -980,3 +1091,55 @@ var_t *vlist;
 	}
 	return complained;
 }
+
+const char *
+ci_typecode_to_name(typecode)
+typecode_t typecode;
+{
+    switch (typecode) {
+	case DT_PTR_TO:		return "ptr";
+	case DT_FUNC_RETURNING: return "function";
+	case DT_ARRAY_OF: 	return "array";
+	case TY_IDENTIFIER:	return "identifier";
+	case TY_ELLIPSIS:	return "ellipsis";
+	case TY_UNSIGNED:	return "unsigned";
+	case TY_SIGNED:		return "signed";
+
+	/* C aggregate types etc */
+	case TY_STRUCT:		return "struct";
+	case TY_UNION:		return "union";
+	case TY_ENUM:		return "enum";
+	case TY_U_STRUCT:	return "undefined struct";
+	case TY_U_UNION:	return "undefined union";
+	case TY_U_ENUM:		return "undefined enum";
+	case TY_BITFIELD:	return "bitfield";
+
+	/* Base types (common to C and Fortran */
+	case TY_VOID:		return "void";
+	case TY_CHAR:		return "char";
+	case TY_UCHAR:		return "unsigned char";
+	case TY_SHORT:		return "short";
+	case TY_USHORT:		return "unsigned short";
+	case TY_INT:		return "int";
+	case TY_UINT:		return "unsigned int";
+	case TY_LONG:		return "long";
+	case TY_ULONG:		return "unsigned long";
+	case TY_FLOAT:		return "float";
+	case TY_DOUBLE:		return "double";
+	case TY_INT_ASSUMED:	return "int (assumed)";
+
+	/* Non-standard C types */
+	case TY_LONGLONG:	return "long long";
+	case TY_ULONGLONG:	return "unsigned long long";
+	case TY_LONGDOUBLE:	return "long double";
+	case TY_BOOLEAN:	return "boolean";
+
+	/* FORTRAN base types */
+	case TY_COMPLEX:	return "complex";
+	case TY_DBLCOMP:	return "dblcomp";
+	case TY_LOGICAL:	return "logical";
+	case TY_CHARACTER:	return "character";
+	case TY_FVOID:		return "fvoid";
+	default:		return "unknown type";
+    }
+}
