@@ -11,7 +11,7 @@ static MENU MM1 = {
 	350,
 	55,
 	0,
-	490,
+	0,
 	0,
 	0,
 	0,
@@ -23,7 +23,7 @@ static MENU MM1 = {
 };
 static MENU MM2 = {
 	0x40,
-	0,
+	698,
 	"cut and paste",
 	48,
 	55,
@@ -31,7 +31,7 @@ static MENU MM2 = {
 	350,
 	90,
 	0,
-	559,
+	0,
 	0,
 	0,
 	0,
@@ -51,7 +51,7 @@ static MENU MM3 = {
 	350,
 	90,
 	0,
-	524,
+	0,
 	0,
 	0,
 	0,
@@ -71,7 +71,7 @@ static MENU MM4 = {
 	350,
 	125,
 	0,
-	559,
+	0,
 	0,
 	0,
 	0,
@@ -91,7 +91,7 @@ static MENU MM5 = {
 	588,
 	159,
 	0,
-	697,
+	0,
 	0,
 	0,
 	0,
@@ -103,7 +103,7 @@ static MENU MM5 = {
 };
 static MENU MM6 = {
 	0x40,
-	0,
+	912,
 	"by name",
 	66,
 	316,
@@ -111,7 +111,7 @@ static MENU MM6 = {
 	588,
 	194,
 	0,
-	732,
+	0,
 	0,
 	0,
 	0,
@@ -131,7 +131,7 @@ static MENU MM7 = {
 	588,
 	194,
 	0,
-	628,
+	0,
 	0,
 	0,
 	0,
@@ -143,7 +143,7 @@ static MENU MM7 = {
 };
 static MENU MM8 = {
 	0x40,
-	0,
+	839,
 	"conditional",
 	100,
 	316,
@@ -151,7 +151,7 @@ static MENU MM8 = {
 	588,
 	229,
 	0,
-	628,
+	0,
 	0,
 	0,
 	0,
@@ -171,7 +171,7 @@ static MENU MM9 = {
 	588,
 	264,
 	0,
-	490,
+	0,
 	0,
 	0,
 	0,
@@ -191,7 +191,7 @@ static MENU MM10 = {
 	588,
 	299,
 	0,
-	455,
+	0,
 	0,
 	0,
 	0,
@@ -211,7 +211,7 @@ static MENU MM11 = {
 	588,
 	299,
 	0,
-	490,
+	0,
 	0,
 	0,
 	0,
@@ -231,7 +231,7 @@ static MENU MM12 = {
 	588,
 	299,
 	0,
-	697,
+	0,
 	0,
 	0,
 	0,
@@ -251,7 +251,7 @@ static MENU MM13 = {
 	588,
 	299,
 	0,
-	663,
+	0,
 	0,
 	0,
 	0,
@@ -263,7 +263,7 @@ static MENU MM13 = {
 };
 static MENU MM14 = {
 	0x40,
-	0,
+	802,
 	"auto completion",
 	68,
 	316,
@@ -271,7 +271,7 @@ static MENU MM14 = {
 	588,
 	333,
 	0,
-	213,
+	0,
 	0,
 	0,
 	0,
@@ -283,7 +283,7 @@ static MENU MM14 = {
 };
 static MENU MM15 = {
 	0x40,
-	0,
+	767,
 	"listing matches",
 	69,
 	316,
@@ -291,7 +291,7 @@ static MENU MM15 = {
 	588,
 	368,
 	0,
-	525,
+	0,
 	0,
 	0,
 	0,
@@ -311,7 +311,7 @@ static MENU MM16 = {
 	588,
 	368,
 	0,
-	351,
+	0,
 	0,
 	0,
 	0,
@@ -323,7 +323,7 @@ static MENU MM16 = {
 };
 static MENU MM17 = {
 	0x1040,
-	0,
+	663,
 	"activation",
 	70,
 	316,
@@ -331,7 +331,7 @@ static MENU MM17 = {
 	588,
 	403,
 	0,
-	525,
+	0,
 	0,
 	0,
 	0,
@@ -350,8 +350,8 @@ static MENU MM18 = {
 	403,
 	588,
 	438,
-	0,
-	629,
+	-15992,
+	29285,
 	0,
 	0,
 	0,
@@ -371,7 +371,7 @@ static MENU MM19 = {
 	588,
 	473,
 	0,
-	594,
+	0,
 	0,
 	0,
 	0,
@@ -390,8 +390,8 @@ static MENU MM20 = {
 	403,
 	588,
 	473,
-	0,
-	594,
+	-21,
+	-11,
 	0,
 	0,
 	0,
@@ -411,7 +411,7 @@ static MENU MM21 = {
 	588,
 	473,
 	0,
-	559,
+	0,
 	0,
 	0,
 	0,
@@ -431,7 +431,7 @@ static MENU MM22 = {
 	588,
 	473,
 	0,
-	421,
+	0,
 	0,
 	0,
 	0,
@@ -451,7 +451,7 @@ static MENU MM23 = {
 	588,
 	473,
 	0,
-	628,
+	0,
 	0,
 	0,
 	0,
@@ -471,7 +471,7 @@ static MENU MM24 = {
 	350,
 	159,
 	0,
-	490,
+	0,
 	0,
 	0,
 	0,
@@ -491,7 +491,7 @@ static MENU MM25 = {
 	350,
 	159,
 	0,
-	593,
+	0,
 	0,
 	0,
 	0,
@@ -511,7 +511,7 @@ static MENU MM26 = {
 	350,
 	159,
 	0,
-	490,
+	0,
 	0,
 	0,
 	0,
@@ -531,7 +531,7 @@ static MENU MM27 = {
 	350,
 	194,
 	0,
-	698,
+	0,
 	0,
 	0,
 	0,
@@ -543,15 +543,15 @@ static MENU MM27 = {
 };
 static MENU MM28 = {
 	0x40,
-	0,
+	98,
 	"typing shortcuts",
 	112,
 	55,
 	194,
 	350,
 	229,
+	-15992,
 	0,
-	663,
 	0,
 	0,
 	0,
@@ -571,7 +571,7 @@ static MENU MM29 = {
 	350,
 	229,
 	0,
-	663,
+	0,
 	0,
 	0,
 	0,
@@ -591,7 +591,7 @@ static MENU MM30 = {
 	589,
 	263,
 	0,
-	-13,
+	0,
 	0,
 	0,
 	0,
@@ -603,15 +603,15 @@ static MENU MM30 = {
 };
 static MENU MM31 = {
 	0x40,
-	0,
+	274,
 	"step button",
 	74,
 	319,
 	263,
 	589,
 	298,
-	0,
-	19500,
+	-87,
+	-13,
 	0,
 	0,
 	0,
@@ -651,7 +651,7 @@ static MENU MM33 = {
 	589,
 	332,
 	0,
-	21836,
+	0,
 	0,
 	0,
 	0,
@@ -671,7 +671,7 @@ static MENU MM34 = {
 	589,
 	332,
 	0,
-	13612,
+	0,
 	0,
 	0,
 	0,
@@ -683,7 +683,7 @@ static MENU MM34 = {
 };
 static MENU MM35 = {
 	0x40,
-	0,
+	114,
 	"tags",
 	76,
 	319,
@@ -763,7 +763,7 @@ static MENU MM38 = {
 };
 static MENU MM39 = {
 	0x40,
-	0,
+	49,
 	"RWC Strings",
 	78,
 	319,
@@ -771,7 +771,7 @@ static MENU MM39 = {
 	589,
 	471,
 	0,
-	0,
+	-13,
 	0,
 	0,
 	0,
@@ -825,13 +825,13 @@ static MENU MM42 = {
 	0x404,
 	332,
 	NULL,
-	8252,
+	0,
 	319,
 	229,
 	589,
 	471,
 	0,
-	2382,
+	0,
 	0,
 	0,
 	0,
@@ -851,7 +851,7 @@ static MENU MM43 = {
 	350,
 	263,
 	0,
-	11274,
+	0,
 	0,
 	0,
 	0,
@@ -949,7 +949,7 @@ static MENU MM48 = {
 	303,
 	367,
 	536,
-	401,
+	402,
 	0,
 	0,
 	0,
@@ -967,7 +967,7 @@ static MENU MM49 = {
 	"structures",
 	86,
 	303,
-	401,
+	402,
 	536,
 	436,
 	0,
@@ -983,7 +983,7 @@ static MENU MM49 = {
 };
 static MENU MM50 = {
 	0x4,
-	401,
+	402,
 	NULL,
 	85,
 	303,
@@ -1049,7 +1049,7 @@ static MENU MM53 = {
 	303,
 	471,
 	536,
-	505,
+	506,
 	0,
 	0,
 	0,
@@ -1069,7 +1069,7 @@ static MENU MM54 = {
 	303,
 	436,
 	536,
-	505,
+	506,
 	0,
 	0,
 	0,
@@ -1087,7 +1087,7 @@ static MENU MM55 = {
 	"typedefs",
 	89,
 	303,
-	505,
+	506,
 	536,
 	540,
 	0,
@@ -1122,14 +1122,54 @@ static MENU MM56 = {
 	NULL,
 };
 static MENU MM57 = {
+	0x40,
+	0,
+	"dump memory",
+	97,
+	303,
+	575,
+	536,
+	610,
+	0,
+	0,
+	0,
+	0,
+	0,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+};
+static MENU MM58 = {
+	0x4,
+	575,
+	NULL,
+	90,
+	303,
+	540,
+	536,
+	610,
+	0,
+	0,
+	0,
+	0,
+	0,
+	NULL,
+	&MM56,
+	&MM57,
+	NULL,
+	NULL,
+};
+static MENU MM59 = {
 	0x4,
 	540,
 	NULL,
 	89,
 	303,
-	505,
+	506,
 	536,
-	575,
+	610,
 	0,
 	0,
 	0,
@@ -1137,19 +1177,19 @@ static MENU MM57 = {
 	0,
 	NULL,
 	&MM55,
-	&MM56,
+	&MM58,
 	NULL,
 	NULL,
 };
-static MENU MM58 = {
+static MENU MM60 = {
 	0x4,
-	505,
+	506,
 	NULL,
 	87,
 	303,
 	436,
 	536,
-	575,
+	610,
 	0,
 	0,
 	0,
@@ -1157,19 +1197,19 @@ static MENU MM58 = {
 	0,
 	NULL,
 	&MM54,
-	&MM57,
+	&MM59,
 	NULL,
 	NULL,
 };
-static MENU MM59 = {
+static MENU MM61 = {
 	0x404,
 	436,
 	NULL,
-	25888,
+	0,
 	303,
 	298,
 	536,
-	575,
+	610,
 	0,
 	0,
 	0,
@@ -1177,11 +1217,11 @@ static MENU MM59 = {
 	0,
 	NULL,
 	&MM51,
-	&MM58,
+	&MM60,
 	NULL,
 	NULL,
 };
-static MENU MM60 = {
+static MENU MM62 = {
 	0x240,
 	0,
 	"examing data",
@@ -1196,12 +1236,12 @@ static MENU MM60 = {
 	0,
 	0,
 	NULL,
-	&MM59,
+	&MM61,
 	NULL,
 	NULL,
 	NULL,
 };
-static MENU MM61 = {
+static MENU MM63 = {
 	0x4,
 	298,
 	NULL,
@@ -1217,11 +1257,11 @@ static MENU MM61 = {
 	0,
 	NULL,
 	&MM44,
-	&MM60,
+	&MM62,
 	NULL,
 	NULL,
 };
-static MENU MM62 = {
+static MENU MM64 = {
 	0x4,
 	263,
 	NULL,
@@ -1231,17 +1271,17 @@ static MENU MM62 = {
 	350,
 	333,
 	0,
-	-13,
+	0,
 	0,
 	0,
 	0,
 	NULL,
 	&MM43,
-	&MM61,
+	&MM63,
 	NULL,
 	NULL,
 };
-static MENU MM63 = {
+static MENU MM65 = {
 	0x4,
 	229,
 	NULL,
@@ -1251,17 +1291,17 @@ static MENU MM63 = {
 	350,
 	333,
 	0,
-	525,
+	0,
 	0,
 	0,
 	0,
 	NULL,
 	&MM29,
-	&MM62,
+	&MM64,
 	NULL,
 	NULL,
 };
-static MENU MM64 = {
+static MENU MM66 = {
 	0x4,
 	159,
 	NULL,
@@ -1271,17 +1311,17 @@ static MENU MM64 = {
 	350,
 	333,
 	0,
-	455,
+	0,
 	0,
 	0,
 	0,
 	NULL,
 	&MM26,
-	&MM63,
+	&MM65,
 	NULL,
 	NULL,
 };
-static MENU MM65 = {
+static MENU MM67 = {
 	0x40,
 	0,
 	"editable fields",
@@ -1301,7 +1341,7 @@ static MENU MM65 = {
 	NULL,
 	NULL,
 };
-static MENU MM66 = {
+static MENU MM68 = {
 	0x40,
 	0,
 	"command arguments",
@@ -1321,7 +1361,7 @@ static MENU MM66 = {
 	NULL,
 	NULL,
 };
-static MENU MM67 = {
+static MENU MM69 = {
 	0x4,
 	367,
 	NULL,
@@ -1336,12 +1376,12 @@ static MENU MM67 = {
 	0,
 	0,
 	NULL,
-	&MM65,
-	&MM66,
+	&MM67,
+	&MM68,
 	NULL,
 	NULL,
 };
-static MENU MM68 = {
+static MENU MM70 = {
 	0x40,
 	0,
 	"custom menu",
@@ -1361,7 +1401,7 @@ static MENU MM68 = {
 	NULL,
 	NULL,
 };
-static MENU MM69 = {
+static MENU MM71 = {
 	0x40,
 	0,
 	"init file",
@@ -1381,7 +1421,7 @@ static MENU MM69 = {
 	NULL,
 	NULL,
 };
-static MENU MM70 = {
+static MENU MM72 = {
 	0x4,
 	437,
 	NULL,
@@ -1396,12 +1436,12 @@ static MENU MM70 = {
 	0,
 	0,
 	NULL,
-	&MM68,
-	&MM69,
+	&MM70,
+	&MM71,
 	NULL,
 	NULL,
 };
-static MENU MM71 = {
+static MENU MM73 = {
 	0x4,
 	402,
 	NULL,
@@ -1416,12 +1456,12 @@ static MENU MM71 = {
 	0,
 	0,
 	NULL,
-	&MM67,
-	&MM70,
+	&MM69,
+	&MM72,
 	NULL,
 	NULL,
 };
-static MENU MM72 = {
+static MENU MM74 = {
 	0x40,
 	0,
 	"attach / detach",
@@ -1441,7 +1481,7 @@ static MENU MM72 = {
 	NULL,
 	NULL,
 };
-static MENU MM73 = {
+static MENU MM75 = {
 	0x40,
 	0,
 	"resizing windows",
@@ -1461,7 +1501,7 @@ static MENU MM73 = {
 	NULL,
 	NULL,
 };
-static MENU MM74 = {
+static MENU MM76 = {
 	0x4,
 	506,
 	NULL,
@@ -1476,12 +1516,12 @@ static MENU MM74 = {
 	0,
 	0,
 	NULL,
-	&MM72,
-	&MM73,
+	&MM74,
+	&MM75,
 	NULL,
 	NULL,
 };
-static MENU MM75 = {
+static MENU MM77 = {
 	0x40,
 	0,
 	"signals",
@@ -1501,7 +1541,7 @@ static MENU MM75 = {
 	NULL,
 	NULL,
 };
-static MENU MM76 = {
+static MENU MM78 = {
 	0x40,
 	0,
 	"ups version",
@@ -1521,7 +1561,7 @@ static MENU MM76 = {
 	NULL,
 	NULL,
 };
-static MENU MM77 = {
+static MENU MM79 = {
 	0x40,
 	0,
 	"`step' action",
@@ -1541,7 +1581,7 @@ static MENU MM77 = {
 	NULL,
 	NULL,
 };
-static MENU MM78 = {
+static MENU MM80 = {
 	0x4,
 	611,
 	NULL,
@@ -1556,12 +1596,12 @@ static MENU MM78 = {
 	0,
 	0,
 	NULL,
-	&MM76,
-	&MM77,
+	&MM78,
+	&MM79,
 	NULL,
 	NULL,
 };
-static MENU MM79 = {
+static MENU MM81 = {
 	0x40,
 	0,
 	"scrollbars",
@@ -1581,7 +1621,7 @@ static MENU MM79 = {
 	NULL,
 	NULL,
 };
-static MENU MM80 = {
+static MENU MM82 = {
 	0x40,
 	0,
 	"assembler",
@@ -1601,7 +1641,7 @@ static MENU MM80 = {
 	NULL,
 	NULL,
 };
-static MENU MM81 = {
+static MENU MM83 = {
 	0x40,
 	0,
 	"authors",
@@ -1621,7 +1661,7 @@ static MENU MM81 = {
 	NULL,
 	NULL,
 };
-static MENU MM82 = {
+static MENU MM84 = {
 	0x4,
 	720,
 	NULL,
@@ -1636,12 +1676,12 @@ static MENU MM82 = {
 	0,
 	0,
 	NULL,
-	&MM80,
-	&MM81,
+	&MM82,
+	&MM83,
 	NULL,
 	NULL,
 };
-static MENU MM83 = {
+static MENU MM85 = {
 	0x4,
 	684,
 	NULL,
@@ -1656,16 +1696,16 @@ static MENU MM83 = {
 	0,
 	0,
 	NULL,
-	&MM79,
-	&MM82,
+	&MM81,
+	&MM84,
 	NULL,
 	NULL,
 };
-static MENU MM84 = {
+static MENU MM86 = {
 	0x404,
 	647,
 	NULL,
-	11632,
+	0,
 	312,
 	575,
 	558,
@@ -1676,12 +1716,12 @@ static MENU MM84 = {
 	0,
 	0,
 	NULL,
-	&MM78,
-	&MM83,
+	&MM80,
+	&MM85,
 	NULL,
 	NULL,
 };
-static MENU MM85 = {
+static MENU MM87 = {
 	0x240,
 	0,
 	"miscellaneous",
@@ -1696,12 +1736,12 @@ static MENU MM85 = {
 	0,
 	0,
 	NULL,
-	&MM84,
+	&MM86,
 	NULL,
 	NULL,
 	NULL,
 };
-static MENU MM86 = {
+static MENU MM88 = {
 	0x40,
 	0,
 	"append text",
@@ -1721,7 +1761,7 @@ static MENU MM86 = {
 	NULL,
 	NULL,
 };
-static MENU MM87 = {
+static MENU MM89 = {
 	0x40,
 	0,
 	"always clear",
@@ -1741,11 +1781,11 @@ static MENU MM87 = {
 	NULL,
 	NULL,
 };
-static MENU MM88 = {
+static MENU MM90 = {
 	0x404,
 	645,
 	NULL,
-	28533,
+	0,
 	309,
 	611,
 	582,
@@ -1756,12 +1796,12 @@ static MENU MM88 = {
 	0,
 	0,
 	NULL,
-	&MM86,
-	&MM87,
+	&MM88,
+	&MM89,
 	NULL,
 	NULL,
 };
-static MENU MM89 = {
+static MENU MM91 = {
 	0x240,
 	0,
 	"help window",
@@ -1776,12 +1816,12 @@ static MENU MM89 = {
 	0,
 	0,
 	NULL,
-	&MM88,
+	&MM90,
 	NULL,
 	NULL,
 	NULL,
 };
-static MENU MM90 = {
+static MENU MM92 = {
 	0x4,
 	610,
 	NULL,
@@ -1796,12 +1836,12 @@ static MENU MM90 = {
 	0,
 	0,
 	NULL,
-	&MM85,
-	&MM89,
+	&MM87,
+	&MM91,
 	NULL,
 	NULL,
 };
-static MENU MM91 = {
+static MENU MM93 = {
 	0x4,
 	575,
 	NULL,
@@ -1816,12 +1856,12 @@ static MENU MM91 = {
 	0,
 	0,
 	NULL,
-	&MM75,
-	&MM90,
+	&MM77,
+	&MM92,
 	NULL,
 	NULL,
 };
-static MENU MM92 = {
+static MENU MM94 = {
 	0x4,
 	541,
 	NULL,
@@ -1836,12 +1876,12 @@ static MENU MM92 = {
 	0,
 	0,
 	NULL,
-	&MM74,
-	&MM91,
+	&MM76,
+	&MM93,
 	NULL,
 	NULL,
 };
-static MENU MM93 = {
+static MENU MM95 = {
 	0x4,
 	471,
 	NULL,
@@ -1856,16 +1896,16 @@ static MENU MM93 = {
 	0,
 	0,
 	NULL,
-	&MM71,
-	&MM92,
+	&MM73,
+	&MM94,
 	NULL,
 	NULL,
 };
-static MENU MM94 = {
+static MENU MM96 = {
 	0x404,
 	333,
 	NULL,
-	28261,
+	0,
 	55,
 	21,
 	350,
@@ -1876,12 +1916,12 @@ static MENU MM94 = {
 	0,
 	0,
 	NULL,
-	&MM64,
-	&MM93,
+	&MM66,
+	&MM95,
 	NULL,
 	NULL,
 };
-static MENU MM95 = {
+static MENU MM97 = {
 	0x2260,
 	0,
 	"Help",
@@ -1890,18 +1930,18 @@ static MENU MM95 = {
 	-1,
 	76,
 	32,
-	-15992,
-	29285,
+	0,
+	0,
 	0,
 	0,
 	0,
 	NULL,
-	&MM94,
+	&MM96,
 	NULL,
 	NULL,
 	NULL,
 };
-static MENU MM96 = {
+static MENU MM98 = {
 	0x40,
 	0,
 	"Backwards",
@@ -1921,7 +1961,7 @@ static MENU MM96 = {
 	NULL,
 	NULL,
 };
-static MENU MM97 = {
+static MENU MM99 = {
 	0x40,
 	0,
 	"Forwards",
@@ -1941,11 +1981,11 @@ static MENU MM97 = {
 	NULL,
 	NULL,
 };
-static MENU MM98 = {
+static MENU MM100 = {
 	0x408,
 	134,
 	NULL,
-	19813,
+	0,
 	2,
 	0,
 	291,
@@ -1956,12 +1996,12 @@ static MENU MM98 = {
 	0,
 	0,
 	NULL,
-	&MM96,
-	&MM97,
+	&MM98,
+	&MM99,
 	NULL,
 	NULL,
 };
-static MENU MM99 = {
+static MENU MM101 = {
 	0x260,
 	0,
 	"Search",
@@ -1976,12 +2016,12 @@ static MENU MM99 = {
 	0,
 	0,
 	NULL,
-	&MM98,
+	&MM100,
 	NULL,
 	NULL,
 	NULL,
 };
-static MENU MM100 = {
+static MENU MM102 = {
 	0x8,
 	76,
 	NULL,
@@ -1990,18 +2030,18 @@ static MENU MM100 = {
 	-1,
 	194,
 	32,
-	-15992,
+	0,
 	0,
 	0,
 	0,
 	0,
 	NULL,
-	&MM95,
-	&MM99,
+	&MM97,
+	&MM101,
 	NULL,
 	NULL,
 };
-static MENU MM101 = {
+static MENU MM103 = {
 	0x40,
 	0,
 	"Selected object",
@@ -2021,7 +2061,7 @@ static MENU MM101 = {
 	NULL,
 	NULL,
 };
-static MENU MM102 = {
+static MENU MM104 = {
 	0x40,
 	0,
 	"All objects",
@@ -2041,7 +2081,7 @@ static MENU MM102 = {
 	NULL,
 	NULL,
 };
-static MENU MM103 = {
+static MENU MM105 = {
 	0x4,
 	50,
 	NULL,
@@ -2056,12 +2096,12 @@ static MENU MM103 = {
 	0,
 	0,
 	NULL,
-	&MM101,
-	&MM102,
+	&MM103,
+	&MM104,
 	NULL,
 	NULL,
 };
-static MENU MM104 = {
+static MENU MM106 = {
 	0x40,
 	0,
 	"msg logging on",
@@ -2081,7 +2121,7 @@ static MENU MM104 = {
 	NULL,
 	NULL,
 };
-static MENU MM105 = {
+static MENU MM107 = {
 	0x40,
 	0,
 	"msg logging off",
@@ -2101,7 +2141,7 @@ static MENU MM105 = {
 	NULL,
 	NULL,
 };
-static MENU MM106 = {
+static MENU MM108 = {
 	0x4,
 	114,
 	NULL,
@@ -2116,16 +2156,16 @@ static MENU MM106 = {
 	0,
 	0,
 	NULL,
-	&MM104,
-	&MM105,
+	&MM106,
+	&MM107,
 	NULL,
 	NULL,
 };
-static MENU MM107 = {
+static MENU MM109 = {
 	0x404,
 	82,
 	NULL,
-	29281,
+	0,
 	249,
 	19,
 	551,
@@ -2136,12 +2176,12 @@ static MENU MM107 = {
 	0,
 	0,
 	NULL,
-	&MM103,
-	&MM106,
+	&MM105,
+	&MM108,
 	NULL,
 	NULL,
 };
-static MENU MM108 = {
+static MENU MM110 = {
 	0x2260,
 	0,
 	"Snapshot",
@@ -2156,12 +2196,12 @@ static MENU MM108 = {
 	0,
 	0,
 	NULL,
-	&MM107,
+	&MM109,
 	NULL,
 	NULL,
 	NULL,
 };
-static MENU MM109 = {
+static MENU MM111 = {
 	0x40,
 	0,
 	"cancel",
@@ -2181,7 +2221,7 @@ static MENU MM109 = {
 	NULL,
 	NULL,
 };
-static MENU MM110 = {
+static MENU MM112 = {
 	0x40,
 	0,
 	"confirm",
@@ -2201,11 +2241,11 @@ static MENU MM110 = {
 	NULL,
 	NULL,
 };
-static MENU MM111 = {
+static MENU MM113 = {
 	0x404,
 	49,
 	NULL,
-	8269,
+	0,
 	415,
 	19,
 	574,
@@ -2216,12 +2256,12 @@ static MENU MM111 = {
 	0,
 	0,
 	NULL,
-	&MM109,
-	&MM110,
+	&MM111,
+	&MM112,
 	NULL,
 	NULL,
 };
-static MENU MM112 = {
+static MENU MM114 = {
 	0x2260,
 	0,
 	"Quit",
@@ -2236,12 +2276,12 @@ static MENU MM112 = {
 	0,
 	0,
 	NULL,
-	&MM111,
+	&MM113,
 	NULL,
 	NULL,
 	NULL,
 };
-static MENU MM113 = {
+static MENU MM115 = {
 	0x8,
 	336,
 	NULL,
@@ -2256,8 +2296,8 @@ static MENU MM113 = {
 	0,
 	0,
 	NULL,
-	&MM108,
-	&MM112,
+	&MM110,
+	&MM114,
 	NULL,
 	NULL,
 };
@@ -2265,7 +2305,7 @@ MENU cmd_men = {
 	0x408,
 	194,
 	NULL,
-	23562,
+	0,
 	-1,
 	-1,
 	415,
@@ -2276,8 +2316,8 @@ MENU cmd_men = {
 	0,
 	0,
 	NULL,
-	&MM100,
-	&MM113,
+	&MM102,
+	&MM115,
 	NULL,
 	NULL,
 };
