@@ -10,8 +10,8 @@ static MENU MM1 = {
 	-1,
 	35,
 	26,
-	-13216,
-	24940,
+	0,
+	25972,
 	0,
 	0,
 	0,
@@ -30,8 +30,8 @@ static MENU MM2 = {
 	-1,
 	72,
 	26,
-	-13216,
-	28192,
+	0,
+	11619,
 	0,
 	0,
 	0,
@@ -50,8 +50,8 @@ static MENU MM3 = {
 	-1,
 	72,
 	26,
-	-13216,
-	2643,
+	0,
+	8284,
 	0,
 	0,
 	0,
@@ -63,15 +63,15 @@ static MENU MM3 = {
 };
 static MENU MM4 = {
 	0x40,
-	0,
+	306,
 	"::",
 	121,
 	72,
 	-1,
 	109,
 	26,
-	-13216,
-	26656,
+	0,
+	8224,
 	0,
 	0,
 	0,
@@ -91,7 +91,7 @@ static MENU MM5 = {
 	325,
 	45,
 	-13216,
-	25455,
+	24931,
 	0,
 	0,
 	0,
@@ -110,8 +110,8 @@ static MENU MM6 = {
 	45,
 	325,
 	75,
-	-13216,
-	28261,
+	257,
+	0,
 	0,
 	0,
 	0,
@@ -122,16 +122,36 @@ static MENU MM6 = {
 	NULL,
 };
 static MENU MM7 = {
-	0x40,
+	0x4,
+	45,
+	NULL,
+	69,
+	180,
+	15,
+	325,
+	75,
+	-13216,
+	24942,
 	0,
+	0,
+	0,
+	NULL,
+	&MM5,
+	&MM6,
+	NULL,
+	NULL,
+};
+static MENU MM8 = {
+	0x40,
+	4,
 	"Static Members",
 	83,
 	180,
 	75,
 	325,
-	106,
-	-13216,
-	28192,
+	105,
+	2,
+	4,
 	0,
 	0,
 	0,
@@ -141,47 +161,67 @@ static MENU MM7 = {
 	NULL,
 	NULL,
 };
-static MENU MM8 = {
-	0x4,
-	75,
-	NULL,
-	121,
-	180,
-	45,
-	325,
-	106,
-	-13216,
-	29305,
-	0,
-	0,
-	0,
-	NULL,
-	&MM6,
-	&MM7,
-	NULL,
-	NULL,
-};
 static MENU MM9 = {
+	0x40,
+	0,
+	"Dump Memory",
+	87,
+	180,
+	105,
+	325,
+	135,
+	4,
+	50,
+	0,
+	0,
+	0,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+};
+static MENU MM10 = {
+	0x4,
+	105,
+	NULL,
+	83,
+	180,
+	75,
+	325,
+	135,
+	0,
+	258,
+	0,
+	0,
+	0,
+	NULL,
+	&MM8,
+	&MM9,
+	NULL,
+	NULL,
+};
+static MENU MM11 = {
 	0x404,
-	45,
+	75,
 	NULL,
 	0,
 	180,
 	15,
 	325,
-	106,
+	135,
 	-23,
 	-11,
 	0,
 	0,
 	0,
 	NULL,
-	&MM5,
-	&MM8,
+	&MM7,
+	&MM10,
 	NULL,
 	NULL,
 };
-static MENU MM10 = {
+static MENU MM12 = {
 	0x2260,
 	0,
 	"Expand",
@@ -190,18 +230,18 @@ static MENU MM10 = {
 	-1,
 	203,
 	26,
-	-13216,
-	30066,
+	0,
+	18533,
 	0,
 	0,
 	0,
 	NULL,
-	&MM9,
+	&MM11,
 	NULL,
 	NULL,
 	NULL,
 };
-static MENU MM11 = {
+static MENU MM13 = {
 	0x8,
 	109,
 	NULL,
@@ -210,18 +250,18 @@ static MENU MM11 = {
 	-1,
 	203,
 	26,
-	-13216,
-	26982,
+	0,
+	25977,
 	0,
 	0,
 	0,
 	NULL,
 	&MM4,
-	&MM10,
+	&MM12,
 	NULL,
 	NULL,
 };
-static MENU MM12 = {
+static MENU MM14 = {
 	0x8,
 	72,
 	NULL,
@@ -230,18 +270,18 @@ static MENU MM12 = {
 	-1,
 	203,
 	26,
-	-13216,
 	0,
+	8224,
 	0,
 	0,
 	0,
 	NULL,
 	&MM3,
-	&MM11,
+	&MM13,
 	NULL,
 	NULL,
 };
-static MENU MM13 = {
+static MENU MM15 = {
 	0x40,
 	0,
 	"First level",
@@ -250,8 +290,8 @@ static MENU MM13 = {
 	14,
 	417,
 	42,
-	-13216,
-	29285,
+	0,
+	87,
 	0,
 	0,
 	0,
@@ -261,7 +301,7 @@ static MENU MM13 = {
 	NULL,
 	NULL,
 };
-static MENU MM14 = {
+static MENU MM16 = {
 	0x40,
 	0,
 	"Completely",
@@ -270,8 +310,8 @@ static MENU MM14 = {
 	42,
 	417,
 	71,
-	-13216,
-	24931,
+	0,
+	84,
 	0,
 	0,
 	0,
@@ -281,7 +321,7 @@ static MENU MM14 = {
 	NULL,
 	NULL,
 };
-static MENU MM15 = {
+static MENU MM17 = {
 	0x404,
 	42,
 	NULL,
@@ -296,12 +336,12 @@ static MENU MM15 = {
 	0,
 	0,
 	NULL,
-	&MM13,
-	&MM14,
+	&MM15,
+	&MM16,
 	NULL,
 	NULL,
 };
-static MENU MM16 = {
+static MENU MM18 = {
 	0x2260,
 	0,
 	"Collapse",
@@ -310,18 +350,18 @@ static MENU MM16 = {
 	-1,
 	314,
 	26,
-	-13216,
-	8276,
+	4,
+	48,
 	0,
 	0,
 	0,
 	NULL,
-	&MM15,
+	&MM17,
 	NULL,
 	NULL,
 	NULL,
 };
-static MENU MM17 = {
+static MENU MM19 = {
 	0x40,
 	0,
 	"Dup",
@@ -330,48 +370,8 @@ static MENU MM17 = {
 	-1,
 	371,
 	26,
-	-13216,
-	25957,
 	0,
-	0,
-	0,
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-};
-static MENU MM18 = {
-	0x8,
-	314,
-	NULL,
-	63,
-	203,
-	-1,
-	371,
-	26,
-	-13216,
-	28276,
-	0,
-	0,
-	0,
-	NULL,
-	&MM16,
-	&MM17,
-	NULL,
-	NULL,
-};
-static MENU MM19 = {
-	0x40,
-	0,
-	"Del",
-	107,
-	371,
-	-1,
-	436,
-	26,
-	-13216,
-	28259,
+	514,
 	0,
 	0,
 	0,
@@ -382,36 +382,36 @@ static MENU MM19 = {
 	NULL,
 };
 static MENU MM20 = {
-	0x40,
-	0,
-	"Decimal",
-	84,
-	342,
+	0x8,
+	314,
+	NULL,
 	63,
-	435,
-	88,
+	203,
+	-1,
+	371,
+	26,
 	0,
-	25955,
+	123,
 	0,
 	0,
 	0,
 	NULL,
-	NULL,
-	NULL,
+	&MM18,
+	&MM19,
 	NULL,
 	NULL,
 };
 static MENU MM21 = {
 	0x40,
 	0,
-	"Octal",
-	79,
-	342,
-	88,
-	435,
-	114,
+	"Del",
+	107,
+	371,
+	-1,
+	436,
+	26,
+	0,
 	0,
-	28483,
 	0,
 	0,
 	0,
@@ -422,36 +422,36 @@ static MENU MM21 = {
 	NULL,
 };
 static MENU MM22 = {
-	0x4,
-	88,
-	NULL,
+	0x40,
+	4,
+	"Decimal",
 	84,
 	342,
 	63,
 	435,
-	114,
+	88,
 	0,
-	29485,
+	2,
 	0,
 	0,
 	0,
 	NULL,
-	&MM20,
-	&MM21,
+	NULL,
+	NULL,
 	NULL,
 	NULL,
 };
 static MENU MM23 = {
 	0x40,
-	0,
-	"Hex",
-	72,
+	4,
+	"Octal",
+	79,
 	342,
-	114,
+	88,
 	435,
-	139,
+	114,
 	0,
-	2592,
+	257,
 	0,
 	0,
 	0,
@@ -462,16 +462,36 @@ static MENU MM23 = {
 	NULL,
 };
 static MENU MM24 = {
+	0x4,
+	88,
+	NULL,
+	84,
+	342,
+	63,
+	435,
+	114,
+	4,
+	99,
+	0,
+	0,
+	0,
+	NULL,
+	&MM22,
+	&MM23,
+	NULL,
+	NULL,
+};
+static MENU MM25 = {
 	0x40,
 	0,
-	"Binary",
-	66,
+	"Hex",
+	72,
 	342,
-	139,
+	114,
 	435,
-	165,
+	139,
 	0,
-	8284,
+	257,
 	0,
 	0,
 	0,
@@ -481,7 +501,27 @@ static MENU MM24 = {
 	NULL,
 	NULL,
 };
-static MENU MM25 = {
+static MENU MM26 = {
+	0x40,
+	0,
+	"Binary",
+	66,
+	342,
+	139,
+	435,
+	165,
+	1,
+	-60,
+	0,
+	0,
+	0,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+};
+static MENU MM27 = {
 	0x4,
 	139,
 	NULL,
@@ -491,17 +531,17 @@ static MENU MM25 = {
 	435,
 	165,
 	0,
-	25977,
+	257,
 	0,
 	0,
 	0,
 	NULL,
-	&MM23,
-	&MM24,
+	&MM25,
+	&MM26,
 	NULL,
 	NULL,
 };
-static MENU MM26 = {
+static MENU MM28 = {
 	0x404,
 	114,
 	NULL,
@@ -510,18 +550,18 @@ static MENU MM26 = {
 	63,
 	435,
 	165,
-	-13216,
-	12868,
+	0,
+	-432,
 	0,
 	0,
 	0,
 	NULL,
-	&MM22,
-	&MM25,
+	&MM24,
+	&MM27,
 	NULL,
 	NULL,
 };
-static MENU MM27 = {
+static MENU MM29 = {
 	0x260,
 	0,
 	"Unsigned",
@@ -530,18 +570,18 @@ static MENU MM27 = {
 	31,
 	434,
 	59,
-	-13216,
-	25185,
+	0,
+	64,
 	0,
 	0,
 	0,
 	NULL,
-	&MM26,
+	&MM28,
 	NULL,
 	NULL,
 	NULL,
 };
-static MENU MM28 = {
+static MENU MM30 = {
 	0x40,
 	0,
 	"Decimal",
@@ -551,47 +591,7 @@ static MENU MM28 = {
 	525,
 	89,
 	0,
-	23662,
-	0,
-	0,
-	0,
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-};
-static MENU MM29 = {
-	0x40,
-	0,
-	"Octal",
-	111,
-	432,
-	89,
-	525,
-	114,
-	0,
-	25955,
-	0,
-	0,
-	0,
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-};
-static MENU MM30 = {
-	0x40,
-	0,
-	"Hex",
-	104,
-	432,
-	114,
-	525,
-	139,
-	0,
-	28734,
+	513,
 	0,
 	0,
 	0,
@@ -602,6 +602,46 @@ static MENU MM30 = {
 	NULL,
 };
 static MENU MM31 = {
+	0x40,
+	0,
+	"Octal",
+	111,
+	432,
+	89,
+	525,
+	114,
+	0,
+	0,
+	0,
+	0,
+	0,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+};
+static MENU MM32 = {
+	0x40,
+	1,
+	"Hex",
+	104,
+	432,
+	114,
+	525,
+	139,
+	0,
+	0,
+	0,
+	0,
+	0,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+};
+static MENU MM33 = {
 	0x4,
 	114,
 	NULL,
@@ -611,37 +651,37 @@ static MENU MM31 = {
 	525,
 	139,
 	0,
-	25189,
+	0,
 	0,
 	0,
 	0,
 	NULL,
-	&MM29,
-	&MM30,
+	&MM31,
+	&MM32,
 	NULL,
 	NULL,
 };
-static MENU MM32 = {
+static MENU MM34 = {
 	0x404,
 	89,
 	NULL,
-	26482,
+	0,
 	432,
 	64,
 	525,
 	139,
 	0,
-	25956,
+	513,
 	0,
 	0,
 	0,
 	NULL,
-	&MM28,
-	&MM31,
+	&MM30,
+	&MM33,
 	NULL,
 	NULL,
 };
-static MENU MM33 = {
+static MENU MM35 = {
 	0x260,
 	0,
 	"Signed",
@@ -651,17 +691,17 @@ static MENU MM33 = {
 	525,
 	59,
 	0,
-	25956,
+	3,
 	0,
 	0,
 	0,
 	NULL,
-	&MM32,
+	&MM34,
 	NULL,
 	NULL,
 	NULL,
 };
-static MENU MM34 = {
+static MENU MM36 = {
 	0x40,
 	0,
 	"Default",
@@ -671,7 +711,7 @@ static MENU MM34 = {
 	636,
 	88,
 	0,
-	30309,
+	0,
 	0,
 	0,
 	0,
@@ -681,7 +721,7 @@ static MENU MM34 = {
 	NULL,
 	NULL,
 };
-static MENU MM35 = {
+static MENU MM37 = {
 	0x40,
 	0,
 	"Ascii",
@@ -691,49 +731,9 @@ static MENU MM35 = {
 	636,
 	114,
 	0,
-	8224,
 	0,
 	0,
 	0,
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-	NULL,
-};
-static MENU MM36 = {
-	0x4,
-	88,
-	NULL,
-	110,
-	525,
-	62,
-	636,
-	114,
-	0,
-	8284,
-	0,
-	0,
-	0,
-	NULL,
-	&MM34,
-	&MM35,
-	NULL,
-	NULL,
-};
-static MENU MM37 = {
-	0x40,
-	0,
-	"String",
-	115,
-	525,
-	114,
-	636,
-	140,
-	0,
-	25972,
-	0,
-	0,
 	0,
 	NULL,
 	NULL,
@@ -742,6 +742,46 @@ static MENU MM37 = {
 	NULL,
 };
 static MENU MM38 = {
+	0x4,
+	88,
+	NULL,
+	110,
+	525,
+	62,
+	636,
+	114,
+	0,
+	0,
+	0,
+	0,
+	0,
+	NULL,
+	&MM36,
+	&MM37,
+	NULL,
+	NULL,
+};
+static MENU MM39 = {
+	0x40,
+	0,
+	"String",
+	115,
+	525,
+	114,
+	636,
+	140,
+	0,
+	0,
+	0,
+	0,
+	0,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+	NULL,
+};
+static MENU MM40 = {
 	0x40,
 	0,
 	"RWCstring",
@@ -751,7 +791,7 @@ static MENU MM38 = {
 	636,
 	167,
 	0,
-	11619,
+	0,
 	0,
 	0,
 	0,
@@ -761,7 +801,7 @@ static MENU MM38 = {
 	NULL,
 	NULL,
 };
-static MENU MM39 = {
+static MENU MM41 = {
 	0x4,
 	140,
 	NULL,
@@ -771,37 +811,37 @@ static MENU MM39 = {
 	636,
 	167,
 	0,
-	25977,
+	0,
 	0,
 	0,
 	0,
 	NULL,
-	&MM37,
-	&MM38,
+	&MM39,
+	&MM40,
 	NULL,
 	NULL,
 };
-static MENU MM40 = {
+static MENU MM42 = {
 	0x404,
 	114,
 	NULL,
-	10868,
+	0,
 	525,
 	62,
 	636,
 	167,
 	0,
-	8224,
+	0,
 	0,
 	0,
 	0,
 	NULL,
-	&MM36,
-	&MM39,
+	&MM38,
+	&MM41,
 	NULL,
 	NULL,
 };
-static MENU MM41 = {
+static MENU MM43 = {
 	0x260,
 	0,
 	"Other",
@@ -811,17 +851,17 @@ static MENU MM41 = {
 	616,
 	59,
 	0,
-	18533,
+	-158,
 	0,
 	0,
 	0,
 	NULL,
-	&MM40,
+	&MM42,
 	NULL,
 	NULL,
 	NULL,
 };
-static MENU MM42 = {
+static MENU MM44 = {
 	0x8,
 	525,
 	NULL,
@@ -830,38 +870,38 @@ static MENU MM42 = {
 	31,
 	616,
 	59,
-	0,
-	25460,
+	1,
+	-236,
 	0,
 	0,
 	0,
 	NULL,
-	&MM33,
-	&MM41,
+	&MM35,
+	&MM43,
 	NULL,
 	NULL,
 };
-static MENU MM43 = {
+static MENU MM45 = {
 	0x408,
 	434,
 	NULL,
-	22377,
+	0,
 	344,
 	31,
 	616,
 	59,
-	-13216,
-	24942,
+	0,
+	38,
 	0,
 	0,
 	0,
 	NULL,
-	&MM27,
-	&MM42,
+	&MM29,
+	&MM44,
 	NULL,
 	NULL,
 };
-static MENU MM44 = {
+static MENU MM46 = {
 	0x260,
 	0,
 	"Format",
@@ -870,18 +910,18 @@ static MENU MM44 = {
 	-1,
 	527,
 	26,
-	-13216,
-	24931,
+	0,
+	957,
 	0,
 	0,
 	0,
 	NULL,
-	&MM43,
+	&MM45,
 	NULL,
 	NULL,
 	NULL,
 };
-static MENU MM45 = {
+static MENU MM47 = {
 	0x40,
 	0,
 	"Use typedefs",
@@ -891,7 +931,7 @@ static MENU MM45 = {
 	742,
 	49,
 	0,
-	28252,
+	0,
 	0,
 	0,
 	0,
@@ -901,7 +941,7 @@ static MENU MM45 = {
 	NULL,
 	NULL,
 };
-static MENU MM46 = {
+static MENU MM48 = {
 	0x40,
 	0,
 	"Ignore typedefs",
@@ -911,7 +951,7 @@ static MENU MM46 = {
 	742,
 	75,
 	0,
-	20079,
+	0,
 	0,
 	0,
 	0,
@@ -921,11 +961,11 @@ static MENU MM46 = {
 	NULL,
 	NULL,
 };
-static MENU MM47 = {
+static MENU MM49 = {
 	0x404,
 	49,
 	NULL,
-	28533,
+	0,
 	600,
 	24,
 	742,
@@ -936,12 +976,12 @@ static MENU MM47 = {
 	0,
 	0,
 	NULL,
-	&MM45,
-	&MM46,
+	&MM47,
+	&MM48,
 	NULL,
 	NULL,
 };
-static MENU MM48 = {
+static MENU MM50 = {
 	0x3260,
 	0,
 	"Decl",
@@ -951,17 +991,17 @@ static MENU MM48 = {
 	600,
 	26,
 	0,
-	21306,
+	0,
 	0,
 	0,
 	0,
 	NULL,
-	&MM47,
+	&MM49,
 	NULL,
 	NULL,
 	NULL,
 };
-static MENU MM49 = {
+static MENU MM51 = {
 	0x8,
 	527,
 	NULL,
@@ -970,18 +1010,18 @@ static MENU MM49 = {
 	-1,
 	600,
 	26,
-	-13216,
-	28526,
+	0,
+	514,
 	0,
 	0,
 	0,
 	NULL,
-	&MM44,
-	&MM48,
+	&MM46,
+	&MM50,
 	NULL,
 	NULL,
 };
-static MENU MM50 = {
+static MENU MM52 = {
 	0x8,
 	436,
 	NULL,
@@ -990,18 +1030,18 @@ static MENU MM50 = {
 	-1,
 	600,
 	26,
-	-13216,
-	12320,
+	0,
+	222,
 	0,
 	0,
 	0,
 	NULL,
-	&MM19,
-	&MM49,
+	&MM21,
+	&MM51,
 	NULL,
 	NULL,
 };
-static MENU MM51 = {
+static MENU MM53 = {
 	0x8,
 	371,
 	NULL,
@@ -1010,14 +1050,14 @@ static MENU MM51 = {
 	-1,
 	600,
 	26,
-	-13216,
-	30062,
+	0,
+	257,
 	0,
 	0,
 	0,
 	NULL,
-	&MM18,
-	&MM50,
+	&MM20,
+	&MM52,
 	NULL,
 	NULL,
 };
@@ -1025,19 +1065,19 @@ MENU var_men = {
 	0x408,
 	203,
 	NULL,
-	2313,
+	0,
 	-1,
 	-1,
 	600,
 	26,
 	0,
-	0,
+	30309,
 	0,
 	0,
 	0,
 	NULL,
-	&MM12,
-	&MM51,
+	&MM14,
+	&MM53,
 	NULL,
 	NULL,
 };
