@@ -7,11 +7,13 @@
  *  unaltered copy of this message (including the copyright).
  */
 
-/* @(#)obj_buildf.h	1.8 13/8/92 (UKC) */
+/* @(#)obj_buildf.h	1.9 12/22/93 (UKC) */
 
 void do_formats PROTO((bool have_window));
 void close_target_display PROTO((void));
-objid_t rebuild_display PROTO((proc_t proc));
 void update_variable_values PROTO((void));
-void initialise_display_area PROTO((const char *textname, const char *corename,
-				    const char *args, int have_common_blocks));
+
+#ifdef TARGET_H_INCLUDED
+void initialise_display_area PROTO((target_t *xp, const char *args, bool use_full_path));
+objid_t rebuild_display PROTO((target_t *xp));
+#endif
