@@ -28,8 +28,7 @@ char ups_obj_env_c_sccsid[] = "@(#)obj_env.c	1.15 09 Apr 1995 (UKC)";
 #include "menudata.h"
 #include "tdr.h"
 
-/* Linux <stdlib.h> already has 'environ'. */
-#if defined(OS_LINUX) || !defined(__USE_MISC)
+#if !HAVE_DEFINED_ENVIRON
 extern const char **environ;
 #endif
 
