@@ -17,7 +17,6 @@ char ups_obj_misc_c_sccsid[] = "@(#)obj_misc.c	1.26 04 Jun 1995 (UKC)";
 #include <sys/param.h>		/* for MAXPATHLEN */
 #include <sys/stat.h>
 #include <sys/utsname.h>
-#include <errno.h>
 
 #ifdef __STDC__
 #include <unistd.h>
@@ -26,9 +25,7 @@ char ups_obj_misc_c_sccsid[] = "@(#)obj_misc.c	1.26 04 Jun 1995 (UKC)";
 #include <varargs.h>
 #endif
 
-#include <stdio.h>
 #include <stdlib.h>
-#include <string.h>
 
 #include <local/wn.h>
 #include <local/ukcprog.h>
@@ -445,8 +442,8 @@ src_cmp2(obj1, obj2)
 		       ((fil_t *)obj2)->fi_flags & FI_DUPLICATE))
     return 1;
  if (!strs_differ && 
-      ((fil_t *)obj1)->fi_flags & FI_HIDE_ENTRY == 0 &&
-      ((fil_t *)obj2)->fi_flags & FI_HIDE_ENTRY == 0)
+      (((fil_t *)obj1)->fi_flags & FI_HIDE_ENTRY) == 0 &&
+      (((fil_t *)obj2)->fi_flags & FI_HIDE_ENTRY) == 0)
     ((fil_t *)obj2)->fi_flags |= FI_HIDE_ENTRY;
   return strs_differ;
 }
