@@ -76,18 +76,23 @@ static sig_info_t Sigtab[] = {
 	{ SIGUSR1,	"SIGUSR1",					      },
 	{ SIGUSR2,	"SIGUSR2",					      },
 	{ SIGCHLD,	"SIGCHLD",	SGH_DFL_IGNORE | SGH_CONT | SGH_ACCEPT},
-#ifdef SIGPWR
+#if defined (SIGPWR)
 	{ SIGPWR,	"SIGPWR",	SGH_DFL_IGNORE | SGH_CONT | SGH_ACCEPT},
 #endif
-#ifdef SIGWINCH
+#if defined (SIGWINCH)
 	{ SIGWINCH,	"SIGWINCH",	SGH_DFL_IGNORE | SGH_CONT | SGH_ACCEPT},
 #endif
 	{ SIGURG,	"SIGURG",	SGH_DFL_IGNORE | SGH_CONT | SGH_ACCEPT},
-#if defined(SIGPOLL) && (defined(OS_SVR4) || !defined(SIGIO) || SIGPOLL != SIGIO)
+#if defined(SIGPOLL) && defined(SIGIO) && (SIGPOLL == SIGIO)
+	/* SIGPOLL same as SIGIO, prefer SIGPOLL */
+	{ SIGPOLL,	"SIGPOLL",	SGH_CONT | SGH_ACCEPT		      },
+#else
+#if defined(SIGPOLL)
 	{ SIGPOLL,	"SIGPOLL",	SGH_CONT | SGH_ACCEPT		      },
 #endif
-#if defined(SIGIO) && (!defined(OS_SVR4) || !defined(SIGPOLL) || SIGPOLL != SIGIO)
+#if defined(SIGIO)
 	{ SIGIO,	"SIGIO",	SGH_DFL_IGNORE | SGH_CONT | SGH_ACCEPT},
+#endif
 #endif
 	{ SIGSTOP,	"SIGSTOP",	SGH_DFL_STOPS			      },
 	{ SIGTSTP,	"SIGTSTP",	SGH_DFL_STOPS | SGH_CONT | SGH_ACCEPT },
@@ -116,10 +121,7 @@ static sig_info_t Sigtab[] = {
 #ifdef SIGTHAW
 	{ SIGTHAW,	"SIGTHAW",					      },
 #endif
-#ifdef OS_LINUX /* RGA linux merge */
-	/*	{ SIG31,	"SIG31",					      },*/
-	/*	{ SIG32,	"SIG32",					      },*/
-	{ SIGPWR,	"SIGPWR",					      },
+#if defined (SIGUNUSED)
 	{ SIGUNUSED,	"SIGUNUSED",					      },
 #endif
 };
