@@ -31,12 +31,14 @@ char ups_obj_stack_c_sccsid[] = "@(#)obj_stack.c	1.21 20 Jun 1995 (UKC)";
 #include "ups.h"
 #include "symtab.h"
 #include "ao_syms.h"
+#include "srcwin.h"
 #include "st.h"
 #include "target.h"
 #include "obj_stack.h"
 #include "data.h"
 #include "ui.h"
 #include "va.h"
+#include "expr.h"
 #include "obj_signal.h"
 #include "obj_misc.h"
 #include "menudata.h"
@@ -1253,7 +1255,7 @@ back_iterate_over_stack_files(sw_id, name, startpos, limpos)
 	stk1 = stk1->stk_inner;
      }
       if (!skip && show_global
-	  (sw_id, stk->stk_func->fu_fil, (fil_t*)NULL,
+	  ((Srcwin *)sw_id, stk->stk_func->fu_fil, (func_t*)NULL,
 	   (common_block_t *)NULL,
 	   name, TRUE, FALSE, FALSE, (objid_t *)NULL, TRUE))
 	return TRUE;
