@@ -260,10 +260,10 @@ char *arg;
 		  td_restore_replay_fp();
 		}
 #ifdef AO_TARGET
-#if defined(OS_SUNOS_4) || defined(OS_BSD44)
+#if defined(AO_AOUT_SHLIBS)
 		unload_shared_library_symtabs(get_current_target());
 		load_shared_library_symtabs(get_current_target(), TRUE);
-#endif /* OS_SUNOS_4 or OS_BSD44 */
+#endif /* AO_AOUT_SHLIBS */
 		rescan_dynamic_solibs(get_current_target());
 		if (can_get_target_vars(get_current_target()))
 		  refresh_target_display(get_current_target(), SR_BPT, FALSE);
