@@ -7,6 +7,7 @@
  *  unaltered copy of this message (including the copyright).
  */
 
-/* @(#)printf.h	1.3 4/7/91 (UKC) */
+/* @(#)printf.h	1.4 12/22/93 (UKC) */
 
-ci_exec_result_t ups_printf PROTO((proc_t proc, code_id_t code_id, taddr_t *args, int nargs));
+ci_exec_result_t ups_printf PROTO((target_t *xp, machine_t *machine,
+						taddr_t *args, int nargs));
