@@ -111,7 +111,7 @@ static void set_coloring PROTO((Highlighting *hl, Edit_buffer *buffer,
 				size_t start, size_t lim, Edit_flags flagmask,
 				Edit_flags flags));
 static void init_outwin PROTO((Outwin *ow, int wn, tbar_id_t tbar,
-			       Edit_buffer *buffer));
+			       Edit_buffer *buffer, int fold_lines));
 static bool set_point PROTO((Outwin *ow, size_t point, Region *region, 
                              char *data));
 static size_t update_ow_tbar PROTO((Outwin *ow, bool set_pos));
@@ -193,7 +193,7 @@ tbar_id_t tbar;
 	Edit_keymap *keymap;
 
 	sw = (Srcwin *)e_malloc(sizeof(Srcwin));
-	init_outwin(&sw->outwin, wn, tbar, (Edit_buffer *)NULL);
+	init_outwin(&sw->outwin, wn, tbar, (Edit_buffer *)NULL, TRUE); /* folded lines */
 	sw->fil = NULL;
 	sw->hist = NULL;
 	
@@ -284,7 +284,7 @@ tbar_id_t tbar;
 	buffer = edit_create_buffer(tb, Srcfont_info, 0);
 	
 	ow = (Outwin *)e_malloc(sizeof(Outwin));
-	init_outwin(ow, wn, tbar, buffer);
+	init_outwin(ow, wn, tbar, buffer, TRUE); /* Folded lines */
 
 	ow->next = All_windows;
 	All_windows = ow;
@@ -293,11 +293,12 @@ tbar_id_t tbar;
 }
 
 static void
-init_outwin(ow, wn, tbar, buffer)
+init_outwin(ow, wn, tbar, buffer, fold_lines)
 Outwin *ow;
 int wn;
 tbar_id_t tbar;
 Edit_buffer *buffer;
+int fold_lines;
 {
 	Edit_display *display;
 
@@ -308,9 +309,30 @@ Edit_buffer *buffer;
 		display = edit_create_wn_display(wn, WN_FG, WN_BG,
 						 FALSE, FALSE);
 
+		/*
+		**  RCB ( 4/15/99):
+		**   There seems to be a bug in the redraw code if lines
+		**   are folded and the top most displayed line is the
+		**   tail end of a folded line.  Streching the window
+		**   to un-fold the lines leaves the top most displayed
+		**   line unchanged.  A subsequent scroll gets into an
+		**   infinite loop.  Rather than track down the bug, I
+		**   turned off the line folding for the output window.
+		**
+		**   On the other hand, not folding lines in the source display
+		**   messes up the highlighting of the highlighting of the
+		**   active line.
+		**
+		**  RGA ( 6/17/99):
+		**   Restored the folded lines for the output window.
+		**   Eliminated the infinite loop by setting the window to
+		**   the top when resizing, then restoring the postion
+		**   after the redraw. See code in srcwin_draw() and 
+		**   outwin_draw().
+		*/
 		edit_use_folded_lines(display, Tabspaces, Want_display_checks,
-				      TRUE); /* folded lines */
-	
+				      fold_lines);
+
 		if (buffer != NULL)
 			edit_set_buffer(display, buffer);
 	}
@@ -390,6 +412,7 @@ Srcwin *sw;
 const char *pattern;
 bool forwards;
 {
+  if (sw->outwin.buffer != NULL)
 	outwin_search(&sw->outwin, pattern, forwards);
 }
 
@@ -1039,6 +1062,17 @@ bool set_pos;
 	return start;
 }
 
+size_t
+outwin_get_pos(ow)
+Outwin *ow;
+{
+	size_t start, lim;
+	int pixel_offset;
+	
+	edit_get_display_info(ow->display, &pixel_offset, &start, &lim);
+	return start;
+}
+
 void
 outwin_insert(ow, text, len)
 Outwin *ow;
@@ -1093,6 +1127,25 @@ int ch;
 	outwin_insert(ow, &c, 1);
 }
 
+size_t
+srcwin_get_pos(sw)
+Srcwin *sw;
+{
+	size_t start, lim;
+	int pixel_offset;
+	
+	edit_get_display_info(sw->outwin.display, &pixel_offset, &start, &lim);
+	return start;
+}
+
+void
+srcwin_goto_point(sw, point)
+Srcwin *sw;
+size_t point;
+{
+	edit_display_from(sw->outwin.display, 0, point);
+}
+
 int
 srcwin_scroll(sw, npixels)
 Srcwin *sw;
