@@ -378,6 +378,8 @@ global_list_t **p_glhead;
 {
 	symtab_t *st;
 	int wants_stop = 0;
+        cursor_t old_cursor = wn_get_window_cursor(WN_STDWIN);
+	set_bm_cursor(WN_STDWIN, CU_WAIT);
 
 	/*  First search the source files of all the symbol tables.
 	 */
@@ -456,8 +458,10 @@ global_list_t **p_glhead;
 			    wants_stop = 1;
 		}
 	}
-	
-	update_target_menu_state(xp_get_state(xp), xp_is_attached(xp));
+
+	if (target_menu_search_disabled(0, 0) == FALSE)
+	  update_target_menu_state(xp_get_state(xp), xp_is_attached(xp));
+	wn_define_cursor(WN_STDWIN, old_cursor);
 	if (matchfil == NULL && filename == NULL &&
 	    !have_exact_match(*p_glhead, varname)) {
 		/*  Not found under any source file, so search the
@@ -619,6 +623,10 @@ bool all_syms;
 	xp = get_current_target();
 
 	st = NULL;
+	/*
+	**  RCB: Don't do blocking cursor here.
+	**       There may not be any windows set up yet.
+	*/
 	update_target_menu_state(TS_SEARCHING, xp_is_attached(xp));
 	stop_pressed(0, 1);	/* reset */
 	while (xp_next_symtab(xp, st,
@@ -634,7 +642,8 @@ bool all_syms;
 				      filename_len, funcpat, funcname,
 				      p_glhead);
 	}
-	update_target_menu_state(xp_get_state(xp), xp_is_attached(xp));
+	if (target_menu_search_disabled(0, 0) == FALSE)
+	  update_target_menu_state(xp_get_state(xp), xp_is_attached(xp));
 }
 					
 int
@@ -1096,12 +1105,13 @@ iterate_over_source_files(func, arg)
 void (*func)PROTO((fil_t *fil, bool arg));
 bool arg;
 {
-	static bool first_call = TRUE;
+	static bool first_call = TRUE, call_level = 0;
 	target_t *xp;
 	symtab_t *st;
 	fil_t *fil;
-	cursor_t old_cursor = NULL;
+	cursor_t old_cursor = (cursor_t)NULL;
 
+	call_level++;
 	xp = get_current_target();
 	st = NULL;
 
@@ -1112,7 +1122,7 @@ bool arg;
 	}
 	while (xp_next_symtab(xp, st, TRUE, &st)) {
 		for (fil = st->st_sfiles; fil != NULL; fil = fil->fi_next) {
-		  if (first_call)
+		  if (first_call && call_level == 1)
 		    scan_elf_dot_o_file_symtab(fil);
 		  if ((fil->fi_flags & FI_HIDE_ENTRY) == 0)
 		    (*func)(fil, arg);
@@ -1121,6 +1131,7 @@ bool arg;
 	if (first_call)
 	  wn_define_cursor(WN_STDWIN, old_cursor);
 	first_call = FALSE;
+	call_level--;
 }
 
 /*  Call (*func)(cblock) for each common block.
@@ -1193,13 +1204,13 @@ int cmp_style;
 			     fl != NULL;
 			     fl = fl->fl_next) {
 				if (arg_match(fl->fl_func->fu_demangled_name, funcpat)) {
-				  func_bp_list_t *fl;
+				  func_bp_list_t *fl2;
 				  
-				  fl = new_func_bp_list();
-				  fl->fl_func = f;
-				  fl->fl_bp = 0;
-				  fl->fl_next = *funchead;
-				  *funchead = fl;
+				  fl2 = new_func_bp_list();
+				  fl2->fl_func = f;
+				  fl2->fl_bp = 0;
+				  fl2->fl_next = *funchead;
+				  *funchead = fl2;
 				}
 			}
 		}
@@ -1269,7 +1280,7 @@ func_bp_list_t **funchead;
   }
 
   /* RGA append "*" to C++ names like "array<array<int> *>::" ... */
-  if (*s == '\0' || (c = strchr(name, ':')) != NULL && c[1] == ':') {
+  if (*s == '\0' || ((c = strchr(name, ':')) != NULL && c[1] == ':')) {
     namecopy = strf("%s*", funcname);
     globname = namecopy;
   }
