@@ -294,6 +294,7 @@ const char *text;
 	static const char display_global[] = "%g "; 
 	static const char add_brkpoint[] = "%b ";
 	static const char list_file[] = "%l ";
+	static const char dump_mem[] = "%d";
 
 
 	/*  Ignore a zero length string.
@@ -354,6 +355,10 @@ const char *text;
 	    else
 		 errf("\bNo Source File", finame);
 	}
+	else if (strncmp(text, dump_mem, sizeof(dump_mem) - 1) == 0)
+	{
+	    dump_memory(text);
+	}
 	else if (*text == '/' || *text == '?') {
 	    srcwin_search(get_current_srcwin(), text+1, *text == '/');
 	}
@@ -714,3 +719,121 @@ char **p_string;
 	return 0;
 }
 
+/*
+**   Dump target memory to the output window and/or file.
+**   Syntax of command line
+**
+**     %d[size] address [ length | .. end_address ]
+**
+**       size : b for bytes, s for shorts, l for longs, or omit.
+**              if omitted, byte or short will be selected based on
+**		target endianness.
+**
+*/
+void dump_memory (text)
+const char* text;
+{
+    static short default_grp = 0x0201;  /* Actually, a char[2] */
+    char buffer[100];
+    taddr_t addr;
+    int length = 16;
+    int grp;
+    int parse_error = FALSE;
+    int read_error = FALSE;
+    const char* t = text;
+    char* tt;
+    target_t * xp = get_current_target();
+    if ( xp == NULL || !can_get_target_vars(xp))
+    {
+	errf("Target not running");
+	return;
+    }
+
+    /*  Parse the command line */
+    t += 2;  /* skip %d */
+    switch (*t++)
+    {
+    case 'b':
+       grp = 1; break;
+    case 's':
+       grp = 2; break;
+    case 'l':
+       grp = 4; break;
+    case ' ':
+       grp = *(char*)&default_grp; break;
+    default:
+       parse_error = TRUE; break;
+    }
+    while (*t == ' ')
+	t++;
+    if ( !parse_error)
+    {
+	if ( t[0] == '0' && (t[1] == 'x' || t[1] == 'X'))
+	    t+=2;
+	parse_error = (0==sscanf(t,"%lx",&addr));
+	while (isxdigit(*t))
+	   t++;
+    }
+    while (*t == ' ')
+	t++;
+    if (*t && !parse_error)
+    {
+	if ( t[0] == '.' && t[1] == '.')
+	{
+	    taddr_t end_addr;
+	    t+= 2;
+	    while (*t == ' ')
+		t++;
+	    if ( t[0] == '0' && (t[1] == 'x' || t[1] == 'X'))
+		t+=2;
+	    parse_error = (0==sscanf(t,"%lx",&end_addr));
+	    while (isxdigit(*t))
+		t++;
+	    if ( t == tt || end_addr <= addr)
+		parse_error = TRUE;
+	    length = end_addr - addr;
+	} else if (isxdigit(*t))
+	{
+	    while (*t == ' ')
+		t++;
+	    if ( t[0] == '0' && (t[1] == 'x' || t[1] == 'X'))
+	    {
+		t+=2;
+	        parse_error = (0==sscanf(t,"%x",&length));
+		while (isxdigit(*t))
+		    t++;
+	    }else
+	    {
+	        parse_error = (0==sscanf(t,"%u",&length));
+		while (isdigit(*t))
+		    t++;
+	    }
+	} else
+	    parse_error = TRUE;
+    }
+    while (*t == ' ')
+	t++;
+
+
+    /*  Write the command to the output */
+    outwin_insert_string(text);
+    outwin_insert_string("\n");
+
+    if (parse_error)
+    {
+	outwin_insert_string("Invalid %d command\n");
+	return;
+    }
+    while(length && !read_error)
+    {
+	int len = length;
+	if ( len > 16)
+	    len = 16;
+	read_error = dump_to_buffer (xp, addr, len, grp, buffer);
+	outwin_insert_string(buffer);
+	length -= len;
+	addr += len;
+    }
+}
+
+
