@@ -1507,8 +1507,19 @@ int wn;
 int width, height;
 re_draw_reason_t draw_reason;
 {
-	if (draw_reason == RE_EXPOSED || draw_reason == RE_RESIZED)
-		outwin_redraw((Outwin *)re_get_data(region));
+    Outwin *ow;
+    size_t pos = 0;
+
+    ow = (Outwin *)re_get_data(region);
+    if (draw_reason == RE_RESIZED)
+    {
+	pos = outwin_get_pos(ow);
+	outwin_goto_point_and_update(ow, 0); /* set to beginning */
+    }
+    if (draw_reason == RE_EXPOSED || draw_reason == RE_RESIZED)
+	outwin_redraw(ow);
+    if (draw_reason == RE_RESIZED)
+	outwin_goto_point_and_update(ow, pos); /* restore original position */
 }
 
 static void
@@ -1518,8 +1529,19 @@ int wn;
 int width, height;
 re_draw_reason_t draw_reason;
 {
-	if (draw_reason == RE_EXPOSED || draw_reason == RE_RESIZED)
-		srcwin_redraw((Srcwin *)re_get_data(region));
+    Srcwin *sw;
+    size_t pos = 0;
+
+    sw = (Srcwin *)re_get_data(region);
+    if (draw_reason == RE_RESIZED)
+    {
+	pos = srcwin_get_pos(sw);
+	srcwin_goto_point(sw, 0); /* set to beginning */
+    }
+    if (draw_reason == RE_EXPOSED || draw_reason == RE_RESIZED)
+	srcwin_redraw(sw);
+    if (draw_reason == RE_RESIZED)
+	srcwin_goto_point(sw, pos);	/* restore original position */
 }
 
 static void
