@@ -73,7 +73,6 @@ static bool show_source_no_record PROTO((fil_t *fil, int lnum));
 static void null_ofunc PROTO((const char *s));
 
 /* { Stuff added by RCB */
-/*#include <unistd.h>*/
 
 static void
 call_editor( si, lnum)
@@ -596,10 +595,24 @@ int lnum;
 	int found = 0, *this_obj_var,
 	this_obj_exists = 0, mangled = 0;
 	errf_ofunc_t oldf = NULL;
-	
+	language_t fi_language;
+
 	display = srcwin_get_display(sw);
 	buffer = edit_get_buffer(display);
-	
+
+	/* RGA file may be preprocessed, so look at parent to guess at
+	   underlying language.
+	   */
+	fi_language = fil->fi_language;
+	if (fi_language == LANG_UNKNOWN &&
+	    (fil->fi_flags & FI_RENAMED_OTHER) &&
+	    fil->fi_next)
+	  fi_language = fil->fi_next->fi_language;
+	if (fi_language == LANG_UNKNOWN)
+	  fi_language = get_user_lang();
+	if (fi_language == LANG_UNKNOWN)
+	  fi_language = get_mainfunc_lang();
+
 	if (edit_find_char_backwards(buffer, sel_point, 0, pat, &start))
 		++start;
 	edit_find_char_forwards(buffer, sel_point, EDIT_MAX_POINT, pat, &lim);
@@ -610,7 +623,7 @@ int lnum;
 
 		vartext = edit_copy_bytes(buffer, start, lim, (char *)NULL);
 
-		if ( get_varname(fil->fi_language, vartext,
+		if ( get_varname(fi_language, vartext,
 				vartext + (sel_point - start),
 				&lstart, &llim) &&
 		     /* RCB: check for and ignore click on common breakpoint text */
@@ -638,7 +651,7 @@ int lnum;
 	    /*  f77 maps all upper case variable names to
 	     *  lower case, so follow suit.
 	     */
-	    if (IS_FORTRAN(fil->fi_language)) {
+	    if (IS_FORTRAN(fi_language)) {
 	      char *cptr;
 		
 	      for (cptr = text; *cptr != '\0'; ++cptr)	
@@ -649,9 +662,9 @@ int lnum;
 	    td_record_show_var(fil, lnum, text);
 
 	    /* RGA for mangled C++ names */
-	    if (fil->fi_language == LANG_CC
+	    if (fi_language == LANG_CC
 		|| get_user_lang() == LANG_CC
-		|| (fil->fi_language == LANG_UNKNOWN &&
+		|| (fi_language == LANG_UNKNOWN &&
 		    get_mainfunc_lang() == LANG_CC))
 	    {
 	      /* suppress error messages for all except last try */
