@@ -83,6 +83,7 @@ static bool statedir_exists PROTO((const char *state_dir));
 static void set_special_edit_chars PROTO((Edit_keymap *keymap));
 static void add_keymap_entry PROTO((Edit_keymap *keymap, unsigned modifiers,
 				    int ch, Edit_function func));
+static void quit_ups PROTO((void));
 
 unsigned long Debug_flags = 0;
 
@@ -95,6 +96,16 @@ const char *s;
 	Done_panic = TRUE;
 }
 
+static void
+quit_ups()
+{
+  extern MENU tgt_stop_men;
+
+  if (Mselectable(&tgt_stop_men))
+    target_stop();
+  re_set_exit_event_loop_flag();
+}
+
 /*  This routine is called when we get a signal that causes a core dump.
  *  We want to avoid overwriting an existing core file in the current
  *  directory because that may be from the target and thus precious to
@@ -767,6 +778,9 @@ setup_display()
 
 	set_special_edit_chars(edit_get_default_keymap());
 	
+	wn_set_quit_func(quit_ups);
+	wn_set_cur_posn_func(get_cur_posn);
+	wn_set_overlay_insert_string_func(display_area_overlay_insert_string);
 	return 0;
 }
 
@@ -906,7 +920,7 @@ bool attach;
 	func_t *f, *f1;
 	const char *basepath, *state_path, *user_path;
 	bool file_want_auto_start;
-	int res;
+	int res, file_access = -1;
 	symtab_t *st;
 		
  	td_set_no_window_flag();
@@ -1046,5 +1060,9 @@ bool attach;
 	if (target_process_exists(xp))
 		kill_or_detach_from_target(xp);
 
+	if ((file_access = access(get_temp_bpt_filename(), O_RDONLY)) != -1)
+	  if (unlink(get_temp_bpt_filename()) != 0)
+	    errf("Can't unlink `%s'", get_temp_bpt_filename());
+
 	return res;
 }
