@@ -39,7 +39,7 @@ static const char *c_mkdecl PROTO((const char *name, type_t *type,
                                    bool hide_ptr, bool want_typedefs,
 				   short *ul_start));
 static const char *fortran_mkdecl PROTO((const char *name, type_t *type, 
-					 ilist_t *ilist));
+					 ilist_t *ilist, short *ul_start));
 
 ALLOC_NEW_FREELIST(extern,ilist_t,ilist,il_next)
 
@@ -297,10 +297,11 @@ char *buf;
 }
 
 static const char *
-fortran_mkdecl(name, vartype, ilist)
+fortran_mkdecl(name, vartype, ilist, ul_start)
 const char *name;
 type_t *vartype;
 ilist_t *ilist;
+short *ul_start;
 {
 	static char bufs[2][256];
 	int cur;
@@ -447,6 +448,8 @@ ilist_t *ilist;
 		sprintf(bufs[1 - cur], "%s%s %s",
                         fortran_basetype_name(type), pointer_tag, bufs[cur]);
 	}
+	if (ul_start)
+		*ul_start = strlen (bufs[1 - cur]) - strlen(bufs[cur]);
 	
 	return bufs[1 - cur];
 }
@@ -464,6 +467,10 @@ type_t *type;
 	if (type->ty_code != TY_STRUCT)
 		return type->ty_name;
 	
+	/* GNU f77 produces typedef's in symbol table. */
+	if ((type->ty_typedef != NULL) && (type->ty_typedef->td_name != NULL))
+		return type->ty_typedef->td_name;
+
 	if ((tag = type->ty_aggr_or_enum->ae_tag) == NULL)
 		tag = "<UNKNOWN>";
 
@@ -491,7 +498,7 @@ bool want_typedefs;
 
 	case LANG_F77:
 	case LANG_F90:
-		return fortran_mkdecl(name, type, (ilist_t *)NULL);
+		return fortran_mkdecl(name, type, (ilist_t *)NULL, 0);
 
 	default:
 		panic("unknown lang in ttd");
@@ -525,7 +532,8 @@ dvar_t *dv;
 				&dv->dv_ul_start);
 	case LANG_F77:
 	case LANG_F90:
-		return fortran_mkdecl(v->va_name, v->va_type, dv->dv_ilist);
+		return fortran_mkdecl(v->va_name, v->va_type, dv->dv_ilist,
+				      &dv->dv_ul_start);
 		
 	default:
 		panic("unknown language in mkdecl");
