@@ -42,7 +42,7 @@ char ups_va_edit_c_sccsid[] = "@(#)va_edit.c	1.31 04 Jun 1995 (UKC)";
 double strtod();
 #endif
 
-#if (defined(__GNUC__) && !defined (OS_SUNOS_4)) || defined(HAVE_LONG_LONG)
+#if HAVE_LONG_LONG
 typedef unsigned long long	largeint;
 #else
 typedef unsigned long		largeint;
@@ -922,7 +922,7 @@ bool *p_done_mesg;
 	case TY_FLOAT:
 		res = DWRITE_VAR(xp, addr, value.vl_float);
 		break;
-#if (defined(__GNUC__) && !defined (OS_SUNOS_4)) || defined(HAVE_LONG_DOUBLE)
+#if HAVE_LONG_DOUBLE
  	case TY_LONGDOUBLE:
  		res = DWRITE_VAR(xp, addr, value.vl_longdouble);
  		break;
@@ -934,7 +934,7 @@ bool *p_done_mesg;
 	case TY_ULONG:
 		res = DWRITE_VAR(xp, addr, value.vl_long);
 		break;
-#if (defined(__GNUC__) && !defined (OS_SUNOS_4)) || defined(HAVE_LONG_LONG)
+#if HAVE_LONG_LONG
  	case TY_LONGLONG:
  	case TY_ULONGLONG:
  		res = DWRITE_VAR(xp, addr, value.vl_longlong);
@@ -1162,7 +1162,7 @@ vformat_t *p_vformat;
 			res = -1;
 		break;
 
-#if (defined(__GNUC__) && !defined (OS_SUNOS_4)) || defined(HAVE_LONG_LONG)
+#if HAVE_LONG_LONG
 	case TY_LONGLONG:
 	case TY_ULONGLONG:
 		if (get_integer(vstr, &val, p_vformat, boolean) == 0)
