@@ -75,6 +75,8 @@ static bool is_hex_digit PROTO((int c));
 static void inc_exprnum PROTO((Edit_display *display));
 static void dec_exprnum PROTO((Edit_display *display));
 static void adjust_expr_number PROTO((Edit_display *display, bool up));
+static void dump_de_to_outwin PROTO((dexpr_t* de));
+
 
 /*char Expr_format[] = "%[-]60cx%[-]30cs\n";*/
 /* RGA use elastic format ... */
@@ -605,6 +607,9 @@ char *arg;
 	case MR_VAR_SHOW_STATICS:
 	        expand_statics(de->de_type);
 		break;
+	case MR_VAR_DUMP_TO_OUTWIN:
+		dump_de_to_outwin(de);
+		break;
 	case MR_VAR_DUP:
 		add_to_new_selection((objid_t)dup_dexpr(de));
 	    	note_var_change((objid_t)de);
@@ -988,7 +993,7 @@ ci_exec_result_t res;
 		strcpy(buf, get_real(xp->xp_words_big_endian, vl, FALSE,
 				     sizeof (double)));
 		break;
-#if (defined(__GNUC__) && !defined (OS_SUNOS_4)) || defined(HAVE_LONG_DOUBLE)
+#if HAVE_LONG_DOUBLE
  	case TY_LONGDOUBLE:
  		strcpy(buf, get_real(xp->xp_words_big_endian, vl, FALSE,
  				     sizeof (long double)));
@@ -1067,3 +1072,60 @@ taddr_t *p_res;
 	
 	return CI_ER_CONTINUE;
 }
+
+static void dump_de_to_outwin(de)
+dexpr_t *de;
+{
+    char buff[80];
+    type_t *type  = de->de_type;
+    int length = 0;
+    char grpchar = ' ';
+    taddr_t addr = de->de_value.vl_addr;
+
+    if (   type->ty_code != DT_PTR_TO)
+    {
+	errf("Can only dump pointer expressions");
+	return;
+    }
+    type = type->ty_base;
+
+    if ( IS_BASIC_TYPE(type->ty_code)
+	    || type->ty_code == TY_NOTYPE)    /* For void */
+    {
+	length = 256;
+	switch (ci_typesize(NULL, type))
+	{
+	case 1:
+	    grpchar = 'b'; break;
+	case 2:
+	    grpchar = 's'; break;
+	case 4:
+	case 8:
+	case 10: /* for long doubles */
+	    grpchar = 'l'; break;
+	default:
+	    grpchar = ' '; break;
+	}
+    }
+    else
+    {
+	length = ci_typesize(NULL, type);
+	if (length < 0 )
+	    length = 16;
+	switch (type->ty_code)
+	{
+	case DT_PTR_TO:
+	case DT_FUNC_RETURNING:
+	case DT_ARRAY_OF:
+	case TY_U_ENUM:
+	    grpchar = 'l';
+	    break;
+	default:
+            break;
+	}
+    }
+
+    sprintf(buff,"%%d%c %lx %d", grpchar,addr,length);
+    dump_memory (buff);
+}
+
