@@ -487,7 +487,7 @@ const char** format_spec;
      if ( dv_format != DF_NONE )
         alloc_special(identifier, len, typecode, dv_format);
      *format_spec = format;
-};
+}
 
 static void parse_format_string()
 {
@@ -674,6 +674,13 @@ bool restoring;
 	}
 
 	dv = new_dvar();
+	/* Dibyendu 26/12/98 
+	 * Unnamed bitfields do not set the name.
+	 * This caused UPS to fail when debugging interpeter programs
+	 * containing unnamed bitfields.
+	 */
+	if (v->va_name == NULL)
+		v->va_name = "unnamed";
 	dv->dv_var = v;
 	dv->dv_ilevel = default_level(v->va_type, v->va_language);
 	dv->dv_ilist = make_ilist(v->va_type, v->va_language, dv->dv_ilevel);
@@ -1014,6 +1021,7 @@ type_t* type;
     if ( !found)
 	errf("No static members");
 }
+
 taddr_t
 expand_hierarchy(obj, type)
 objid_t obj;
@@ -1067,6 +1075,90 @@ type_t* type;
     return vtbl_addr;
 }
 
+static void dump_dv_to_outwin(dv)
+dvar_t* dv;
+{
+    char buff[80];
+    var_t* v = dv->dv_var;
+    type_t* type  = get_type_at_level(v, dv->dv_ilevel );
+    taddr_t addr = addr = dvar_addr(dv);
+    int length = 0;
+    char grpchar = ' ';
+
+
+
+    if (   type->ty_code == DT_PTR_TO)
+    {
+	/*  For a pointer, Get the address pointed to */
+	taddr_t addr2;
+	target_t* xp = get_current_target();
+	if (dread(xp, addr, (char *)&addr2, sizeof(addr)) == 0)
+	    addr = addr2;
+
+	/* and the type pointed to */
+	type = type->ty_base;
+	if (   IS_BASIC_TYPE(type->ty_code)
+	    || type->ty_code == TY_NOTYPE)    /* For void */
+	    length = 256;
+    } else if ( dv->dv_ilevel )
+    {
+	/*  If the object is an array element, dump to the end of the array */
+	type_t* atype  = get_type_at_level(v, dv->dv_ilevel-1);
+	if ( atype->ty_code == DT_ARRAY_OF)
+	{
+	    int array_size = ci_typesize(NULL, atype);
+	    ilist_t *il = dv->dv_ilist;
+	    int i = dv->dv_ilevel;
+	    while (--i )
+		il = il->il_next;
+	    if ( il->il_low_known)
+	        length = array_size
+			 -ci_typesize(NULL, type)*(il->il_index-il->il_low);
+	} else if ( dv->dv_format == DF_STRING)
+	{
+	    length = 256;
+	}
+    }
+
+    if ( length <= 0)
+    {
+        length = ci_typesize(NULL, type);
+	if (length <= 0 )
+	    length = 16;
+    }
+
+    /*   Decide whether to group the data as bytes, shorts, or longs */
+    if ( IS_BASIC_TYPE(type->ty_code))
+    {
+	switch (ci_typesize(NULL, type))
+	{
+	case 1:
+	    grpchar = 'b'; break;
+	case 2:
+	case 10: /* for long doubles */
+	    grpchar = 's'; break;
+	case 4:
+	case 8:
+	    grpchar = 'l'; break;
+	default:
+	    break;
+	}
+    } else switch (type->ty_code)
+    {
+    case DT_PTR_TO:
+    case DT_FUNC_RETURNING:
+    case DT_ARRAY_OF:
+    case TY_U_ENUM:
+	grpchar = 'l';
+	break;
+    default:
+        break;
+    }
+
+    sprintf(buff,"%%d%c %lx %d", grpchar,addr,length);
+    dump_memory (buff);
+}
+
 /*  Process the return from a var menu.
  */
 static void
@@ -1269,6 +1361,9 @@ char *arg;
 	case MR_VAR_SHOW_STATICS:
 	        expand_statics(deref_aggr(dv));
 		break;
+	case MR_VAR_DUMP_TO_OUTWIN:
+		dump_dv_to_outwin(dv);
+		break;
 	case MR_VAR_DUP:
 		dv2 = new_dvar();
 		*dv2 = *dv;
