@@ -202,6 +202,7 @@ vformat_t format;
 		int_to_string(buf, bufsize, (vlong)addr, format);
 	}
 }
+
 static void
 vtbl_to_string(buf, bufsize, addr, type, format)
 char *buf;
@@ -214,7 +215,7 @@ vformat_t format;
     const char* name = lookup_global_name(addr, &offset);
     if ( name )
     {
-	char* dmangle = demangle_name_3(name);
+	char* dmangle = demangle_name_3((char *)name);
 	if ( dmangle)
 	{
 	    strncpy(buf, dmangle, bufsize-1);
@@ -242,6 +243,101 @@ vformat_t format;
 	addr_to_string(buf, bufsize, addr, type, format);
 }
 
+#if HAVE_LONG_LONG
+/* Compiler supports 'long long', does 'sprintf()' ? */
+#if defined LONG_LONG_FMT
+# define VLONG_FMT LONG_LONG_FMT
+# define sprintf_ll sprintf
+#else
+# define VLONG_FMT ""
+#endif
+#else
+/* Compiler does not support 'long long'. */
+# define VLONG_FMT "l"
+# define sprintf_ll sprintf
+#endif
+
+/*
+**  Some compilers handle long longs fine but can't print them.
+**  This routine simulates sprintf(buf, fmt, n) for that case. (RCB)
+*/
+#if !defined sprintf_ll
+static void sprintf_ll(char* buf, const char* fmt, vlong n)
+{
+#define MAX_PTEN (1+(sizeof(unsigned long long)*8*3)/10)
+#define MAX_PEIGHT (1+sizeof(unsigned long long)*8/3)
+    static unsigned long long powers_of_ten[MAX_PTEN];
+    static unsigned long long powers_of_eight[MAX_PEIGHT];
+    unsigned long long* power_table;
+    int base;
+    int max_power;
+    int exp;
+
+
+    unsigned long long nn = (unsigned long long)n;
+    unsigned long long power;
+    while (*fmt != '%')
+       *buf++ = *fmt++;
+    switch(*++fmt)
+    {
+    case 'd':
+	if ( n < 0 )
+	{
+	    nn = -n;
+	    *buf++ = '-';
+	}
+	/* Fall into unsigned case */
+
+    case 'u':
+	base = 10;
+	power_table = powers_of_ten;
+	max_power = MAX_PTEN;
+	break;
+    case 'x':
+	if ( nn > 0xffffffff)
+	    sprintf(buf, "%lx%08lx", (unsigned long)(nn>>32), (unsigned long)nn);
+	else
+	    sprintf(buf, "%lx", (unsigned long)nn);
+	return;
+
+    case 'o':
+	base = 8;
+	power_table = powers_of_eight;
+	max_power = MAX_PEIGHT;
+	break;
+    }
+
+    if ( power_table[0] == 0)
+    {
+       /* First time, calculate all the powers of the base */
+       power = 1;
+       exp =0;
+       while (exp < max_power)
+       {
+	    power_table[exp++] = power;
+	    power *= base;
+       }
+
+    }
+
+    /* Compute the first power of base larger than n */
+    exp = 0;
+    do  exp++;
+    while ( exp < max_power && power_table[exp] <= nn);
+
+    /* Now form the decimal or octal value */
+    do
+    {
+	int digit;
+	power = power_table[--exp];
+	digit = nn / power;
+	*buf++ = '0' + digit;
+	nn -= power*digit;
+    }while(exp);
+    *buf = 0;
+}
+#endif
+
 /*  Construct a value string for an integer type variable using the format.
  */
 void
@@ -252,65 +348,61 @@ vlong n;
 vformat_t format;
 {
 	switch(format) {
-#if (defined(__GNUC__) && !defined (OS_SUNOS_4)) || defined(HAVE_LONG_LONG)
-#if defined(OS_SUNOS)
-#define FMT_L "%ll"
-#else
-#define FMT_L "%q"
-#endif
+/* This test is really "ANSI compliant C pre-processor ?" */
+#if HAVE_LONG_LONG
  	case DF_NONE:
  	case DF_SDEC:
- 		sprintf(buf, FMT_L "d", n);
+ 		sprintf_ll(buf, "%" VLONG_FMT "d", n);
  		break;
  	case DF_UDEC:
- 		sprintf(buf, FMT_L "u", n);
+ 		sprintf_ll(buf, "%" VLONG_FMT "u", n);
  		break;
  	case DF_SOCT:
  		if (n >= 0)
- 			sprintf(buf, "0" FMT_L "o", n);
+ 			sprintf_ll(buf, "0" "%" VLONG_FMT "o", n);
  		else
- 			sprintf(buf, "-0" FMT_L "o", -n);
+ 			sprintf_ll(buf, "-0" "%" VLONG_FMT "o", -n);
  		break;
  	case DF_UOCT:
- 		sprintf(buf, "0" FMT_L "o", n);
+ 		sprintf_ll(buf, "0" "%" VLONG_FMT "o", n);
  		break;
  	case DF_SHEX:
  		if (n >= 0)
- 			sprintf(buf, "0x" FMT_L "x", n);
+ 			sprintf_ll(buf, "0x" "%" VLONG_FMT "x", n);
  		else
- 			sprintf(buf, "-0x" FMT_L "x", -n);
+ 			sprintf_ll(buf, "-0x" "%" VLONG_FMT "x", -n);
  		break;
  	case DF_UHEX:
  	case DF_STRING:
- 		sprintf(buf, "0x" FMT_L "x", n);
+ 		sprintf_ll(buf, "0x" "%" VLONG_FMT "x", n);
  		break;
 #else
-	case DF_NONE:
-	case DF_SDEC:
-		sprintf(buf, "%ld", n);
-		break;
-	case DF_UDEC:
-		sprintf(buf, "%lu", n);
-		break;
-	case DF_SOCT:
-		if (n >= 0)
-			sprintf(buf, "0%lo", n);
-		else
-			sprintf(buf, "-0%lo", -n);
-		break;
-	case DF_UOCT:
-		sprintf(buf, "0%lo", n);
-		break;
-	case DF_SHEX:
-		if (n >= 0)
-			sprintf(buf, "0x%lx", n);
-		else
-			sprintf(buf, "-0x%lx", -n);
-		break;
-	case DF_UHEX:
-	case DF_STRING:
-		sprintf(buf, "0x%lx", n);
-		break;
+ 	case DF_NONE:
+ 	case DF_SDEC:
+ 		sprintf_ll(buf, "%ld", n);
+ 		break;
+ 	case DF_UDEC:
+ 		sprintf_ll(buf, "%lu", n);
+ 		break;
+ 	case DF_SOCT:
+ 		if (n >= 0)
+ 			sprintf_ll(buf, "0%lo", n);
+ 		else
+ 			sprintf_ll(buf, "-0%lo", -n);
+ 		break;
+ 	case DF_UOCT:
+ 		sprintf_ll(buf, "0%lo", n);
+ 		break;
+ 	case DF_SHEX:
+ 		if (n >= 0)
+ 			sprintf_ll(buf, "0x%lx", n);
+ 		else
+ 			sprintf_ll(buf, "-0x%lx", -n);
+ 		break;
+ 	case DF_UHEX:
+ 	case DF_STRING:
+ 		sprintf_ll(buf, "0x%lx", n);
+ 		break;
 #endif
 	case DF_UBIN:
 	    {
@@ -640,17 +732,13 @@ dvar_t *dv;
 		break;
 	case TY_LONGLONG:
 	case TY_ULONGLONG:
-#if (defined(__GNUC__) && !defined (OS_SUNOS_4)) || defined(HAVE_LONG_LONG)
+#if HAVE_LONG_LONG
  		if (DREAD_VAR(xp, addr, vl.vl_longlong)) {
  			int_to_string(buf, sizeof(buf),
  				      (vlong)vl.vl_longlong, dv->dv_format);
  		}
 #else
-#ifdef OS_SUNOS_4
-		strcpy(buf, "<long long not supported on SunOS>");
-#else
-		strcpy(buf, "<recompile UPS with GCC to use long long>");
-#endif
+		strcpy(buf, "<long long not supported>");
 #endif
 		break;
 	case TY_BITFIELD:
@@ -713,18 +801,14 @@ dvar_t *dv;
 		break;
 		
 	case TY_LONGDOUBLE:
-#if (defined(__GNUC__) && !defined (OS_SUNOS_4)) || defined(HAVE_LONG_DOUBLE)
+#if HAVE_LONG_DOUBLE
  		if (dread_fpval(xp, addr, v->va_class == CL_REG, sizeof(long double),
  				(char *)&vl.vl_longdouble) == 0) {
  		    strcpy(buf, get_real(xp->xp_words_big_endian,
  					 vl, want_hex, sizeof(long double)));
  		}
 #else
-#ifdef OS_SUNOS_4
-		strcpy(buf, "<long double not supported on SunOS>");
-#else
-		strcpy(buf, "<recompile UPS with GCC to use long double>");
-#endif
+		strcpy(buf, "<long double not supported>");
 #endif
   		break;
 	case TY_ENUM:
