@@ -7,35 +7,13 @@
  *  unaltered copy of this message (including the copyright).
  */
 
-/*
- *  RCB: Rewrote this to #include as few standard header files as
- *  posible, and define as much as possible as extern int foo();
- *  This allows compilation with -ansi.
- */
-
-/*
- *  (IDE) Another rewrite - preprocessor definitions BUILTIN_... in
- *  "xc_builtins.h" control what is used here through the inclusion of
- *  "cx_libfuncs.h" and "cx_libvars.h".  If a compiler objects, the
- *  simplest fix is a new BUILTIN_... in "xc_builtins.h" which is usually
- *  defined but is #undef'd for the system that it fails on.
- */
-
 char ups_xc_builtins_c_sccsid[] = "@(#)xc_builtins.c	1.11 04 Jun 1995 (UKC)";
 
 #include <mtrprog/ifdefs.h>
 
-#include <sys/types.h>
-#include <time.h>
 #include <sys/stat.h>
-#include <stdio.h>
 #include <fcntl.h>
 #include <ctype.h>
-#include <errno.h>
-
-#if defined (OS_SUNOS_5) && defined (__CLCC__)
-#include <unistd.h>
-#endif
 
 #include <local/ukcprog.h>
 
@@ -46,25 +24,31 @@ char ups_xc_builtins_c_sccsid[] = "@(#)xc_builtins.c	1.11 04 Jun 1995 (UKC)";
 #include "xc_machine.h"
 #include "xc_builtins.h"
 
-#ifdef BUILTIN_X11
+#if HAVE_X_WINDOWS
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/Xresource.h>
 extern int _Xdebug;
 #endif
+#if STDC_HEADERS
+#include <stdarg.h>
+#else
+#include <varargs.h>
+#endif
 
 /*
  * This should be kept in step with that in cx_libfuncs.h.
  */
 
 typedef int (*qsort_func_t)PROTO((const void *, const void *));
-extern void qsort PROTO((char *base, size_t nel, size_t width,
-						qsort_func_t cmp_func));
 static void builtin_qsort PROTO((char *base, size_t nel, size_t width,
 						textaddr_t cmp_func));
+static voidptr builtin_bsearch PROTO((const void *key, const void *base,
+			size_t nmemb, size_t size, textaddr_t cmp_func));
+#if HAVE_X_WINDOWS
 static int builtin_XIfEvent PROTO((Display *display, XEvent *xev,
 					textaddr_t wanted_func, char *arg));
-extern textaddr_t signal PROTO((int sig, textaddr_t func));
+#endif
 static textaddr_t builtin_signal PROTO((int sig, textaddr_t func));
 
 static int builtin__exit PROTO((int status));
@@ -84,20 +68,23 @@ static int builtin_dup PROTO((int fd));
 static int builtin_fsync PROTO((int fd));
 static int builtin_fchown PROTO((int fd, int uid, int gid));
 static int builtin_fchmod PROTO((int fd, int mode));
-#ifdef BUILTIN_FLOCK
+#if HAVE_FLOCK
 static int builtin_flock PROTO((int fd, int op));
 #endif
 static int builtin_ftruncate PROTO((int fd, long length));
 static int builtin_ioctl PROTO((int fd, unsigned cmd, caddr_t arg));
 static int builtin_fstat PROTO((int fd, struct stat *stbuf));
+#if HAVE_X_WINDOWS
 static Display *builtin_XOpenDisplay PROTO((const char *display_name));
 static int builtin_XCloseDisplay PROTO(( Display *dpy));
+#endif
 static FILE *builtin_fopen PROTO((const char *path, const char *mode));
 static int builtin_fclose PROTO(( FILE *fp));
 static FILE *builtin_popen PROTO((const char *cmd, const char *mode));
 static int builtin_pclose PROTO(( FILE *fp));
-static FILE *builtin_freopen PROTO((const char *path, const char *mode,
-								FILE *fp));
+static FILE *builtin_freopen PROTO((const char *path, const char *mode, FILE *fp));
+#if HAVE___BUILTIN_NEXT_ARG
+#endif
 
 static voidptr builtin_malloc PROTO((size_t size));
 static voidptr builtin_calloc PROTO((size_t count, size_t size));
@@ -106,6 +93,11 @@ static void builtin_free PROTO((voidptr p));
 
 static bool fd_ok PROTO((int fd));
 
+static FILE *builtin_stdin PROTO((void));
+static FILE *builtin_stderr PROTO((void));
+static FILE *builtin_stdout PROTO((void));
+static int *builtin_errno PROTO((void));
+
 extern int optind;
 extern char *optarg;
 
@@ -116,6 +108,7 @@ static char **Builtin_environ = NULL;
 
 #define WANT_DECLS
 #include "cx_libfuncs.h"
+#include "cx_libvars.h"
 #undef  WANT_DECLS
 
 static libfunc_addr_t Libfunc_addrs[] = {
@@ -170,6 +163,20 @@ textaddr_t cmp_func;
 	qsort(base, nel, width, (qsort_func_t)ci_make_callback(cmp_func, 2));
 }
 
+#if HAVE_BSEARCH
+static voidptr
+builtin_bsearch(key, base, nmemb, size, cmp_func)
+const void *key;
+const void *base;
+size_t nmemb, size;
+textaddr_t cmp_func;
+{
+	return bsearch(key, base, nmemb, size,
+		(qsort_func_t)ci_make_callback(cmp_func, 2));
+}
+#endif
+
+#if HAVE_X_WINDOWS
 static int
 builtin_XIfEvent(display, xev, wanted_func, arg)
 Display *display;
@@ -182,6 +189,7 @@ char *arg;
 	return XIfEvent(display, xev,
 			(xie_func_t)ci_make_callback(wanted_func, 3), arg);
 }
+#endif
 
 static bool
 fd_ok(fd)
@@ -248,7 +256,7 @@ char *arg;
 	return fd_ok(fd) ? ioctl(fd, (int)cmd, arg) : -1;
 }
 
-#ifdef BUILTIN_FLOCK
+#if HAVE_FLOCK
 static int
 builtin_flock(fd, op)
 int fd, op;
@@ -429,6 +437,7 @@ FILE *fp;
 	return pclose(fp);
 }
 
+#if HAVE_X_WINDOWS
 static Display *
 builtin_XOpenDisplay(display_name)
 const char *display_name;
@@ -450,6 +459,7 @@ Display *dpy;
 	ci_unregister_fd((machine_t *)NULL, ConnectionNumber(dpy));
 	return XCloseDisplay(dpy);
 }
+#endif
 
 static voidptr
 builtin_calloc(count, size)
@@ -460,7 +470,7 @@ size_t count, size;
 
 	nbytes = count * size;
 
-	p = ci_mem_malloc((machine_t *)NULL, size);
+	p = ci_mem_malloc((machine_t *)NULL, nbytes);
 
 	if (p != NULL)
 		memset(p, '\0', nbytes);
@@ -490,6 +500,35 @@ voidptr p;
 	ci_mem_free((machine_t *)NULL, p);
 }
 
+/* Dibyendu - hack to get standard streams. */
+static FILE *
+builtin_stdin()
+{
+	return stdin;
+}
+
+static FILE *
+builtin_stdout()
+{
+	return stdout;
+}
+
+static FILE *
+builtin_stderr()
+{
+	return stderr;
+}
+
+static int *
+builtin_errno()
+{
+#if HAVE___ERRNO_LOCATION
+	return __errno_location();
+#else
+	return &errno;
+#endif
+}
+
 /*  BUG: this sucks.
  */
 void
@@ -504,7 +543,7 @@ cx_get_libfuncs(count)
 size_t count;
 {
 	if (count != N_LIBFUNCS)
-		panic("libvar count botch");
+		panic("libfuncs count botch");
 
 	return Libfunc_addrs;
 }
@@ -513,6 +552,7 @@ char **
 cx_get_libvars(count)
 size_t count;
 {
+	int i = N_LIBVARS;
 	if (count != N_LIBVARS)
 		panic("libvar count botch");
 
